/********************************************************************************
** Form generated from reading UI file 'viewDialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_VIEWDIALOG_H
#define UI_VIEWDIALOG_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDoubleSpinBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSlider>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QStackedWidget>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QTextBrowser>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QTreeWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "AngleSpinBox.hpp"
#include "Dialog.hpp"
#include "LightPollutionWidget.hpp"
#include "SkyCultureMapGraphicsView.hpp"
#include "gui/ColorButton.hpp"

QT_BEGIN_NAMESPACE

class Ui_viewDialogForm
{
public:
    QVBoxLayout *vboxLayout;
    TitleBar *titleBar;
    QFrame *viewContent;
    QGridLayout *gridLayout_8;
    QListWidget *stackListWidget;
    QStackedWidget *stackedWidget;
    QWidget *page_sky;
    QGridLayout *gridLayout;
    QSpacerItem *verticalSpacer_2;
    QGroupBox *largeObjectsGroupbox;
    QGridLayout *gridLayout_18;
    QGridLayout *gridLayout_6;
    QLabel *zhrLabel;
    QSlider *zhrSlider;
    QSpinBox *zhrSpinBox;
    QLabel *label_14;
    QLabel *twilightLabel;
    QDoubleSpinBox *twilightAltitudeDoubleSpinBox;
    QGridLayout *gridLayout_14;
    QHBoxLayout *horizontalLayout_21;
    QCheckBox *atmosphereCheckBox;
    QToolButton *pushButtonAtmosphereDetails;
    QToolButton *pushButtonSkylightDetails;
    QToolButton *tonemappingPushButton;
    QDoubleSpinBox *milkyWaySaturationDoubleSpinBox;
    QHBoxLayout *_2;
    QLabel *label_4;
    LightPollutionWidget *lightPollutionWidget;
    QCheckBox *zodiacalLightCheckBox;
    QDoubleSpinBox *milkyWayBrightnessDoubleSpinBox;
    QCheckBox *milkyWayCheckBox;
    QDoubleSpinBox *zodiacalLightBrightnessDoubleSpinBox;
    QCheckBox *adaptationCheckbox;
    QSpacerItem *verticalSpacer_8;
    QGroupBox *starGroupBox;
    QGridLayout *gridLayout_19;
    QGridLayout *gridLayout_16;
    QLabel *label_5;
    QDoubleSpinBox *starTwinkleAmountDoubleSpinBox;
    QDoubleSpinBox *starRelativeScaleDoubleSpinBox;
    QCheckBox *starTwinkleCheckBox;
    QHBoxLayout *horizontalLayout_starLabel;
    QCheckBox *starLabelCheckBox;
    QSlider *starsLabelsHorizontalSlider;
    QDoubleSpinBox *starLimitMagnitudeDoubleSpinBox;
    QDoubleSpinBox *starScaleRadiusDoubleSpinBox;
    QCheckBox *checkBoxAdditionalNamesStars;
    QCheckBox *checkBoxStarDesignationsOnlyUsage;
    QCheckBox *starLimitMagnitudeCheckBox;
    QLabel *label_7;
    QHBoxLayout *horizontalLayout_28;
    QCheckBox *dblStarsDesignationsCheckBox;
    QCheckBox *varStarsDesignationsCheckBox;
    QCheckBox *hipDesignationsCheckBox;
    QSpacerItem *horizontalSpacer_5;
    QCheckBox *spikyStarsCheckBox;
    QCheckBox *starTwinkleWithoutAtmosphereCheckBox;
    QGroupBox *setProjectionGroupBox;
    QHBoxLayout *horizontalLayout_10;
    QListWidget *projectionListWidget;
    QVBoxLayout *projectionDetailsVerticalLayout;
    QTextBrowser *projectionTextBrowser;
    QHBoxLayout *horizontalLayout_12;
    QLabel *currentFovLabel;
    AngleSpinBox *currentFovSpinBox;
    QSpacerItem *horizontalSpacer_8;
    QHBoxLayout *viewportOffsetHorizontalLayout;
    QLabel *viewportOffsetLabel;
    QDoubleSpinBox *viewportOffsetSpinBox;
    QLabel *userMaxFovLabel;
    QDoubleSpinBox *userMaxFovSpinBox;
    QSpacerItem *horizontalSpacer;
    QWidget *page_SS;
    QGridLayout *gridLayout_22;
    QSpacerItem *verticalSpacer;
    QGroupBox *planetsGroupBox;
    QGridLayout *gridLayout_20;
    QHBoxLayout *horizontalLayout_17;
    QCheckBox *planetLabelCheckBox;
    QSlider *planetsLabelsHorizontalSlider;
    ColorButton *planetLabelColor;
    QHBoxLayout *horizontalLayout_6;
    QLabel *planetDetailsLabel;
    QComboBox *planetMagnitudeAlgorithmComboBox;
    QHBoxLayout *horizontalLayout_19;
    ColorButton *planetTrailsColor;
    QCheckBox *planetTrailsCheckBox;
    QSpinBox *planetTrailsThicknessSpinBox;
    QCheckBox *shadowEnlargementDanjonCheckBox;
    QHBoxLayout *planetLimMagHorizontalLayout;
    QCheckBox *planetLimitMagnitudeCheckBox;
    QDoubleSpinBox *planetLimitMagnitudeDoubleSpinBox;
    QHBoxLayout *horizontalLayout_16;
    QCheckBox *planetOrbitCheckBox;
    QCheckBox *planetOrbitPermanentCheckBox;
    QCheckBox *planetOrbitMajorPlanetsCheckBox;
    QToolButton *pushButtonOrbitColors;
    QSpinBox *planetOrbitsThicknessSpinBox;
    QHBoxLayout *horizontalLayout_9;
    ColorButton *planetNomenclatureColor;
    QCheckBox *planetNomenclatureCheckBox;
    QHBoxLayout *horizontalLayout_18;
    QCheckBox *planetIsolatedTrailsCheckBox;
    QSpinBox *planetIsolatedTrailsSpinBox;
    QVBoxLayout *verticalLayout;
    QCheckBox *planetOrbitOnlyCheckBox;
    QCheckBox *planetIsolatedOrbitCheckBox;
    QCheckBox *planetOrbitsMoonCheckBox;
    QGridLayout *gridLayout_9;
    QCheckBox *planetMarkerCheckBox;
    QCheckBox *drawSunCoronaCheckBox;
    QCheckBox *drawMoonHaloCheckBox;
    QLabel *labelShow;
    QCheckBox *drawSunGlareCheckBox;
    QHBoxLayout *horizontalLayout_2;
    QCheckBox *minorPlanetMarkersCheckBox;
    QSpacerItem *horizontalSpacer_4;
    QDoubleSpinBox *minorPlanetMarkerMagThresholdSpinBox;
    QCheckBox *planetUseObjModelsCheckBox;
    QCheckBox *planetLightSpeedCheckBox;
    QHBoxLayout *horizontalLayout_15;
    QPushButton *pushButtonGrsDetails;
    QPushButton *pushButtonSSE;
    QGridLayout *gridLayout_5;
    QCheckBox *planetScalePlanetsCheckBox;
    QCheckBox *planetScaleMinorBodyCheckBox;
    QDoubleSpinBox *minorBodyScaleFactor;
    QDoubleSpinBox *moonScaleFactor;
    QDoubleSpinBox *sunScaleFactor;
    QCheckBox *planetScaleSunCheckBox;
    QDoubleSpinBox *planetScaleFactor;
    QLabel *labelScale;
    QCheckBox *planetScaleMoonCheckBox;
    QCheckBox *moonScaleDynamicCheckBox;
    QLabel *moonScaleMinFovLabel;
    QDoubleSpinBox *moonScaleMinFovSpinBox;
    QLabel *moonScaleMaxFovLabel;
    QDoubleSpinBox *moonScaleMaxFovSpinBox;
    QSpacerItem *horizontalSpacer_17;
    QVBoxLayout *verticalLayout_2;
    QCheckBox *hidePlanetNomenclatureCheckBox;
    QHBoxLayout *terminatorHorizontalLayout;
    QCheckBox *showTerminatorNomenclatureOnlyCheckBox;
    QSpinBox *terminatorMinAltSpinbox;
    QLabel *labelTerminator;
    QSpinBox *terminatorMaxAltSpinbox;
    QSpacerItem *horizontalSpacer_6;
    QHBoxLayout *horizontalLayout_Nomenclature;
    QCheckBox *outlineCratersCheckBox;
    QCheckBox *showSpecialNomenclatureOnlyCheckBox;
    QHBoxLayout *horizontalLayoutSelfShadowing;
    QCheckBox *planetShowObjSelfShadowsCheckBox;
    QVBoxLayout *verticalLayout_3;
    QLabel *planetMagnitudeAlgorithmDescription;
    QWidget *page_DSO;
    QGridLayout *gridLayout_11;
    QGroupBox *groupDSOCatalogs;
    QGridLayout *gridLayout_10;
    QHBoxLayout *horizontalLayout;
    QLabel *label;
    QPushButton *selectAllCatalogs;
    QPushButton *selectStandardCatalogs;
    QPushButton *selectPreferredCatalogs;
    QPushButton *storePreferredCatalogs;
    QPushButton *selectNoneCatalogs;
    QCheckBox *checkBoxArp;
    QCheckBox *checkBoxUGC;
    QCheckBox *checkBoxLBN;
    QCheckBox *checkBoxRCW;
    QCheckBox *checkBoxSh2;
    QCheckBox *checkBoxNGC;
    QCheckBox *checkBoxSt;
    QCheckBox *checkBoxRu;
    QCheckBox *checkBoxACO;
    QCheckBox *checkBoxMel;
    QCheckBox *checkBoxVV;
    QCheckBox *checkBoxVdB;
    QCheckBox *checkBoxPK;
    QCheckBox *checkBoxCr;
    QCheckBox *checkBoxVdBH;
    QCheckBox *checkBoxHCG;
    QCheckBox *checkBoxPNG;
    QCheckBox *checkBoxDWB;
    QCheckBox *checkBoxESO;
    QCheckBox *checkBoxSNRG;
    QCheckBox *checkBoxLDN;
    QCheckBox *checkBoxB;
    QCheckBox *checkBoxIC;
    QCheckBox *checkBoxOther;
    QCheckBox *checkBoxPGC;
    QCheckBox *checkBoxCed;
    QCheckBox *checkBoxVdBHa;
    QCheckBox *checkBoxM;
    QCheckBox *checkBoxTr;
    QCheckBox *checkBoxC;
    QFrame *line;
    QSpacerItem *verticalSpacer_3;
    QGroupBox *groupBoxDSOTypeFilters;
    QGridLayout *gridLayout_13;
    QCheckBox *checkBoxActiveGalaxiesType;
    QCheckBox *checkBoxPlanetaryNebulaeType;
    QCheckBox *checkBoxBrightNebulaeType;
    QCheckBox *checkBoxDarkNebulaeType;
    QCheckBox *checkBoxHydrogenRegionsType;
    QCheckBox *checkBoxGalaxyClustersType;
    QCheckBox *checkBoxGalaxiesType;
    QCheckBox *checkBoxInteractingGalaxiesType;
    QCheckBox *checkBoxSupernovaRemnantsType;
    QCheckBox *checkBoxOpenStarClustersType;
    QSpacerItem *verticalSpacer_7;
    QCheckBox *checkBoxOtherType;
    QCheckBox *checkBoxGlobularStarClustersType;
    QVBoxLayout *verticalLayout_4;
    QGroupBox *groupBoxDSOLabelsAndMarkers;
    QGridLayout *gridLayout_12;
    QCheckBox *checkBoxDesignationsOnlyUsage;
    QCheckBox *checkBoxAdditionalNamesDSO;
    QCheckBox *checkBoxShowOnlyNamedDSO;
    QCheckBox *checkBoxOutlines;
    QCheckBox *checkBoxProportionalHints;
    QGridLayout *gridLayout_15;
    QSlider *nebulasLabelsHorizontalSlider;
    QLabel *labelLabels;
    QDoubleSpinBox *labelsBrightnessDoubleSpinBox;
    QDoubleSpinBox *hintsBrightnessDoubleSpinBox;
    QLabel *labelHints;
    QSlider *nebulasHintsHorizontalSlider;
    QCheckBox *checkBoxSurfaceBrightnessUsage;
    QPushButton *pushButtonConfigureDSOColors;
    QGridLayout *gridLayout_17;
    QCheckBox *nebulaLimitSizeCheckBox;
    QDoubleSpinBox *nebulaLimitMagnitudeDoubleSpinBox;
    QDoubleSpinBox *nebulaLimitSizeMaxDoubleSpinBox;
    QCheckBox *nebulaLimitMagnitudeCheckBox;
    QDoubleSpinBox *nebulaLimitSizeMinDoubleSpinBox;
    QWidget *page_markings;
    QGridLayout *gridLayout_2;
    QGroupBox *celestialSphereGroupBox;
    QVBoxLayout *verticalLayout_10;
    QGridLayout *markingsGridLayout;
    QCheckBox *showApexPointsCheckBox;
    QCheckBox *solarEquatorPartsCheckBox;
    QCheckBox *currentVerticalPartsCheckBox;
    QCheckBox *colureLabelsCheckBox;
    ColorButton *colorGalacticCenter;
    ColorButton *colorCircumpolarCircles;
    QLabel *galacticEquatorLabel;
    QHBoxLayout *horizontalLayout_27;
    QCheckBox *showUmbraCheckBox;
    QCheckBox *showUmbraCenterCheckBox;
    ColorButton *colorSolsticePoints;
    ColorButton *colorEquinoxPoints;
    ColorButton *colorUmbraCircle;
    QCheckBox *fixedEquatorLabelsCheckBox;
    QCheckBox *primeVerticalPartsCheckBox;
    ColorButton *colorAntisolarPoint;
    QLabel *colureLabel;
    QCheckBox *galacticEquatorPartsCheckBox;
    QCheckBox *solarEquatorLabelsCheckBox;
    QCheckBox *showEquinoxJ2000PointsCheckBox;
    QCheckBox *showEclipticGridOfDateCheckBox;
    QCheckBox *showEquinoxPointsCheckBox;
    ColorButton *colorHorizonLine;
    QCheckBox *colurePartsCheckBox;
    QCheckBox *showEclipticLineOfDateCheckBox;
    QCheckBox *showEclipticPolesCheckBox;
    ColorButton *colorSupergalacticEquatorLine;
    ColorButton *colorGalacticGrid;
    QCheckBox *currentVerticalLabelsCheckBox;
    QCheckBox *showInvariablePlaneCheckBox;
    ColorButton *colorSupergalacticPoles;
    QCheckBox *precessionPartsCheckBox;
    QCheckBox *meridianLabelsCheckBox;
    QCheckBox *showEclipticGridJ2000CheckBox;
    ColorButton *colorPrimeVerticalLine;
    QCheckBox *showSupergalacticPolesCheckBox;
    ColorButton *colorCelestialJ2000Poles;
    QCheckBox *galacticEquatorLabelsCheckBox;
    QCheckBox *longitudePartsCheckBox;
    QCheckBox *showZenithNadirCheckBox;
    QCheckBox *fixedEquatorPartsCheckBox;
    ColorButton *colorSolarEquatorLine;
    QCheckBox *showFixedEquatorialGridCheckBox;
    QCheckBox *showGalacticEquatorLineCheckBox;
    ColorButton *colorPenumbraCircle;
    ColorButton *colorEclipticGridJ2000;
    ColorButton *colorSupergalacticGrid;
    QLabel *longitudeLabel;
    ColorButton *colorEquatorLine;
    QCheckBox *primeVerticalLabelsCheckBox;
    QCheckBox *equatorJ2000LabelsCheckBox;
    QCheckBox *showSupergalacticEquatorLineCheckBox;
    QCheckBox *equatorJ2000PartsCheckBox;
    QCheckBox *eclipticPartsCheckBox;
    ColorButton *colorGalacticPoles;
    QCheckBox *showAzimuthalGridCheckBox;
    QCheckBox *showEquatorLineCheckBox;
    QCheckBox *supergalacticEquatorLabelsCheckBox;
    QLabel *supergalacticEquatorLabel;
    ColorButton *colorEclipticLineJ2000;
    ColorButton *colorFixedEquatorialGrid;
    ColorButton *colorFOVCenterMarker;
    QCheckBox *meridianPartsCheckBox;
    ColorButton *colorCardinalPoints;
    ColorButton *colorAzimuthalGrid;
    ColorButton *colorLongitudeLine;
    QCheckBox *showEclipticLineJ2000CheckBox;
    QCheckBox *horizonPartsCheckBox;
    QGridLayout *gridLayout_23;
    QDoubleSpinBox *fovRectangularMarkerWidthDoubleSpinBox;
    QDoubleSpinBox *fovCircularMarkerSizeDoubleSpinBox;
    QSpacerItem *horizontalSpacer_19;
    QCheckBox *showFOVCircularMarkerCheckBox;
    QDoubleSpinBox *fovRectangularMarkerRotationAngleDoubleSpinBox;
    QDoubleSpinBox *fovRectangularMarkerHeightDoubleSpinBox;
    QCheckBox *showFOVRectangularMarkerCheckBox;
    ColorButton *colorFOVCircularMarker;
    ColorButton *colorFOVRectangularMarker;
    QCheckBox *equatorLabelsCheckBox;
    ColorButton *colorApexPoints;
    QLabel *equatorLabel;
    QCheckBox *precessionLabelsCheckBox;
    QLabel *equatorJ2000Label;
    ColorButton *colorQuadratureLine;
    QCheckBox *showSolarEquatorCheckBox;
    QCheckBox *showSupergalacticGridCheckBox;
    QCheckBox *showEquatorJ2000LineCheckBox;
    QCheckBox *eclipticJ2000PartsCheckBox;
    QCheckBox *eclipticLabelsCheckBox;
    ColorButton *colorCelestialPoles;
    QCheckBox *showSolsticeJ2000PointsCheckBox;
    QLabel *horizonLabel;
    ColorButton *colorEquatorialGrid;
    QCheckBox *longitudeLabelsCheckBox;
    ColorButton *colorEclipticGridOfDate;
    QCheckBox *showCelestialJ2000PolesCheckBox;
    QLabel *eclipticJ2000Label;
    QLabel *solarEquatorLabel;
    QCheckBox *showPenumbraCheckBox;
    ColorButton *colorEclipticLineOfDate;
    QCheckBox *showEquatorialJ2000GridCheckBox;
    ColorButton *colorSolsticeJ2000Points;
    QCheckBox *eclipticJ2000LabelsCheckBox;
    QCheckBox *showSolsticePointsCheckBox;
    QCheckBox *showPrimeVerticalLineCheckBox;
    QCheckBox *showCelestialPolesCheckBox;
    ColorButton *colorCurrentVerticalLine;
    QLabel *primeVerticalLabel;
    QCheckBox *showLongitudeLineCheckBox;
    QCheckBox *showEquatorialGridCheckBox;
    QCheckBox *showPrecessionCirclesCheckBox;
    QSpacerItem *horizontalSpacer_3;
    QCheckBox *showMeridianLineCheckBox;
    QLabel *precessionLabel;
    QCheckBox *showGalacticPolesCheckBox;
    QLabel *currentVerticalLabel;
    QCheckBox *showCompassMarksCheckBox;
    ColorButton *colorEquatorJ2000Line;
    ColorButton *colorEquatorialJ2000Grid;
    QCheckBox *showGalacticGridCheckBox;
    ColorButton *colorMeridianLine;
    QCheckBox *showCurrentVerticalLineCheckBox;
    QSpacerItem *horizontalSpacer_2;
    QHBoxLayout *horizontalLayout_26;
    QCheckBox *showCardinalPointsCheckBox;
    QSpacerItem *horizontalSpacer_7;
    QCheckBox *showOrdinal8WRPointsCheckBox;
    QCheckBox *showOrdinal16WRPointsCheckBox;
    QCheckBox *showOrdinal32WRPointsCheckBox;
    QCheckBox *showAntisolarPointCheckBox;
    ColorButton *colorGalacticEquatorLine;
    QCheckBox *showCircumpolarCirclesCheckBox;
    QCheckBox *showHorizonLineCheckBox;
    ColorButton *colorEclipticPoles;
    QCheckBox *showFixedEquatorLineCheckBox;
    QCheckBox *horizonLabelsCheckBox;
    QCheckBox *showEclipticJ2000PolesCheckBox;
    ColorButton *colorFixedEquatorLine;
    QCheckBox *showQuadratureLineCheckBox;
    QCheckBox *showColuresLineCheckBox;
    QLabel *fixedEquatorLabel;
    QCheckBox *showGalacticCenterCheckBox;
    QHBoxLayout *horizontalLayout_eclipticLine;
    QLabel *eclipticLabel;
    QCheckBox *withSolarTicksCheckbox;
    QCheckBox *equatorPartsCheckBox;
    QCheckBox *supergalacticEquatorPartsCheckBox;
    ColorButton *colorCompassMarks;
    ColorButton *colorColuresLine;
    ColorButton *colorZenithNadir;
    ColorButton *colorEquinoxJ2000Points;
    QLabel *meridianLabel;
    ColorButton *colorEclipticJ2000Poles;
    QCheckBox *showFOVCenterMarkerCheckBox;
    ColorButton *colorInvariablePlane;
    ColorButton *colorPrecessionCircles;
    QFrame *lineDivider;
    QHBoxLayout *horizontalLayout_5;
    QSpacerItem *horizontalSpacer_13;
    QLabel *gridSpacingLabel;
    QComboBox *gridSpacingComboBox;
    QSpacerItem *horizontalSpacer_12;
    QLabel *label_2;
    QSpinBox *lineThicknessSpinBox;
    QLabel *partThicknessLabel;
    QSpinBox *partThicknessSpinBox;
    QLabel *pointSizeLabel;
    QSpinBox *pointSizeSpinBox;
    QSpacerItem *horizontalSpacer_11;
    QSpacerItem *verticalSpacer_4;
    QWidget *page_landscape;
    QGridLayout *gridLayout_3;
    QTextBrowser *landscapeTextBrowser;
    QGridLayout *landscapeButtonsGridLayout;
    QPushButton *pushButtonAddRemoveLandscapes;
    QPushButton *pushButtonLandscapes_say;
    QPushButton *pushButtonLandscapes_stop;
    QGroupBox *landscapeOptionsGroupBox;
    QGridLayout *gridLayout_7;
    QHBoxLayout *horizontalLayout_25;
    QCheckBox *localLandscapeBrightnessCheckBox;
    QCheckBox *landscapeIlluminationCheckBox;
    QHBoxLayout *horizontalLayout_13;
    QCheckBox *landscapeTransparencyCheckBox;
    QDoubleSpinBox *landscapeTransparencySpinBox;
    QHBoxLayout *landscapePolylineHorizontalLayout;
    QCheckBox *landscapePolylineCheckBox;
    QSpinBox *landscapePolylineThicknessSpinBox;
    QHBoxLayout *horizontalLayout_11;
    QCheckBox *landscapeBrightnessCheckBox;
    QDoubleSpinBox *landscapeBrightnessSpinBox;
    QHBoxLayout *horizontalLayout_3;
    QCheckBox *landscapeLabelsCheckBox;
    QSpinBox *landscapeLabelsFontSizeSpinBox;
    QSpinBox *landscapeLabelsAngleSpinBox;
    ColorButton *labelsColorButton;
    ColorButton *polygonColorButton;
    QCheckBox *showFogCheckBox;
    QCheckBox *showGroundCheckBox;
    QCheckBox *landscapeLocationCheckBox;
    QCheckBox *useAsDefaultLandscapeCheckBox;
    QListWidget *landscapesListWidget;
    QWidget *page_skyCulture;
    QGridLayout *gridLayout_4;
    QTabWidget *skyCultureTabWidget;
    QWidget *skyCultureDetailsTab;
    QGridLayout *skyCultureDetailsPageGridLayout;
    QTextBrowser *skyCultureTextBrowser;
    QGroupBox *skyCultureOptionsGroupBox;
    QGridLayout *formLayout_2;
    QGridLayout *gridLayout_CulturalLabeling;
    QCheckBox *useAsDefaultSkyCultureCheckBox;
    QPushButton *pushButtonSkyculture_say;
    QPushButton *pushButtonSkyculture_stop;
    QLabel *labelInfoLabel2;
    QLabel *labelScreenLabel2;
    QCheckBox *screenLabelTranslationCheckBox;
    QCheckBox *infoLabelTranslationCheckBox;
    QCheckBox *screenLabelPronounceCheckBox;
    QCheckBox *screenLabelModernCheckBox;
    QCheckBox *screenLabelTransliterationCheckBox;
    QCheckBox *infoLabelNativeCheckBox;
    QCheckBox *infoLabelTransliterationCheckBox;
    QCheckBox *infoLabelIPACheckBox;
    QCheckBox *screenLabelNativeCheckBox;
    QCheckBox *infoLabelPronounceCheckBox;
    QCheckBox *screenLabelIPACheckBox;
    QCheckBox *infoLabelModernCheckBox;
    QCheckBox *infoLabelBynameCheckBox;
    QCheckBox *screenLabelBynameCheckBox;
    QGridLayout *skyCultureGridLayout;
    QSpacerItem *horizontalSpacer_10;
    QCheckBox *zodiacCheckBox;
    QSpinBox *constellationsFontSizeSpinBox;
    ColorButton *zodiacColorButton;
    QSpinBox *zodiacThicknessSpinBox;
    QDoubleSpinBox *asterismLinesFadeDurationDoubleSpinBox;
    QCheckBox *showConstellationLabelsCheckBox;
    ColorButton *colorAsterismLines;
    ColorButton *constellationHullsColorButton;
    QCheckBox *constellationPickCheckBox;
    QSpinBox *constellationBoundariesThicknessSpinBox;
    QCheckBox *showAsterismLinesCheckBox;
    ColorButton *colorRayHelpers;
    QCheckBox *constellationHullsCheckBox;
    ColorButton *colorConstellationBoundaries;
    QCheckBox *abbreviatedNamesCheckBox;
    ColorButton *colorAsterismLabels;
    QCheckBox *showConstellationArtCheckBox;
    QCheckBox *lunarSystemCheckBox;
    QDoubleSpinBox *constellationArtBrightnessSpinBox;
    QCheckBox *showConstellationBoundariesCheckBox;
    QDoubleSpinBox *rayHelpersFadeDurationDoubleSpinBox;
    QCheckBox *showConstellationLinesCheckBox;
    QDoubleSpinBox *namesFadeDurationDoubleSpinBox;
    QSpinBox *constellationHullsThicknessSpinBox;
    QDoubleSpinBox *lunarSystemFadeDurationDoubleSpinBox;
    QDoubleSpinBox *asterismNamesFadeDurationDoubleSpinBox;
    QSpinBox *lunarSystemThicknessSpinBox;
    QCheckBox *showRayHelpersCheckBox;
    QDoubleSpinBox *artFadeDurationDoubleSpinBox;
    ColorButton *colorConstellationLabels;
    QDoubleSpinBox *constellationHullsFadeDurationDoubleSpinBox;
    QSpinBox *asterismLineThicknessSpinBox;
    ColorButton *colorConstellationLines;
    QSpinBox *constellationLineThicknessSpinBox;
    QCheckBox *selectSingleConstellationCheckBox;
    QCheckBox *showAsterismLabelsCheckBox;
    QDoubleSpinBox *zodiacFadeDurationDoubleSpinBox;
    QSpinBox *asterismsFontSizeSpinBox;
    QSpinBox *rayHelperThicknessSpinBox;
    ColorButton *lunarSystemColorButton;
    QSpacerItem *horizontalSpacer_9;
    QDoubleSpinBox *linesFadeDurationDoubleSpinBox;
    QDoubleSpinBox *boundariesFadeDurationDoubleSpinBox;
    QFrame *line_3;
    QComboBox *zodiacLabelComboBox;
    QComboBox *lunarSystemLabelComboBox;
    QFrame *line_2;
    QWidget *skyCultureMapTab;
    QGridLayout *skyCultureMapPageGridLayout;
    QGridLayout *gridLayout_25;
    SkyCultureMapGraphicsView *skyCultureMapGraphicsView;
    QGroupBox *skyCultureTimeOptionsGroupBox;
    QGridLayout *skyCultureTimeOptionsGridLayout;
    QGridLayout *skyCultureTimeSliderGridLayout;
    QLabel *skyCultureCurrentTimeLabel;
    QSlider *skyCultureTimeSlider;
    QSpinBox *skyCultureCurrentTimeSpinBox;
    QGridLayout *skyCultureMinMaxTimeGridLayout;
    QLabel *skyCultureMinTimeLabel;
    QSpinBox *skyCultureMinTimeSpinBox;
    QSpacerItem *timeOptionsHorizontalSpacer;
    QLabel *skyCultureMaxTimeLabel;
    QSpinBox *skyCultureMaxTimeSpinBox;
    QCheckBox *applyTimeOnListCheckBox;
    QLabel *selectedCultureMinTimeLabel;
    QLabel *selectedCultureMinTimeValueLabel;
    QLabel *selectedCultureMaxTimeLabel;
    QLabel *selectedCultureMaxTimeValueLabel;
    QCheckBox *useLocationForRotationCheckBox;
    QVBoxLayout *verticalLayout_5;
    QListWidget *culturesListWidget;
    QLineEdit *culturesListSearchLineEdit;
    QWidget *page_surveys;
    QGridLayout *gridLayout_21;
    QTextBrowser *surveysTextBrowser;
    QComboBox *surveyTypeComboBox;
    QLineEdit *surveysFilter;
    QTreeWidget *surveysTreeWidget;
    QButtonGroup *buttonGroupDisplayedDSOCatalogs;
    QButtonGroup *buttonGroupDisplayedDSOTypes;

    void setupUi(QWidget *viewDialogForm)
    {
        if (viewDialogForm->objectName().isEmpty())
            viewDialogForm->setObjectName("viewDialogForm");
        viewDialogForm->resize(996, 570);
        QFont font;
        viewDialogForm->setFont(font);
        vboxLayout = new QVBoxLayout(viewDialogForm);
        vboxLayout->setSpacing(0);
        vboxLayout->setObjectName("vboxLayout");
        vboxLayout->setContentsMargins(0, 0, 0, 0);
        titleBar = new TitleBar(viewDialogForm);
        titleBar->setObjectName("titleBar");

        vboxLayout->addWidget(titleBar);

        viewContent = new QFrame(viewDialogForm);
        viewContent->setObjectName("viewContent");
        viewContent->setFrameShape(QFrame::StyledPanel);
        gridLayout_8 = new QGridLayout(viewContent);
        gridLayout_8->setSpacing(0);
        gridLayout_8->setObjectName("gridLayout_8");
        gridLayout_8->setContentsMargins(0, 0, 0, 0);
        stackListWidget = new QListWidget(viewContent);
        QIcon icon;
        icon.addFile(QString::fromUtf8(":/graphicGui/tabSky.png"), QSize(), QIcon::Mode::Normal, QIcon::State::On);
        icon.addFile(QString::fromUtf8(":/graphicGui/tabSky-selected.png"), QSize(), QIcon::Mode::Selected, QIcon::State::On);
        QListWidgetItem *__qlistwidgetitem = new QListWidgetItem(stackListWidget);
        __qlistwidgetitem->setIcon(icon);
        QIcon icon1;
        icon1.addFile(QString::fromUtf8(":/graphicGui/tabSSO.png"), QSize(), QIcon::Mode::Normal, QIcon::State::On);
        icon1.addFile(QString::fromUtf8(":/graphicGui/tabSSO-selected.png"), QSize(), QIcon::Mode::Selected, QIcon::State::On);
        QListWidgetItem *__qlistwidgetitem1 = new QListWidgetItem(stackListWidget);
        __qlistwidgetitem1->setIcon(icon1);
        QIcon icon2;
        icon2.addFile(QString::fromUtf8(":/graphicGui/tabDSO.png"), QSize(), QIcon::Mode::Normal, QIcon::State::On);
        icon2.addFile(QString::fromUtf8(":/graphicGui/tabDSO-selected.png"), QSize(), QIcon::Mode::Selected, QIcon::State::On);
        QListWidgetItem *__qlistwidgetitem2 = new QListWidgetItem(stackListWidget);
        __qlistwidgetitem2->setIcon(icon2);
        QIcon icon3;
        icon3.addFile(QString::fromUtf8(":/graphicGui/tabMarkings.png"), QSize(), QIcon::Mode::Normal, QIcon::State::On);
        icon3.addFile(QString::fromUtf8(":/graphicGui/tabMarkings-selected.png"), QSize(), QIcon::Mode::Selected, QIcon::State::On);
        QListWidgetItem *__qlistwidgetitem3 = new QListWidgetItem(stackListWidget);
        __qlistwidgetitem3->setIcon(icon3);
        QIcon icon4;
        icon4.addFile(QString::fromUtf8(":/graphicGui/tabLandscape.png"), QSize(), QIcon::Mode::Normal, QIcon::State::On);
        icon4.addFile(QString::fromUtf8(":/graphicGui/tabLandscape-selected.png"), QSize(), QIcon::Mode::Selected, QIcon::State::On);
        QListWidgetItem *__qlistwidgetitem4 = new QListWidgetItem(stackListWidget);
        __qlistwidgetitem4->setIcon(icon4);
        QIcon icon5;
        icon5.addFile(QString::fromUtf8(":/graphicGui/tabSkyCulture.png"), QSize(), QIcon::Mode::Normal, QIcon::State::On);
        icon5.addFile(QString::fromUtf8(":/graphicGui/tabSkyCulture-selected.png"), QSize(), QIcon::Mode::Selected, QIcon::State::On);
        QListWidgetItem *__qlistwidgetitem5 = new QListWidgetItem(stackListWidget);
        __qlistwidgetitem5->setIcon(icon5);
        QIcon icon6;
        icon6.addFile(QString::fromUtf8(":/graphicGui/tabSurveys.png"), QSize(), QIcon::Mode::Normal, QIcon::State::On);
        icon6.addFile(QString::fromUtf8(":/graphicGui/tabSurveys-selected.png"), QSize(), QIcon::Mode::Selected, QIcon::State::On);
        QListWidgetItem *__qlistwidgetitem6 = new QListWidgetItem(stackListWidget);
        __qlistwidgetitem6->setIcon(icon6);
        stackListWidget->setObjectName("stackListWidget");
        stackListWidget->setFocusPolicy(Qt::NoFocus);
        stackListWidget->setVerticalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
        stackListWidget->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
        stackListWidget->setSelectionMode(QAbstractItemView::SingleSelection);
        stackListWidget->setMovement(QListView::Static);
        stackListWidget->setFlow(QListView::LeftToRight);
        stackListWidget->setProperty("isWrapping", QVariant(false));
        stackListWidget->setResizeMode(QListView::Adjust);
        stackListWidget->setLayoutMode(QListView::SinglePass);
        stackListWidget->setSpacing(0);
        stackListWidget->setViewMode(QListView::IconMode);
        stackListWidget->setUniformItemSizes(false);
        stackListWidget->setWordWrap(false);
        stackListWidget->setSelectionRectVisible(false);

        gridLayout_8->addWidget(stackListWidget, 0, 0, 1, 1);

        stackedWidget = new QStackedWidget(viewContent);
        stackedWidget->setObjectName("stackedWidget");
        page_sky = new QWidget();
        page_sky->setObjectName("page_sky");
        gridLayout = new QGridLayout(page_sky);
        gridLayout->setSpacing(0);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setContentsMargins(0, 0, 0, 0);
        verticalSpacer_2 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(verticalSpacer_2, 2, 0, 1, 1);

        largeObjectsGroupbox = new QGroupBox(page_sky);
        largeObjectsGroupbox->setObjectName("largeObjectsGroupbox");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(largeObjectsGroupbox->sizePolicy().hasHeightForWidth());
        largeObjectsGroupbox->setSizePolicy(sizePolicy);
        largeObjectsGroupbox->setAlignment(Qt::AlignLeading);
        largeObjectsGroupbox->setFlat(true);
        largeObjectsGroupbox->setCheckable(false);
        gridLayout_18 = new QGridLayout(largeObjectsGroupbox);
        gridLayout_18->setObjectName("gridLayout_18");
        gridLayout_18->setContentsMargins(0, 0, 0, 0);
        gridLayout_6 = new QGridLayout();
        gridLayout_6->setObjectName("gridLayout_6");
        zhrLabel = new QLabel(largeObjectsGroupbox);
        zhrLabel->setObjectName("zhrLabel");
        zhrLabel->setTextFormat(Qt::RichText);
        zhrLabel->setScaledContents(false);

        gridLayout_6->addWidget(zhrLabel, 2, 1, 1, 2);

        zhrSlider = new QSlider(largeObjectsGroupbox);
        zhrSlider->setObjectName("zhrSlider");
        zhrSlider->setMaximum(240000);
        zhrSlider->setSliderPosition(10);
        zhrSlider->setOrientation(Qt::Horizontal);
        zhrSlider->setTickPosition(QSlider::NoTicks);

        gridLayout_6->addWidget(zhrSlider, 1, 1, 1, 1);

        zhrSpinBox = new QSpinBox(largeObjectsGroupbox);
        zhrSpinBox->setObjectName("zhrSpinBox");
        zhrSpinBox->setFrame(true);
        zhrSpinBox->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        zhrSpinBox->setMaximum(240000);
        zhrSpinBox->setValue(10);

        gridLayout_6->addWidget(zhrSpinBox, 1, 2, 1, 1);

        label_14 = new QLabel(largeObjectsGroupbox);
        label_14->setObjectName("label_14");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Minimum);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(label_14->sizePolicy().hasHeightForWidth());
        label_14->setSizePolicy(sizePolicy1);
        label_14->setTextFormat(Qt::PlainText);
        label_14->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);

        gridLayout_6->addWidget(label_14, 1, 0, 1, 1);

        twilightLabel = new QLabel(largeObjectsGroupbox);
        twilightLabel->setObjectName("twilightLabel");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Fixed);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(twilightLabel->sizePolicy().hasHeightForWidth());
        twilightLabel->setSizePolicy(sizePolicy2);

        gridLayout_6->addWidget(twilightLabel, 0, 0, 1, 2);

        twilightAltitudeDoubleSpinBox = new QDoubleSpinBox(largeObjectsGroupbox);
        twilightAltitudeDoubleSpinBox->setObjectName("twilightAltitudeDoubleSpinBox");
        twilightAltitudeDoubleSpinBox->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        twilightAltitudeDoubleSpinBox->setSuffix(QString::fromUtf8("\302\260"));
        twilightAltitudeDoubleSpinBox->setDecimals(2);
        twilightAltitudeDoubleSpinBox->setMinimum(-20.000000000000000);
        twilightAltitudeDoubleSpinBox->setMaximum(0.000000000000000);
        twilightAltitudeDoubleSpinBox->setSingleStep(0.100000000000000);

        gridLayout_6->addWidget(twilightAltitudeDoubleSpinBox, 0, 2, 1, 1);


        gridLayout_18->addLayout(gridLayout_6, 9, 0, 1, 1);

        gridLayout_14 = new QGridLayout();
        gridLayout_14->setObjectName("gridLayout_14");
        horizontalLayout_21 = new QHBoxLayout();
        horizontalLayout_21->setObjectName("horizontalLayout_21");
        atmosphereCheckBox = new QCheckBox(largeObjectsGroupbox);
        atmosphereCheckBox->setObjectName("atmosphereCheckBox");
        sizePolicy2.setHeightForWidth(atmosphereCheckBox->sizePolicy().hasHeightForWidth());
        atmosphereCheckBox->setSizePolicy(sizePolicy2);

        horizontalLayout_21->addWidget(atmosphereCheckBox);

        pushButtonAtmosphereDetails = new QToolButton(largeObjectsGroupbox);
        pushButtonAtmosphereDetails->setObjectName("pushButtonAtmosphereDetails");
        QIcon icon7;
        icon7.addFile(QString::fromUtf8(":/graphicGui/uibtSettings.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        icon7.addFile(QString::fromUtf8(":/graphicGui/uibtSettings-disabled.png"), QSize(), QIcon::Mode::Disabled, QIcon::State::Off);
        pushButtonAtmosphereDetails->setIcon(icon7);

        horizontalLayout_21->addWidget(pushButtonAtmosphereDetails);

        pushButtonSkylightDetails = new QToolButton(largeObjectsGroupbox);
        pushButtonSkylightDetails->setObjectName("pushButtonSkylightDetails");
        pushButtonSkylightDetails->setText(QString::fromUtf8(""));
        QIcon icon8;
        icon8.addFile(QString::fromUtf8(":/graphicGui/uibtEdit.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        icon8.addFile(QString::fromUtf8(":/graphicGui/uibtEdit-disabled.png"), QSize(), QIcon::Mode::Disabled, QIcon::State::Off);
        pushButtonSkylightDetails->setIcon(icon8);

        horizontalLayout_21->addWidget(pushButtonSkylightDetails);

        tonemappingPushButton = new QToolButton(largeObjectsGroupbox);
        tonemappingPushButton->setObjectName("tonemappingPushButton");
        tonemappingPushButton->setText(QString::fromUtf8(""));
        QIcon icon9;
        icon9.addFile(QString::fromUtf8(":/graphicGui/uibtProcess.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        icon9.addFile(QString::fromUtf8(":/graphicGui/uibtProcess-disabled.png"), QSize(), QIcon::Mode::Disabled, QIcon::State::Off);
        tonemappingPushButton->setIcon(icon9);

        horizontalLayout_21->addWidget(tonemappingPushButton);


        gridLayout_14->addLayout(horizontalLayout_21, 3, 0, 1, 3);

        milkyWaySaturationDoubleSpinBox = new QDoubleSpinBox(largeObjectsGroupbox);
        milkyWaySaturationDoubleSpinBox->setObjectName("milkyWaySaturationDoubleSpinBox");
        milkyWaySaturationDoubleSpinBox->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        milkyWaySaturationDoubleSpinBox->setMinimum(0.000000000000000);
        milkyWaySaturationDoubleSpinBox->setMaximum(1.000000000000000);
        milkyWaySaturationDoubleSpinBox->setSingleStep(0.100000000000000);

        gridLayout_14->addWidget(milkyWaySaturationDoubleSpinBox, 0, 2, 1, 1);

        _2 = new QHBoxLayout();
        _2->setObjectName("_2");
        label_4 = new QLabel(largeObjectsGroupbox);
        label_4->setObjectName("label_4");

        _2->addWidget(label_4);

        lightPollutionWidget = new LightPollutionWidget(largeObjectsGroupbox);
        lightPollutionWidget->setObjectName("lightPollutionWidget");
        QSizePolicy sizePolicy3(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Preferred);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(lightPollutionWidget->sizePolicy().hasHeightForWidth());
        lightPollutionWidget->setSizePolicy(sizePolicy3);

        _2->addWidget(lightPollutionWidget);


        gridLayout_14->addLayout(_2, 4, 0, 1, 3);

        zodiacalLightCheckBox = new QCheckBox(largeObjectsGroupbox);
        zodiacalLightCheckBox->setObjectName("zodiacalLightCheckBox");

        gridLayout_14->addWidget(zodiacalLightCheckBox, 1, 0, 1, 1);

        milkyWayBrightnessDoubleSpinBox = new QDoubleSpinBox(largeObjectsGroupbox);
        milkyWayBrightnessDoubleSpinBox->setObjectName("milkyWayBrightnessDoubleSpinBox");
        milkyWayBrightnessDoubleSpinBox->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        milkyWayBrightnessDoubleSpinBox->setDecimals(2);
        milkyWayBrightnessDoubleSpinBox->setMaximum(10.000000000000000);
        milkyWayBrightnessDoubleSpinBox->setSingleStep(0.100000000000000);
        milkyWayBrightnessDoubleSpinBox->setValue(1.000000000000000);

        gridLayout_14->addWidget(milkyWayBrightnessDoubleSpinBox, 0, 1, 1, 1);

        milkyWayCheckBox = new QCheckBox(largeObjectsGroupbox);
        milkyWayCheckBox->setObjectName("milkyWayCheckBox");
        sizePolicy2.setHeightForWidth(milkyWayCheckBox->sizePolicy().hasHeightForWidth());
        milkyWayCheckBox->setSizePolicy(sizePolicy2);

        gridLayout_14->addWidget(milkyWayCheckBox, 0, 0, 1, 1);

        zodiacalLightBrightnessDoubleSpinBox = new QDoubleSpinBox(largeObjectsGroupbox);
        zodiacalLightBrightnessDoubleSpinBox->setObjectName("zodiacalLightBrightnessDoubleSpinBox");
        zodiacalLightBrightnessDoubleSpinBox->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        zodiacalLightBrightnessDoubleSpinBox->setDecimals(2);
        zodiacalLightBrightnessDoubleSpinBox->setMaximum(10.000000000000000);
        zodiacalLightBrightnessDoubleSpinBox->setSingleStep(0.100000000000000);
        zodiacalLightBrightnessDoubleSpinBox->setValue(1.000000000000000);

        gridLayout_14->addWidget(zodiacalLightBrightnessDoubleSpinBox, 1, 2, 1, 1);

        adaptationCheckbox = new QCheckBox(largeObjectsGroupbox);
        adaptationCheckbox->setObjectName("adaptationCheckbox");
        adaptationCheckbox->setChecked(false);

        gridLayout_14->addWidget(adaptationCheckbox, 2, 0, 1, 1);


        gridLayout_18->addLayout(gridLayout_14, 0, 0, 1, 1);

        verticalSpacer_8 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_18->addItem(verticalSpacer_8, 10, 0, 1, 1);


        gridLayout->addWidget(largeObjectsGroupbox, 0, 0, 1, 1);

        starGroupBox = new QGroupBox(page_sky);
        starGroupBox->setObjectName("starGroupBox");
        starGroupBox->setAlignment(Qt::AlignLeading);
        starGroupBox->setFlat(true);
        starGroupBox->setCheckable(true);
        starGroupBox->setChecked(true);
        gridLayout_19 = new QGridLayout(starGroupBox);
        gridLayout_19->setObjectName("gridLayout_19");
        gridLayout_19->setContentsMargins(0, 0, 0, 0);
        gridLayout_16 = new QGridLayout();
        gridLayout_16->setObjectName("gridLayout_16");
        label_5 = new QLabel(starGroupBox);
        label_5->setObjectName("label_5");
        sizePolicy3.setHeightForWidth(label_5->sizePolicy().hasHeightForWidth());
        label_5->setSizePolicy(sizePolicy3);

        gridLayout_16->addWidget(label_5, 0, 0, 1, 1);

        starTwinkleAmountDoubleSpinBox = new QDoubleSpinBox(starGroupBox);
        starTwinkleAmountDoubleSpinBox->setObjectName("starTwinkleAmountDoubleSpinBox");
        starTwinkleAmountDoubleSpinBox->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        starTwinkleAmountDoubleSpinBox->setDecimals(2);
        starTwinkleAmountDoubleSpinBox->setMaximum(1.500000000000000);
        starTwinkleAmountDoubleSpinBox->setSingleStep(0.100000000000000);

        gridLayout_16->addWidget(starTwinkleAmountDoubleSpinBox, 2, 2, 1, 1);

        starRelativeScaleDoubleSpinBox = new QDoubleSpinBox(starGroupBox);
        starRelativeScaleDoubleSpinBox->setObjectName("starRelativeScaleDoubleSpinBox");
        starRelativeScaleDoubleSpinBox->setFrame(true);
        starRelativeScaleDoubleSpinBox->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        starRelativeScaleDoubleSpinBox->setButtonSymbols(QAbstractSpinBox::UpDownArrows);
        starRelativeScaleDoubleSpinBox->setDecimals(2);
        starRelativeScaleDoubleSpinBox->setMinimum(0.250000000000000);
        starRelativeScaleDoubleSpinBox->setMaximum(5.000000000000000);
        starRelativeScaleDoubleSpinBox->setSingleStep(0.050000000000000);
        starRelativeScaleDoubleSpinBox->setValue(1.000000000000000);

        gridLayout_16->addWidget(starRelativeScaleDoubleSpinBox, 1, 2, 1, 1);

        starTwinkleCheckBox = new QCheckBox(starGroupBox);
        starTwinkleCheckBox->setObjectName("starTwinkleCheckBox");
        starTwinkleCheckBox->setChecked(true);

        gridLayout_16->addWidget(starTwinkleCheckBox, 2, 0, 1, 1);

        horizontalLayout_starLabel = new QHBoxLayout();
        horizontalLayout_starLabel->setObjectName("horizontalLayout_starLabel");
        starLabelCheckBox = new QCheckBox(starGroupBox);
        starLabelCheckBox->setObjectName("starLabelCheckBox");
        starLabelCheckBox->setEnabled(true);

        horizontalLayout_starLabel->addWidget(starLabelCheckBox);

        starsLabelsHorizontalSlider = new QSlider(starGroupBox);
        starsLabelsHorizontalSlider->setObjectName("starsLabelsHorizontalSlider");
        sizePolicy.setHeightForWidth(starsLabelsHorizontalSlider->sizePolicy().hasHeightForWidth());
        starsLabelsHorizontalSlider->setSizePolicy(sizePolicy);
        starsLabelsHorizontalSlider->setValue(33);
        starsLabelsHorizontalSlider->setOrientation(Qt::Horizontal);

        horizontalLayout_starLabel->addWidget(starsLabelsHorizontalSlider);


        gridLayout_16->addLayout(horizontalLayout_starLabel, 5, 0, 1, 3);

        starLimitMagnitudeDoubleSpinBox = new QDoubleSpinBox(starGroupBox);
        starLimitMagnitudeDoubleSpinBox->setObjectName("starLimitMagnitudeDoubleSpinBox");
        starLimitMagnitudeDoubleSpinBox->setFrame(true);
        starLimitMagnitudeDoubleSpinBox->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        starLimitMagnitudeDoubleSpinBox->setButtonSymbols(QAbstractSpinBox::UpDownArrows);
        starLimitMagnitudeDoubleSpinBox->setDecimals(2);
        starLimitMagnitudeDoubleSpinBox->setMinimum(0.000000000000000);
        starLimitMagnitudeDoubleSpinBox->setMaximum(21.000000000000000);
        starLimitMagnitudeDoubleSpinBox->setSingleStep(0.100000000000000);
        starLimitMagnitudeDoubleSpinBox->setValue(6.500000000000000);

        gridLayout_16->addWidget(starLimitMagnitudeDoubleSpinBox, 3, 2, 1, 1);

        starScaleRadiusDoubleSpinBox = new QDoubleSpinBox(starGroupBox);
        starScaleRadiusDoubleSpinBox->setObjectName("starScaleRadiusDoubleSpinBox");
        starScaleRadiusDoubleSpinBox->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        starScaleRadiusDoubleSpinBox->setDecimals(2);
        starScaleRadiusDoubleSpinBox->setMinimum(0.050000000000000);
        starScaleRadiusDoubleSpinBox->setMaximum(10.000000000000000);
        starScaleRadiusDoubleSpinBox->setSingleStep(0.050000000000000);
        starScaleRadiusDoubleSpinBox->setValue(1.000000000000000);

        gridLayout_16->addWidget(starScaleRadiusDoubleSpinBox, 0, 2, 1, 1);

        checkBoxAdditionalNamesStars = new QCheckBox(starGroupBox);
        checkBoxAdditionalNamesStars->setObjectName("checkBoxAdditionalNamesStars");

        gridLayout_16->addWidget(checkBoxAdditionalNamesStars, 6, 0, 1, 3);

        checkBoxStarDesignationsOnlyUsage = new QCheckBox(starGroupBox);
        checkBoxStarDesignationsOnlyUsage->setObjectName("checkBoxStarDesignationsOnlyUsage");

        gridLayout_16->addWidget(checkBoxStarDesignationsOnlyUsage, 7, 0, 1, 3);

        starLimitMagnitudeCheckBox = new QCheckBox(starGroupBox);
        starLimitMagnitudeCheckBox->setObjectName("starLimitMagnitudeCheckBox");
        sizePolicy2.setHeightForWidth(starLimitMagnitudeCheckBox->sizePolicy().hasHeightForWidth());
        starLimitMagnitudeCheckBox->setSizePolicy(sizePolicy2);

        gridLayout_16->addWidget(starLimitMagnitudeCheckBox, 3, 0, 1, 1);

        label_7 = new QLabel(starGroupBox);
        label_7->setObjectName("label_7");

        gridLayout_16->addWidget(label_7, 1, 0, 1, 1);

        horizontalLayout_28 = new QHBoxLayout();
        horizontalLayout_28->setObjectName("horizontalLayout_28");
        horizontalLayout_28->setContentsMargins(22, -1, -1, -1);
        dblStarsDesignationsCheckBox = new QCheckBox(starGroupBox);
        dblStarsDesignationsCheckBox->setObjectName("dblStarsDesignationsCheckBox");

        horizontalLayout_28->addWidget(dblStarsDesignationsCheckBox);

        varStarsDesignationsCheckBox = new QCheckBox(starGroupBox);
        varStarsDesignationsCheckBox->setObjectName("varStarsDesignationsCheckBox");

        horizontalLayout_28->addWidget(varStarsDesignationsCheckBox);

        hipDesignationsCheckBox = new QCheckBox(starGroupBox);
        hipDesignationsCheckBox->setObjectName("hipDesignationsCheckBox");
        hipDesignationsCheckBox->setText(QString::fromUtf8("HIP"));

        horizontalLayout_28->addWidget(hipDesignationsCheckBox);

        horizontalSpacer_5 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_28->addItem(horizontalSpacer_5);


        gridLayout_16->addLayout(horizontalLayout_28, 8, 0, 1, 3);

        spikyStarsCheckBox = new QCheckBox(starGroupBox);
        spikyStarsCheckBox->setObjectName("spikyStarsCheckBox");

        gridLayout_16->addWidget(spikyStarsCheckBox, 4, 0, 1, 3);

        starTwinkleWithoutAtmosphereCheckBox = new QCheckBox(starGroupBox);
        starTwinkleWithoutAtmosphereCheckBox->setObjectName("starTwinkleWithoutAtmosphereCheckBox");

        gridLayout_16->addWidget(starTwinkleWithoutAtmosphereCheckBox, 2, 1, 1, 1);


        gridLayout_19->addLayout(gridLayout_16, 0, 0, 1, 1);


        gridLayout->addWidget(starGroupBox, 0, 1, 1, 1);

        setProjectionGroupBox = new QGroupBox(page_sky);
        setProjectionGroupBox->setObjectName("setProjectionGroupBox");
        setProjectionGroupBox->setCheckable(false);
        horizontalLayout_10 = new QHBoxLayout(setProjectionGroupBox);
        horizontalLayout_10->setObjectName("horizontalLayout_10");
        horizontalLayout_10->setContentsMargins(0, 0, 0, 0);
        projectionListWidget = new QListWidget(setProjectionGroupBox);
        projectionListWidget->setObjectName("projectionListWidget");
        QSizePolicy sizePolicy4(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Expanding);
        sizePolicy4.setHorizontalStretch(0);
        sizePolicy4.setVerticalStretch(0);
        sizePolicy4.setHeightForWidth(projectionListWidget->sizePolicy().hasHeightForWidth());
        projectionListWidget->setSizePolicy(sizePolicy4);
        projectionListWidget->setFocusPolicy(Qt::NoFocus);
        projectionListWidget->setVerticalScrollBarPolicy(Qt::ScrollBarAsNeeded);
        projectionListWidget->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);

        horizontalLayout_10->addWidget(projectionListWidget);

        projectionDetailsVerticalLayout = new QVBoxLayout();
        projectionDetailsVerticalLayout->setObjectName("projectionDetailsVerticalLayout");
        projectionTextBrowser = new QTextBrowser(setProjectionGroupBox);
        projectionTextBrowser->setObjectName("projectionTextBrowser");
        projectionTextBrowser->setOpenExternalLinks(true);

        projectionDetailsVerticalLayout->addWidget(projectionTextBrowser);

        horizontalLayout_12 = new QHBoxLayout();
        horizontalLayout_12->setObjectName("horizontalLayout_12");
        horizontalLayout_12->setContentsMargins(5, 0, -1, -1);
        currentFovLabel = new QLabel(setProjectionGroupBox);
        currentFovLabel->setObjectName("currentFovLabel");

        horizontalLayout_12->addWidget(currentFovLabel);

        currentFovSpinBox = new AngleSpinBox(setProjectionGroupBox);
        currentFovSpinBox->setObjectName("currentFovSpinBox");
        currentFovSpinBox->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        horizontalLayout_12->addWidget(currentFovSpinBox);

        horizontalSpacer_8 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_12->addItem(horizontalSpacer_8);


        projectionDetailsVerticalLayout->addLayout(horizontalLayout_12);

        viewportOffsetHorizontalLayout = new QHBoxLayout();
        viewportOffsetHorizontalLayout->setObjectName("viewportOffsetHorizontalLayout");
        viewportOffsetHorizontalLayout->setContentsMargins(5, -1, -1, -1);
        viewportOffsetLabel = new QLabel(setProjectionGroupBox);
        viewportOffsetLabel->setObjectName("viewportOffsetLabel");

        viewportOffsetHorizontalLayout->addWidget(viewportOffsetLabel);

        viewportOffsetSpinBox = new QDoubleSpinBox(setProjectionGroupBox);
        viewportOffsetSpinBox->setObjectName("viewportOffsetSpinBox");
        viewportOffsetSpinBox->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        viewportOffsetSpinBox->setSuffix(QString::fromUtf8("%"));
        viewportOffsetSpinBox->setDecimals(0);
        viewportOffsetSpinBox->setMinimum(-50.000000000000000);
        viewportOffsetSpinBox->setMaximum(50.000000000000000);

        viewportOffsetHorizontalLayout->addWidget(viewportOffsetSpinBox);

        userMaxFovLabel = new QLabel(setProjectionGroupBox);
        userMaxFovLabel->setObjectName("userMaxFovLabel");

        viewportOffsetHorizontalLayout->addWidget(userMaxFovLabel);

        userMaxFovSpinBox = new QDoubleSpinBox(setProjectionGroupBox);
        userMaxFovSpinBox->setObjectName("userMaxFovSpinBox");
        userMaxFovSpinBox->setSuffix(QString::fromUtf8("\302\260"));
        userMaxFovSpinBox->setDecimals(1);
        userMaxFovSpinBox->setMinimum(1.000000000000000);
        userMaxFovSpinBox->setMaximum(360.000000000000000);
        userMaxFovSpinBox->setValue(360.000000000000000);

        viewportOffsetHorizontalLayout->addWidget(userMaxFovSpinBox);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        viewportOffsetHorizontalLayout->addItem(horizontalSpacer);


        projectionDetailsVerticalLayout->addLayout(viewportOffsetHorizontalLayout);


        horizontalLayout_10->addLayout(projectionDetailsVerticalLayout);


        gridLayout->addWidget(setProjectionGroupBox, 1, 0, 1, 2);

        stackedWidget->addWidget(page_sky);
        page_SS = new QWidget();
        page_SS->setObjectName("page_SS");
        gridLayout_22 = new QGridLayout(page_SS);
        gridLayout_22->setSpacing(0);
        gridLayout_22->setObjectName("gridLayout_22");
        gridLayout_22->setContentsMargins(0, 0, 0, 0);
        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_22->addItem(verticalSpacer, 4, 0, 1, 1);

        planetsGroupBox = new QGroupBox(page_SS);
        planetsGroupBox->setObjectName("planetsGroupBox");
        planetsGroupBox->setFlat(true);
        planetsGroupBox->setCheckable(true);
        gridLayout_20 = new QGridLayout(planetsGroupBox);
        gridLayout_20->setObjectName("gridLayout_20");
        gridLayout_20->setContentsMargins(0, 0, 0, 0);
        horizontalLayout_17 = new QHBoxLayout();
        horizontalLayout_17->setObjectName("horizontalLayout_17");
        planetLabelCheckBox = new QCheckBox(planetsGroupBox);
        planetLabelCheckBox->setObjectName("planetLabelCheckBox");

        horizontalLayout_17->addWidget(planetLabelCheckBox);

        planetsLabelsHorizontalSlider = new QSlider(planetsGroupBox);
        planetsLabelsHorizontalSlider->setObjectName("planetsLabelsHorizontalSlider");
        sizePolicy.setHeightForWidth(planetsLabelsHorizontalSlider->sizePolicy().hasHeightForWidth());
        planetsLabelsHorizontalSlider->setSizePolicy(sizePolicy);
        planetsLabelsHorizontalSlider->setValue(33);
        planetsLabelsHorizontalSlider->setOrientation(Qt::Horizontal);

        horizontalLayout_17->addWidget(planetsLabelsHorizontalSlider);

        planetLabelColor = new ColorButton(planetsGroupBox);
        planetLabelColor->setObjectName("planetLabelColor");

        horizontalLayout_17->addWidget(planetLabelColor);


        gridLayout_20->addLayout(horizontalLayout_17, 2, 1, 1, 1);

        horizontalLayout_6 = new QHBoxLayout();
        horizontalLayout_6->setObjectName("horizontalLayout_6");
        planetDetailsLabel = new QLabel(planetsGroupBox);
        planetDetailsLabel->setObjectName("planetDetailsLabel");

        horizontalLayout_6->addWidget(planetDetailsLabel);

        planetMagnitudeAlgorithmComboBox = new QComboBox(planetsGroupBox);
        planetMagnitudeAlgorithmComboBox->setObjectName("planetMagnitudeAlgorithmComboBox");
        planetMagnitudeAlgorithmComboBox->setEditable(true);
        planetMagnitudeAlgorithmComboBox->setInsertPolicy(QComboBox::NoInsert);

        horizontalLayout_6->addWidget(planetMagnitudeAlgorithmComboBox);


        gridLayout_20->addLayout(horizontalLayout_6, 12, 1, 1, 1);

        horizontalLayout_19 = new QHBoxLayout();
        horizontalLayout_19->setObjectName("horizontalLayout_19");
        planetTrailsColor = new ColorButton(planetsGroupBox);
        planetTrailsColor->setObjectName("planetTrailsColor");

        horizontalLayout_19->addWidget(planetTrailsColor);

        planetTrailsCheckBox = new QCheckBox(planetsGroupBox);
        planetTrailsCheckBox->setObjectName("planetTrailsCheckBox");
        sizePolicy2.setHeightForWidth(planetTrailsCheckBox->sizePolicy().hasHeightForWidth());
        planetTrailsCheckBox->setSizePolicy(sizePolicy2);

        horizontalLayout_19->addWidget(planetTrailsCheckBox);

        planetTrailsThicknessSpinBox = new QSpinBox(planetsGroupBox);
        planetTrailsThicknessSpinBox->setObjectName("planetTrailsThicknessSpinBox");
        planetTrailsThicknessSpinBox->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        planetTrailsThicknessSpinBox->setMinimum(1);
        planetTrailsThicknessSpinBox->setMaximum(5);

        horizontalLayout_19->addWidget(planetTrailsThicknessSpinBox);


        gridLayout_20->addLayout(horizontalLayout_19, 12, 0, 1, 1);

        shadowEnlargementDanjonCheckBox = new QCheckBox(planetsGroupBox);
        shadowEnlargementDanjonCheckBox->setObjectName("shadowEnlargementDanjonCheckBox");

        gridLayout_20->addWidget(shadowEnlargementDanjonCheckBox, 8, 1, 1, 1);

        planetLimMagHorizontalLayout = new QHBoxLayout();
        planetLimMagHorizontalLayout->setObjectName("planetLimMagHorizontalLayout");
        planetLimitMagnitudeCheckBox = new QCheckBox(planetsGroupBox);
        planetLimitMagnitudeCheckBox->setObjectName("planetLimitMagnitudeCheckBox");
        sizePolicy2.setHeightForWidth(planetLimitMagnitudeCheckBox->sizePolicy().hasHeightForWidth());
        planetLimitMagnitudeCheckBox->setSizePolicy(sizePolicy2);

        planetLimMagHorizontalLayout->addWidget(planetLimitMagnitudeCheckBox);

        planetLimitMagnitudeDoubleSpinBox = new QDoubleSpinBox(planetsGroupBox);
        planetLimitMagnitudeDoubleSpinBox->setObjectName("planetLimitMagnitudeDoubleSpinBox");
        planetLimitMagnitudeDoubleSpinBox->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        planetLimitMagnitudeDoubleSpinBox->setMinimum(-5.000000000000000);
        planetLimitMagnitudeDoubleSpinBox->setMaximum(25.000000000000000);
        planetLimitMagnitudeDoubleSpinBox->setSingleStep(0.100000000000000);
        planetLimitMagnitudeDoubleSpinBox->setValue(6.500000000000000);

        planetLimMagHorizontalLayout->addWidget(planetLimitMagnitudeDoubleSpinBox);


        gridLayout_20->addLayout(planetLimMagHorizontalLayout, 1, 1, 1, 1);

        horizontalLayout_16 = new QHBoxLayout();
        horizontalLayout_16->setObjectName("horizontalLayout_16");
        horizontalLayout_16->setContentsMargins(-1, -1, -1, 0);
        planetOrbitCheckBox = new QCheckBox(planetsGroupBox);
        planetOrbitCheckBox->setObjectName("planetOrbitCheckBox");
        QSizePolicy sizePolicy5(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);
        sizePolicy5.setHorizontalStretch(0);
        sizePolicy5.setVerticalStretch(0);
        sizePolicy5.setHeightForWidth(planetOrbitCheckBox->sizePolicy().hasHeightForWidth());
        planetOrbitCheckBox->setSizePolicy(sizePolicy5);

        horizontalLayout_16->addWidget(planetOrbitCheckBox);

        planetOrbitPermanentCheckBox = new QCheckBox(planetsGroupBox);
        planetOrbitPermanentCheckBox->setObjectName("planetOrbitPermanentCheckBox");
        sizePolicy5.setHeightForWidth(planetOrbitPermanentCheckBox->sizePolicy().hasHeightForWidth());
        planetOrbitPermanentCheckBox->setSizePolicy(sizePolicy5);

        horizontalLayout_16->addWidget(planetOrbitPermanentCheckBox);

        planetOrbitMajorPlanetsCheckBox = new QCheckBox(planetsGroupBox);
        planetOrbitMajorPlanetsCheckBox->setObjectName("planetOrbitMajorPlanetsCheckBox");
        sizePolicy2.setHeightForWidth(planetOrbitMajorPlanetsCheckBox->sizePolicy().hasHeightForWidth());
        planetOrbitMajorPlanetsCheckBox->setSizePolicy(sizePolicy2);

        horizontalLayout_16->addWidget(planetOrbitMajorPlanetsCheckBox);

        pushButtonOrbitColors = new QToolButton(planetsGroupBox);
        pushButtonOrbitColors->setObjectName("pushButtonOrbitColors");
        pushButtonOrbitColors->setText(QString::fromUtf8(""));
        pushButtonOrbitColors->setIcon(icon7);

        horizontalLayout_16->addWidget(pushButtonOrbitColors);

        planetOrbitsThicknessSpinBox = new QSpinBox(planetsGroupBox);
        planetOrbitsThicknessSpinBox->setObjectName("planetOrbitsThicknessSpinBox");
        planetOrbitsThicknessSpinBox->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        planetOrbitsThicknessSpinBox->setMinimum(1);
        planetOrbitsThicknessSpinBox->setMaximum(5);

        horizontalLayout_16->addWidget(planetOrbitsThicknessSpinBox);


        gridLayout_20->addLayout(horizontalLayout_16, 8, 0, 1, 1);

        horizontalLayout_9 = new QHBoxLayout();
        horizontalLayout_9->setObjectName("horizontalLayout_9");
        planetNomenclatureColor = new ColorButton(planetsGroupBox);
        planetNomenclatureColor->setObjectName("planetNomenclatureColor");

        horizontalLayout_9->addWidget(planetNomenclatureColor);

        planetNomenclatureCheckBox = new QCheckBox(planetsGroupBox);
        planetNomenclatureCheckBox->setObjectName("planetNomenclatureCheckBox");

        horizontalLayout_9->addWidget(planetNomenclatureCheckBox);


        gridLayout_20->addLayout(horizontalLayout_9, 2, 0, 1, 1);

        horizontalLayout_18 = new QHBoxLayout();
        horizontalLayout_18->setObjectName("horizontalLayout_18");
        horizontalLayout_18->setContentsMargins(22, -1, -1, -1);
        planetIsolatedTrailsCheckBox = new QCheckBox(planetsGroupBox);
        planetIsolatedTrailsCheckBox->setObjectName("planetIsolatedTrailsCheckBox");
        sizePolicy2.setHeightForWidth(planetIsolatedTrailsCheckBox->sizePolicy().hasHeightForWidth());
        planetIsolatedTrailsCheckBox->setSizePolicy(sizePolicy2);

        horizontalLayout_18->addWidget(planetIsolatedTrailsCheckBox);

        planetIsolatedTrailsSpinBox = new QSpinBox(planetsGroupBox);
        planetIsolatedTrailsSpinBox->setObjectName("planetIsolatedTrailsSpinBox");
        planetIsolatedTrailsSpinBox->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        planetIsolatedTrailsSpinBox->setMinimum(1);
        planetIsolatedTrailsSpinBox->setMaximum(5);
        planetIsolatedTrailsSpinBox->setValue(1);

        horizontalLayout_18->addWidget(planetIsolatedTrailsSpinBox);


        gridLayout_20->addLayout(horizontalLayout_18, 13, 0, 1, 1);

        verticalLayout = new QVBoxLayout();
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(22, -1, -1, -1);
        planetOrbitOnlyCheckBox = new QCheckBox(planetsGroupBox);
        planetOrbitOnlyCheckBox->setObjectName("planetOrbitOnlyCheckBox");

        verticalLayout->addWidget(planetOrbitOnlyCheckBox);

        planetIsolatedOrbitCheckBox = new QCheckBox(planetsGroupBox);
        planetIsolatedOrbitCheckBox->setObjectName("planetIsolatedOrbitCheckBox");

        verticalLayout->addWidget(planetIsolatedOrbitCheckBox);

        planetOrbitsMoonCheckBox = new QCheckBox(planetsGroupBox);
        planetOrbitsMoonCheckBox->setObjectName("planetOrbitsMoonCheckBox");

        verticalLayout->addWidget(planetOrbitsMoonCheckBox);


        gridLayout_20->addLayout(verticalLayout, 10, 0, 1, 1);

        gridLayout_9 = new QGridLayout();
        gridLayout_9->setObjectName("gridLayout_9");
        planetMarkerCheckBox = new QCheckBox(planetsGroupBox);
        planetMarkerCheckBox->setObjectName("planetMarkerCheckBox");

        gridLayout_9->addWidget(planetMarkerCheckBox, 1, 1, 1, 1);

        drawSunCoronaCheckBox = new QCheckBox(planetsGroupBox);
        drawSunCoronaCheckBox->setObjectName("drawSunCoronaCheckBox");

        gridLayout_9->addWidget(drawSunCoronaCheckBox, 1, 2, 1, 1);

        drawMoonHaloCheckBox = new QCheckBox(planetsGroupBox);
        drawMoonHaloCheckBox->setObjectName("drawMoonHaloCheckBox");

        gridLayout_9->addWidget(drawMoonHaloCheckBox, 0, 1, 1, 1);

        labelShow = new QLabel(planetsGroupBox);
        labelShow->setObjectName("labelShow");

        gridLayout_9->addWidget(labelShow, 0, 0, 1, 1);

        drawSunGlareCheckBox = new QCheckBox(planetsGroupBox);
        drawSunGlareCheckBox->setObjectName("drawSunGlareCheckBox");

        gridLayout_9->addWidget(drawSunGlareCheckBox, 0, 2, 1, 1);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        minorPlanetMarkersCheckBox = new QCheckBox(planetsGroupBox);
        minorPlanetMarkersCheckBox->setObjectName("minorPlanetMarkersCheckBox");

        horizontalLayout_2->addWidget(minorPlanetMarkersCheckBox);

        horizontalSpacer_4 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer_4);

        minorPlanetMarkerMagThresholdSpinBox = new QDoubleSpinBox(planetsGroupBox);
        minorPlanetMarkerMagThresholdSpinBox->setObjectName("minorPlanetMarkerMagThresholdSpinBox");
        minorPlanetMarkerMagThresholdSpinBox->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        minorPlanetMarkerMagThresholdSpinBox->setDecimals(2);
        minorPlanetMarkerMagThresholdSpinBox->setMinimum(-5.000000000000000);
        minorPlanetMarkerMagThresholdSpinBox->setMaximum(37.000000000000000);
        minorPlanetMarkerMagThresholdSpinBox->setSingleStep(0.100000000000000);
        minorPlanetMarkerMagThresholdSpinBox->setValue(15.000000000000000);

        horizontalLayout_2->addWidget(minorPlanetMarkerMagThresholdSpinBox);


        gridLayout_9->addLayout(horizontalLayout_2, 2, 1, 1, 2);


        gridLayout_20->addLayout(gridLayout_9, 3, 1, 1, 1);

        planetUseObjModelsCheckBox = new QCheckBox(planetsGroupBox);
        planetUseObjModelsCheckBox->setObjectName("planetUseObjModelsCheckBox");

        gridLayout_20->addWidget(planetUseObjModelsCheckBox, 0, 0, 1, 1);

        planetLightSpeedCheckBox = new QCheckBox(planetsGroupBox);
        planetLightSpeedCheckBox->setObjectName("planetLightSpeedCheckBox");

        gridLayout_20->addWidget(planetLightSpeedCheckBox, 0, 1, 1, 1);

        horizontalLayout_15 = new QHBoxLayout();
        horizontalLayout_15->setObjectName("horizontalLayout_15");
        pushButtonGrsDetails = new QPushButton(planetsGroupBox);
        pushButtonGrsDetails->setObjectName("pushButtonGrsDetails");

        horizontalLayout_15->addWidget(pushButtonGrsDetails);

        pushButtonSSE = new QPushButton(planetsGroupBox);
        pushButtonSSE->setObjectName("pushButtonSSE");

        horizontalLayout_15->addWidget(pushButtonSSE);


        gridLayout_20->addLayout(horizontalLayout_15, 14, 0, 1, 1);

        gridLayout_5 = new QGridLayout();
        gridLayout_5->setObjectName("gridLayout_5");
        gridLayout_5->setContentsMargins(-1, -1, -1, 5);
        planetScalePlanetsCheckBox = new QCheckBox(planetsGroupBox);
        planetScalePlanetsCheckBox->setObjectName("planetScalePlanetsCheckBox");

        gridLayout_5->addWidget(planetScalePlanetsCheckBox, 1, 2, 1, 1);

        planetScaleMinorBodyCheckBox = new QCheckBox(planetsGroupBox);
        planetScaleMinorBodyCheckBox->setObjectName("planetScaleMinorBodyCheckBox");

        gridLayout_5->addWidget(planetScaleMinorBodyCheckBox, 1, 4, 1, 1);

        minorBodyScaleFactor = new QDoubleSpinBox(planetsGroupBox);
        minorBodyScaleFactor->setObjectName("minorBodyScaleFactor");
        minorBodyScaleFactor->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        minorBodyScaleFactor->setSuffix(QString::fromUtf8("x"));
        minorBodyScaleFactor->setDecimals(2);
        minorBodyScaleFactor->setMinimum(1.000000000000000);
        minorBodyScaleFactor->setMaximum(1000.000000000000000);
        minorBodyScaleFactor->setSingleStep(0.500000000000000);

        gridLayout_5->addWidget(minorBodyScaleFactor, 1, 5, 1, 1);

        moonScaleFactor = new QDoubleSpinBox(planetsGroupBox);
        moonScaleFactor->setObjectName("moonScaleFactor");
        moonScaleFactor->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        moonScaleFactor->setSuffix(QString::fromUtf8("x"));
        moonScaleFactor->setDecimals(2);
        moonScaleFactor->setMinimum(1.000000000000000);
        moonScaleFactor->setMaximum(100.000000000000000);
        moonScaleFactor->setSingleStep(0.100000000000000);
        moonScaleFactor->setValue(4.000000000000000);

        gridLayout_5->addWidget(moonScaleFactor, 0, 3, 1, 1);

        sunScaleFactor = new QDoubleSpinBox(planetsGroupBox);
        sunScaleFactor->setObjectName("sunScaleFactor");
        sunScaleFactor->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        sunScaleFactor->setSuffix(QString::fromUtf8("x"));
        sunScaleFactor->setMinimum(1.000000000000000);
        sunScaleFactor->setMaximum(100.000000000000000);
        sunScaleFactor->setSingleStep(0.500000000000000);

        gridLayout_5->addWidget(sunScaleFactor, 0, 5, 1, 1);

        planetScaleSunCheckBox = new QCheckBox(planetsGroupBox);
        planetScaleSunCheckBox->setObjectName("planetScaleSunCheckBox");

        gridLayout_5->addWidget(planetScaleSunCheckBox, 0, 4, 1, 1);

        planetScaleFactor = new QDoubleSpinBox(planetsGroupBox);
        planetScaleFactor->setObjectName("planetScaleFactor");
        planetScaleFactor->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        planetScaleFactor->setSuffix(QString::fromUtf8("x"));
        planetScaleFactor->setDecimals(2);
        planetScaleFactor->setMinimum(1.000000000000000);
        planetScaleFactor->setMaximum(500.000000000000000);

        gridLayout_5->addWidget(planetScaleFactor, 1, 3, 1, 1);

        labelScale = new QLabel(planetsGroupBox);
        labelScale->setObjectName("labelScale");

        gridLayout_5->addWidget(labelScale, 0, 0, 1, 1);

        planetScaleMoonCheckBox = new QCheckBox(planetsGroupBox);
        planetScaleMoonCheckBox->setObjectName("planetScaleMoonCheckBox");

        gridLayout_5->addWidget(planetScaleMoonCheckBox, 0, 2, 1, 1);

        moonScaleDynamicCheckBox = new QCheckBox(planetsGroupBox);
        moonScaleDynamicCheckBox->setObjectName("moonScaleDynamicCheckBox");

        gridLayout_5->addWidget(moonScaleDynamicCheckBox, 2, 2, 1, 2);

        moonScaleMinFovLabel = new QLabel(planetsGroupBox);
        moonScaleMinFovLabel->setObjectName("moonScaleMinFovLabel");

        gridLayout_5->addWidget(moonScaleMinFovLabel, 3, 2, 1, 1);

        moonScaleMinFovSpinBox = new QDoubleSpinBox(planetsGroupBox);
        moonScaleMinFovSpinBox->setObjectName("moonScaleMinFovSpinBox");
        moonScaleMinFovSpinBox->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        moonScaleMinFovSpinBox->setSuffix(QString::fromUtf8("\302\260"));
        moonScaleMinFovSpinBox->setDecimals(1);
        moonScaleMinFovSpinBox->setMinimum(0.500000000000000);
        moonScaleMinFovSpinBox->setMaximum(89.000000000000000);
        moonScaleMinFovSpinBox->setSingleStep(1.000000000000000);
        moonScaleMinFovSpinBox->setValue(10.000000000000000);

        gridLayout_5->addWidget(moonScaleMinFovSpinBox, 3, 3, 1, 1);

        moonScaleMaxFovLabel = new QLabel(planetsGroupBox);
        moonScaleMaxFovLabel->setObjectName("moonScaleMaxFovLabel");

        gridLayout_5->addWidget(moonScaleMaxFovLabel, 3, 4, 1, 1);

        moonScaleMaxFovSpinBox = new QDoubleSpinBox(planetsGroupBox);
        moonScaleMaxFovSpinBox->setObjectName("moonScaleMaxFovSpinBox");
        moonScaleMaxFovSpinBox->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        moonScaleMaxFovSpinBox->setSuffix(QString::fromUtf8("\302\260"));
        moonScaleMaxFovSpinBox->setDecimals(1);
        moonScaleMaxFovSpinBox->setMinimum(1.000000000000000);
        moonScaleMaxFovSpinBox->setMaximum(180.000000000000000);
        moonScaleMaxFovSpinBox->setSingleStep(1.000000000000000);
        moonScaleMaxFovSpinBox->setValue(90.000000000000000);

        gridLayout_5->addWidget(moonScaleMaxFovSpinBox, 3, 5, 1, 1);

        horizontalSpacer_17 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_5->addItem(horizontalSpacer_17, 0, 1, 1, 1);


        gridLayout_20->addLayout(gridLayout_5, 10, 1, 1, 1);

        verticalLayout_2 = new QVBoxLayout();
        verticalLayout_2->setObjectName("verticalLayout_2");
        verticalLayout_2->setContentsMargins(22, -1, -1, -1);
        hidePlanetNomenclatureCheckBox = new QCheckBox(planetsGroupBox);
        hidePlanetNomenclatureCheckBox->setObjectName("hidePlanetNomenclatureCheckBox");

        verticalLayout_2->addWidget(hidePlanetNomenclatureCheckBox);

        terminatorHorizontalLayout = new QHBoxLayout();
        terminatorHorizontalLayout->setObjectName("terminatorHorizontalLayout");
        showTerminatorNomenclatureOnlyCheckBox = new QCheckBox(planetsGroupBox);
        showTerminatorNomenclatureOnlyCheckBox->setObjectName("showTerminatorNomenclatureOnlyCheckBox");

        terminatorHorizontalLayout->addWidget(showTerminatorNomenclatureOnlyCheckBox);

        terminatorMinAltSpinbox = new QSpinBox(planetsGroupBox);
        terminatorMinAltSpinbox->setObjectName("terminatorMinAltSpinbox");
        terminatorMinAltSpinbox->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        terminatorMinAltSpinbox->setMinimum(-90);
        terminatorMinAltSpinbox->setMaximum(20);

        terminatorHorizontalLayout->addWidget(terminatorMinAltSpinbox);

        labelTerminator = new QLabel(planetsGroupBox);
        labelTerminator->setObjectName("labelTerminator");

        terminatorHorizontalLayout->addWidget(labelTerminator);

        terminatorMaxAltSpinbox = new QSpinBox(planetsGroupBox);
        terminatorMaxAltSpinbox->setObjectName("terminatorMaxAltSpinbox");
        terminatorMaxAltSpinbox->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        terminatorMaxAltSpinbox->setMaximum(90);

        terminatorHorizontalLayout->addWidget(terminatorMaxAltSpinbox);

        horizontalSpacer_6 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        terminatorHorizontalLayout->addItem(horizontalSpacer_6);


        verticalLayout_2->addLayout(terminatorHorizontalLayout);

        horizontalLayout_Nomenclature = new QHBoxLayout();
        horizontalLayout_Nomenclature->setObjectName("horizontalLayout_Nomenclature");
        outlineCratersCheckBox = new QCheckBox(planetsGroupBox);
        outlineCratersCheckBox->setObjectName("outlineCratersCheckBox");

        horizontalLayout_Nomenclature->addWidget(outlineCratersCheckBox);

        showSpecialNomenclatureOnlyCheckBox = new QCheckBox(planetsGroupBox);
        showSpecialNomenclatureOnlyCheckBox->setObjectName("showSpecialNomenclatureOnlyCheckBox");

        horizontalLayout_Nomenclature->addWidget(showSpecialNomenclatureOnlyCheckBox);


        verticalLayout_2->addLayout(horizontalLayout_Nomenclature);


        gridLayout_20->addLayout(verticalLayout_2, 3, 0, 1, 1);

        horizontalLayoutSelfShadowing = new QHBoxLayout();
        horizontalLayoutSelfShadowing->setObjectName("horizontalLayoutSelfShadowing");
        horizontalLayoutSelfShadowing->setContentsMargins(22, -1, -1, -1);
        planetShowObjSelfShadowsCheckBox = new QCheckBox(planetsGroupBox);
        planetShowObjSelfShadowsCheckBox->setObjectName("planetShowObjSelfShadowsCheckBox");

        horizontalLayoutSelfShadowing->addWidget(planetShowObjSelfShadowsCheckBox);


        gridLayout_20->addLayout(horizontalLayoutSelfShadowing, 1, 0, 1, 1);

        verticalLayout_3 = new QVBoxLayout();
        verticalLayout_3->setObjectName("verticalLayout_3");
        verticalLayout_3->setContentsMargins(22, 0, -1, -1);
        planetMagnitudeAlgorithmDescription = new QLabel(planetsGroupBox);
        planetMagnitudeAlgorithmDescription->setObjectName("planetMagnitudeAlgorithmDescription");
        planetMagnitudeAlgorithmDescription->setText(QString::fromUtf8("Description of algorithm"));
        planetMagnitudeAlgorithmDescription->setTextFormat(Qt::RichText);
        planetMagnitudeAlgorithmDescription->setWordWrap(true);

        verticalLayout_3->addWidget(planetMagnitudeAlgorithmDescription);


        gridLayout_20->addLayout(verticalLayout_3, 13, 1, 1, 1);


        gridLayout_22->addWidget(planetsGroupBox, 3, 0, 1, 1);

        stackedWidget->addWidget(page_SS);
        page_DSO = new QWidget();
        page_DSO->setObjectName("page_DSO");
        gridLayout_11 = new QGridLayout(page_DSO);
        gridLayout_11->setSpacing(0);
        gridLayout_11->setObjectName("gridLayout_11");
        gridLayout_11->setContentsMargins(0, 0, 0, 0);
        groupDSOCatalogs = new QGroupBox(page_DSO);
        groupDSOCatalogs->setObjectName("groupDSOCatalogs");
        gridLayout_10 = new QGridLayout(groupDSOCatalogs);
        gridLayout_10->setSpacing(6);
        gridLayout_10->setObjectName("gridLayout_10");
        gridLayout_10->setContentsMargins(0, 0, 0, 0);
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        label = new QLabel(groupDSOCatalogs);
        label->setObjectName("label");
        QSizePolicy sizePolicy6(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Preferred);
        sizePolicy6.setHorizontalStretch(0);
        sizePolicy6.setVerticalStretch(0);
        sizePolicy6.setHeightForWidth(label->sizePolicy().hasHeightForWidth());
        label->setSizePolicy(sizePolicy6);
        label->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        horizontalLayout->addWidget(label);

        selectAllCatalogs = new QPushButton(groupDSOCatalogs);
        selectAllCatalogs->setObjectName("selectAllCatalogs");

        horizontalLayout->addWidget(selectAllCatalogs);

        selectStandardCatalogs = new QPushButton(groupDSOCatalogs);
        selectStandardCatalogs->setObjectName("selectStandardCatalogs");

        horizontalLayout->addWidget(selectStandardCatalogs);

        selectPreferredCatalogs = new QPushButton(groupDSOCatalogs);
        selectPreferredCatalogs->setObjectName("selectPreferredCatalogs");

        horizontalLayout->addWidget(selectPreferredCatalogs);

        storePreferredCatalogs = new QPushButton(groupDSOCatalogs);
        storePreferredCatalogs->setObjectName("storePreferredCatalogs");

        horizontalLayout->addWidget(storePreferredCatalogs);

        selectNoneCatalogs = new QPushButton(groupDSOCatalogs);
        selectNoneCatalogs->setObjectName("selectNoneCatalogs");

        horizontalLayout->addWidget(selectNoneCatalogs);


        gridLayout_10->addLayout(horizontalLayout, 4, 0, 1, 10);

        checkBoxArp = new QCheckBox(groupDSOCatalogs);
        buttonGroupDisplayedDSOCatalogs = new QButtonGroup(viewDialogForm);
        buttonGroupDisplayedDSOCatalogs->setObjectName("buttonGroupDisplayedDSOCatalogs");
        buttonGroupDisplayedDSOCatalogs->setExclusive(false);
        buttonGroupDisplayedDSOCatalogs->addButton(checkBoxArp);
        checkBoxArp->setObjectName("checkBoxArp");
        checkBoxArp->setText(QString::fromUtf8("Arp"));

        gridLayout_10->addWidget(checkBoxArp, 0, 5, 1, 1);

        checkBoxUGC = new QCheckBox(groupDSOCatalogs);
        buttonGroupDisplayedDSOCatalogs->addButton(checkBoxUGC);
        checkBoxUGC->setObjectName("checkBoxUGC");
        checkBoxUGC->setText(QString::fromUtf8("UGC"));

        gridLayout_10->addWidget(checkBoxUGC, 1, 4, 1, 1);

        checkBoxLBN = new QCheckBox(groupDSOCatalogs);
        buttonGroupDisplayedDSOCatalogs->addButton(checkBoxLBN);
        checkBoxLBN->setObjectName("checkBoxLBN");
        checkBoxLBN->setText(QString::fromUtf8("LBN"));

        gridLayout_10->addWidget(checkBoxLBN, 2, 2, 1, 1);

        checkBoxRCW = new QCheckBox(groupDSOCatalogs);
        buttonGroupDisplayedDSOCatalogs->addButton(checkBoxRCW);
        checkBoxRCW->setObjectName("checkBoxRCW");
        checkBoxRCW->setText(QString::fromUtf8("RCW"));

        gridLayout_10->addWidget(checkBoxRCW, 1, 2, 1, 1);

        checkBoxSh2 = new QCheckBox(groupDSOCatalogs);
        buttonGroupDisplayedDSOCatalogs->addButton(checkBoxSh2);
        checkBoxSh2->setObjectName("checkBoxSh2");
        checkBoxSh2->setText(QString::fromUtf8("SH 2"));

        gridLayout_10->addWidget(checkBoxSh2, 2, 1, 1, 1);

        checkBoxNGC = new QCheckBox(groupDSOCatalogs);
        buttonGroupDisplayedDSOCatalogs->addButton(checkBoxNGC);
        checkBoxNGC->setObjectName("checkBoxNGC");
        checkBoxNGC->setText(QString::fromUtf8("NGC"));

        gridLayout_10->addWidget(checkBoxNGC, 2, 0, 1, 1);

        checkBoxSt = new QCheckBox(groupDSOCatalogs);
        buttonGroupDisplayedDSOCatalogs->addButton(checkBoxSt);
        checkBoxSt->setObjectName("checkBoxSt");
        checkBoxSt->setText(QString::fromUtf8("St"));

        gridLayout_10->addWidget(checkBoxSt, 2, 8, 1, 1);

        checkBoxRu = new QCheckBox(groupDSOCatalogs);
        buttonGroupDisplayedDSOCatalogs->addButton(checkBoxRu);
        checkBoxRu->setObjectName("checkBoxRu");
        checkBoxRu->setText(QString::fromUtf8("Ru"));

        gridLayout_10->addWidget(checkBoxRu, 0, 9, 1, 1);

        checkBoxACO = new QCheckBox(groupDSOCatalogs);
        buttonGroupDisplayedDSOCatalogs->addButton(checkBoxACO);
        checkBoxACO->setObjectName("checkBoxACO");
        checkBoxACO->setText(QString::fromUtf8("Abell (ACO)"));

        gridLayout_10->addWidget(checkBoxACO, 2, 6, 1, 1);

        checkBoxMel = new QCheckBox(groupDSOCatalogs);
        buttonGroupDisplayedDSOCatalogs->addButton(checkBoxMel);
        checkBoxMel->setObjectName("checkBoxMel");
        checkBoxMel->setText(QString::fromUtf8("Mel"));

        gridLayout_10->addWidget(checkBoxMel, 2, 3, 1, 1);

        checkBoxVV = new QCheckBox(groupDSOCatalogs);
        buttonGroupDisplayedDSOCatalogs->addButton(checkBoxVV);
        checkBoxVV->setObjectName("checkBoxVV");
        checkBoxVV->setText(QString::fromUtf8("VV"));

        gridLayout_10->addWidget(checkBoxVV, 1, 5, 1, 1);

        checkBoxVdB = new QCheckBox(groupDSOCatalogs);
        buttonGroupDisplayedDSOCatalogs->addButton(checkBoxVdB);
        checkBoxVdB->setObjectName("checkBoxVdB");
        checkBoxVdB->setText(QString::fromUtf8("vdB"));

        gridLayout_10->addWidget(checkBoxVdB, 0, 2, 1, 1);

        checkBoxPK = new QCheckBox(groupDSOCatalogs);
        buttonGroupDisplayedDSOCatalogs->addButton(checkBoxPK);
        checkBoxPK->setObjectName("checkBoxPK");
        checkBoxPK->setText(QString::fromUtf8("PK"));

        gridLayout_10->addWidget(checkBoxPK, 2, 5, 1, 1);

        checkBoxCr = new QCheckBox(groupDSOCatalogs);
        buttonGroupDisplayedDSOCatalogs->addButton(checkBoxCr);
        checkBoxCr->setObjectName("checkBoxCr");
        checkBoxCr->setText(QString::fromUtf8("Cr"));

        gridLayout_10->addWidget(checkBoxCr, 1, 3, 1, 1);

        checkBoxVdBH = new QCheckBox(groupDSOCatalogs);
        buttonGroupDisplayedDSOCatalogs->addButton(checkBoxVdBH);
        checkBoxVdBH->setObjectName("checkBoxVdBH");
        checkBoxVdBH->setText(QString::fromUtf8("vdBH"));

        gridLayout_10->addWidget(checkBoxVdBH, 1, 7, 1, 1);

        checkBoxHCG = new QCheckBox(groupDSOCatalogs);
        buttonGroupDisplayedDSOCatalogs->addButton(checkBoxHCG);
        checkBoxHCG->setObjectName("checkBoxHCG");
        checkBoxHCG->setText(QString::fromUtf8("HCG"));

        gridLayout_10->addWidget(checkBoxHCG, 0, 7, 1, 1);

        checkBoxPNG = new QCheckBox(groupDSOCatalogs);
        buttonGroupDisplayedDSOCatalogs->addButton(checkBoxPNG);
        checkBoxPNG->setObjectName("checkBoxPNG");
        checkBoxPNG->setText(QString::fromUtf8("PN G"));

        gridLayout_10->addWidget(checkBoxPNG, 0, 6, 1, 1);

        checkBoxDWB = new QCheckBox(groupDSOCatalogs);
        buttonGroupDisplayedDSOCatalogs->addButton(checkBoxDWB);
        checkBoxDWB->setObjectName("checkBoxDWB");
        checkBoxDWB->setText(QString::fromUtf8("DWB"));

        gridLayout_10->addWidget(checkBoxDWB, 0, 8, 1, 1);

        checkBoxESO = new QCheckBox(groupDSOCatalogs);
        buttonGroupDisplayedDSOCatalogs->addButton(checkBoxESO);
        checkBoxESO->setObjectName("checkBoxESO");
        checkBoxESO->setText(QString::fromUtf8("ESO"));

        gridLayout_10->addWidget(checkBoxESO, 2, 7, 1, 1);

        checkBoxSNRG = new QCheckBox(groupDSOCatalogs);
        buttonGroupDisplayedDSOCatalogs->addButton(checkBoxSNRG);
        checkBoxSNRG->setObjectName("checkBoxSNRG");
        checkBoxSNRG->setText(QString::fromUtf8("SNR G"));

        gridLayout_10->addWidget(checkBoxSNRG, 1, 6, 1, 1);

        checkBoxLDN = new QCheckBox(groupDSOCatalogs);
        buttonGroupDisplayedDSOCatalogs->addButton(checkBoxLDN);
        checkBoxLDN->setObjectName("checkBoxLDN");
        checkBoxLDN->setText(QString::fromUtf8("LDN"));

        gridLayout_10->addWidget(checkBoxLDN, 0, 3, 1, 1);

        checkBoxB = new QCheckBox(groupDSOCatalogs);
        buttonGroupDisplayedDSOCatalogs->addButton(checkBoxB);
        checkBoxB->setObjectName("checkBoxB");
        checkBoxB->setText(QString::fromUtf8("B"));

        gridLayout_10->addWidget(checkBoxB, 1, 1, 1, 1);

        checkBoxIC = new QCheckBox(groupDSOCatalogs);
        buttonGroupDisplayedDSOCatalogs->addButton(checkBoxIC);
        checkBoxIC->setObjectName("checkBoxIC");
        checkBoxIC->setText(QString::fromUtf8("IC"));

        gridLayout_10->addWidget(checkBoxIC, 0, 1, 1, 1);

        checkBoxOther = new QCheckBox(groupDSOCatalogs);
        buttonGroupDisplayedDSOCatalogs->addButton(checkBoxOther);
        checkBoxOther->setObjectName("checkBoxOther");

        gridLayout_10->addWidget(checkBoxOther, 2, 9, 1, 1);

        checkBoxPGC = new QCheckBox(groupDSOCatalogs);
        buttonGroupDisplayedDSOCatalogs->addButton(checkBoxPGC);
        checkBoxPGC->setObjectName("checkBoxPGC");
        checkBoxPGC->setText(QString::fromUtf8("PGC"));

        gridLayout_10->addWidget(checkBoxPGC, 0, 4, 1, 1);

        checkBoxCed = new QCheckBox(groupDSOCatalogs);
        buttonGroupDisplayedDSOCatalogs->addButton(checkBoxCed);
        checkBoxCed->setObjectName("checkBoxCed");
        checkBoxCed->setText(QString::fromUtf8("Ced"));

        gridLayout_10->addWidget(checkBoxCed, 2, 4, 1, 1);

        checkBoxVdBHa = new QCheckBox(groupDSOCatalogs);
        buttonGroupDisplayedDSOCatalogs->addButton(checkBoxVdBHa);
        checkBoxVdBHa->setObjectName("checkBoxVdBHa");
        checkBoxVdBHa->setText(QString::fromUtf8("vdB-Ha"));

        gridLayout_10->addWidget(checkBoxVdBHa, 1, 9, 1, 1);

        checkBoxM = new QCheckBox(groupDSOCatalogs);
        buttonGroupDisplayedDSOCatalogs->addButton(checkBoxM);
        checkBoxM->setObjectName("checkBoxM");
        checkBoxM->setText(QString::fromUtf8("M"));

        gridLayout_10->addWidget(checkBoxM, 0, 0, 1, 1);

        checkBoxTr = new QCheckBox(groupDSOCatalogs);
        buttonGroupDisplayedDSOCatalogs->addButton(checkBoxTr);
        checkBoxTr->setObjectName("checkBoxTr");
        checkBoxTr->setText(QString::fromUtf8("Tr"));

        gridLayout_10->addWidget(checkBoxTr, 1, 8, 1, 1);

        checkBoxC = new QCheckBox(groupDSOCatalogs);
        buttonGroupDisplayedDSOCatalogs->addButton(checkBoxC);
        checkBoxC->setObjectName("checkBoxC");
        checkBoxC->setText(QString::fromUtf8("C"));

        gridLayout_10->addWidget(checkBoxC, 1, 0, 1, 1);

        line = new QFrame(groupDSOCatalogs);
        line->setObjectName("line");
        QSizePolicy sizePolicy7(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);
        sizePolicy7.setHorizontalStretch(0);
        sizePolicy7.setVerticalStretch(0);
        sizePolicy7.setHeightForWidth(line->sizePolicy().hasHeightForWidth());
        line->setSizePolicy(sizePolicy7);
        line->setMinimumSize(QSize(0, 1));
        line->setMaximumSize(QSize(16777215, 1));
        line->setFrameShape(QFrame::Shape::HLine);
        line->setFrameShadow(QFrame::Shadow::Sunken);

        gridLayout_10->addWidget(line, 3, 0, 1, 10);


        gridLayout_11->addWidget(groupDSOCatalogs, 0, 0, 1, 2);

        verticalSpacer_3 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_11->addItem(verticalSpacer_3, 3, 0, 1, 1);

        groupBoxDSOTypeFilters = new QGroupBox(page_DSO);
        groupBoxDSOTypeFilters->setObjectName("groupBoxDSOTypeFilters");
        groupBoxDSOTypeFilters->setFlat(true);
        groupBoxDSOTypeFilters->setCheckable(true);
        groupBoxDSOTypeFilters->setChecked(false);
        gridLayout_13 = new QGridLayout(groupBoxDSOTypeFilters);
        gridLayout_13->setSpacing(6);
        gridLayout_13->setObjectName("gridLayout_13");
        gridLayout_13->setContentsMargins(0, 0, 0, 0);
        checkBoxActiveGalaxiesType = new QCheckBox(groupBoxDSOTypeFilters);
        buttonGroupDisplayedDSOTypes = new QButtonGroup(viewDialogForm);
        buttonGroupDisplayedDSOTypes->setObjectName("buttonGroupDisplayedDSOTypes");
        buttonGroupDisplayedDSOTypes->setExclusive(false);
        buttonGroupDisplayedDSOTypes->addButton(checkBoxActiveGalaxiesType);
        checkBoxActiveGalaxiesType->setObjectName("checkBoxActiveGalaxiesType");

        gridLayout_13->addWidget(checkBoxActiveGalaxiesType, 3, 0, 1, 1);

        checkBoxPlanetaryNebulaeType = new QCheckBox(groupBoxDSOTypeFilters);
        buttonGroupDisplayedDSOTypes->addButton(checkBoxPlanetaryNebulaeType);
        checkBoxPlanetaryNebulaeType->setObjectName("checkBoxPlanetaryNebulaeType");

        gridLayout_13->addWidget(checkBoxPlanetaryNebulaeType, 4, 1, 1, 1);

        checkBoxBrightNebulaeType = new QCheckBox(groupBoxDSOTypeFilters);
        buttonGroupDisplayedDSOTypes->addButton(checkBoxBrightNebulaeType);
        checkBoxBrightNebulaeType->setObjectName("checkBoxBrightNebulaeType");

        gridLayout_13->addWidget(checkBoxBrightNebulaeType, 1, 1, 1, 1);

        checkBoxDarkNebulaeType = new QCheckBox(groupBoxDSOTypeFilters);
        buttonGroupDisplayedDSOTypes->addButton(checkBoxDarkNebulaeType);
        checkBoxDarkNebulaeType->setObjectName("checkBoxDarkNebulaeType");

        gridLayout_13->addWidget(checkBoxDarkNebulaeType, 3, 1, 1, 1);

        checkBoxHydrogenRegionsType = new QCheckBox(groupBoxDSOTypeFilters);
        buttonGroupDisplayedDSOTypes->addButton(checkBoxHydrogenRegionsType);
        checkBoxHydrogenRegionsType->setObjectName("checkBoxHydrogenRegionsType");

        gridLayout_13->addWidget(checkBoxHydrogenRegionsType, 6, 1, 1, 1);

        checkBoxGalaxyClustersType = new QCheckBox(groupBoxDSOTypeFilters);
        buttonGroupDisplayedDSOTypes->addButton(checkBoxGalaxyClustersType);
        checkBoxGalaxyClustersType->setObjectName("checkBoxGalaxyClustersType");

        gridLayout_13->addWidget(checkBoxGalaxyClustersType, 5, 0, 1, 1);

        checkBoxGalaxiesType = new QCheckBox(groupBoxDSOTypeFilters);
        buttonGroupDisplayedDSOTypes->addButton(checkBoxGalaxiesType);
        checkBoxGalaxiesType->setObjectName("checkBoxGalaxiesType");

        gridLayout_13->addWidget(checkBoxGalaxiesType, 1, 0, 1, 1);

        checkBoxInteractingGalaxiesType = new QCheckBox(groupBoxDSOTypeFilters);
        buttonGroupDisplayedDSOTypes->addButton(checkBoxInteractingGalaxiesType);
        checkBoxInteractingGalaxiesType->setObjectName("checkBoxInteractingGalaxiesType");

        gridLayout_13->addWidget(checkBoxInteractingGalaxiesType, 4, 0, 1, 1);

        checkBoxSupernovaRemnantsType = new QCheckBox(groupBoxDSOTypeFilters);
        buttonGroupDisplayedDSOTypes->addButton(checkBoxSupernovaRemnantsType);
        checkBoxSupernovaRemnantsType->setObjectName("checkBoxSupernovaRemnantsType");

        gridLayout_13->addWidget(checkBoxSupernovaRemnantsType, 5, 1, 1, 1);

        checkBoxOpenStarClustersType = new QCheckBox(groupBoxDSOTypeFilters);
        buttonGroupDisplayedDSOTypes->addButton(checkBoxOpenStarClustersType);
        checkBoxOpenStarClustersType->setObjectName("checkBoxOpenStarClustersType");

        gridLayout_13->addWidget(checkBoxOpenStarClustersType, 6, 0, 1, 1);

        verticalSpacer_7 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_13->addItem(verticalSpacer_7, 8, 0, 1, 1);

        checkBoxOtherType = new QCheckBox(groupBoxDSOTypeFilters);
        buttonGroupDisplayedDSOTypes->addButton(checkBoxOtherType);
        checkBoxOtherType->setObjectName("checkBoxOtherType");

        gridLayout_13->addWidget(checkBoxOtherType, 7, 1, 1, 1);

        checkBoxGlobularStarClustersType = new QCheckBox(groupBoxDSOTypeFilters);
        buttonGroupDisplayedDSOTypes->addButton(checkBoxGlobularStarClustersType);
        checkBoxGlobularStarClustersType->setObjectName("checkBoxGlobularStarClustersType");

        gridLayout_13->addWidget(checkBoxGlobularStarClustersType, 7, 0, 1, 1);


        gridLayout_11->addWidget(groupBoxDSOTypeFilters, 1, 0, 1, 1);

        verticalLayout_4 = new QVBoxLayout();
        verticalLayout_4->setObjectName("verticalLayout_4");
        groupBoxDSOLabelsAndMarkers = new QGroupBox(page_DSO);
        groupBoxDSOLabelsAndMarkers->setObjectName("groupBoxDSOLabelsAndMarkers");
        groupBoxDSOLabelsAndMarkers->setFlat(true);
        groupBoxDSOLabelsAndMarkers->setCheckable(true);
        groupBoxDSOLabelsAndMarkers->setChecked(false);
        gridLayout_12 = new QGridLayout(groupBoxDSOLabelsAndMarkers);
        gridLayout_12->setSpacing(6);
        gridLayout_12->setObjectName("gridLayout_12");
        gridLayout_12->setContentsMargins(0, 0, 0, 0);
        checkBoxDesignationsOnlyUsage = new QCheckBox(groupBoxDSOLabelsAndMarkers);
        checkBoxDesignationsOnlyUsage->setObjectName("checkBoxDesignationsOnlyUsage");

        gridLayout_12->addWidget(checkBoxDesignationsOnlyUsage, 3, 0, 1, 1);

        checkBoxAdditionalNamesDSO = new QCheckBox(groupBoxDSOLabelsAndMarkers);
        checkBoxAdditionalNamesDSO->setObjectName("checkBoxAdditionalNamesDSO");

        gridLayout_12->addWidget(checkBoxAdditionalNamesDSO, 7, 0, 1, 1);

        checkBoxShowOnlyNamedDSO = new QCheckBox(groupBoxDSOLabelsAndMarkers);
        checkBoxShowOnlyNamedDSO->setObjectName("checkBoxShowOnlyNamedDSO");

        gridLayout_12->addWidget(checkBoxShowOnlyNamedDSO, 8, 0, 1, 1);

        checkBoxOutlines = new QCheckBox(groupBoxDSOLabelsAndMarkers);
        checkBoxOutlines->setObjectName("checkBoxOutlines");

        gridLayout_12->addWidget(checkBoxOutlines, 4, 0, 1, 1);

        checkBoxProportionalHints = new QCheckBox(groupBoxDSOLabelsAndMarkers);
        checkBoxProportionalHints->setObjectName("checkBoxProportionalHints");

        gridLayout_12->addWidget(checkBoxProportionalHints, 5, 0, 1, 1);

        gridLayout_15 = new QGridLayout();
        gridLayout_15->setObjectName("gridLayout_15");
        nebulasLabelsHorizontalSlider = new QSlider(groupBoxDSOLabelsAndMarkers);
        nebulasLabelsHorizontalSlider->setObjectName("nebulasLabelsHorizontalSlider");
        nebulasLabelsHorizontalSlider->setValue(33);
        nebulasLabelsHorizontalSlider->setOrientation(Qt::Horizontal);

        gridLayout_15->addWidget(nebulasLabelsHorizontalSlider, 0, 1, 1, 1);

        labelLabels = new QLabel(groupBoxDSOLabelsAndMarkers);
        labelLabels->setObjectName("labelLabels");

        gridLayout_15->addWidget(labelLabels, 0, 0, 1, 1);

        labelsBrightnessDoubleSpinBox = new QDoubleSpinBox(groupBoxDSOLabelsAndMarkers);
        labelsBrightnessDoubleSpinBox->setObjectName("labelsBrightnessDoubleSpinBox");
        labelsBrightnessDoubleSpinBox->setDecimals(1);
        labelsBrightnessDoubleSpinBox->setMaximum(1.000000000000000);
        labelsBrightnessDoubleSpinBox->setSingleStep(0.100000000000000);
        labelsBrightnessDoubleSpinBox->setValue(1.000000000000000);

        gridLayout_15->addWidget(labelsBrightnessDoubleSpinBox, 0, 2, 1, 1);

        hintsBrightnessDoubleSpinBox = new QDoubleSpinBox(groupBoxDSOLabelsAndMarkers);
        hintsBrightnessDoubleSpinBox->setObjectName("hintsBrightnessDoubleSpinBox");
        hintsBrightnessDoubleSpinBox->setDecimals(1);
        hintsBrightnessDoubleSpinBox->setMaximum(1.000000000000000);
        hintsBrightnessDoubleSpinBox->setSingleStep(0.100000000000000);
        hintsBrightnessDoubleSpinBox->setValue(1.000000000000000);

        gridLayout_15->addWidget(hintsBrightnessDoubleSpinBox, 1, 2, 1, 1);

        labelHints = new QLabel(groupBoxDSOLabelsAndMarkers);
        labelHints->setObjectName("labelHints");

        gridLayout_15->addWidget(labelHints, 1, 0, 1, 1);

        nebulasHintsHorizontalSlider = new QSlider(groupBoxDSOLabelsAndMarkers);
        nebulasHintsHorizontalSlider->setObjectName("nebulasHintsHorizontalSlider");
        nebulasHintsHorizontalSlider->setValue(33);
        nebulasHintsHorizontalSlider->setOrientation(Qt::Horizontal);

        gridLayout_15->addWidget(nebulasHintsHorizontalSlider, 1, 1, 1, 1);


        gridLayout_12->addLayout(gridLayout_15, 2, 0, 1, 1);

        checkBoxSurfaceBrightnessUsage = new QCheckBox(groupBoxDSOLabelsAndMarkers);
        checkBoxSurfaceBrightnessUsage->setObjectName("checkBoxSurfaceBrightnessUsage");

        gridLayout_12->addWidget(checkBoxSurfaceBrightnessUsage, 6, 0, 1, 1);

        pushButtonConfigureDSOColors = new QPushButton(groupBoxDSOLabelsAndMarkers);
        pushButtonConfigureDSOColors->setObjectName("pushButtonConfigureDSOColors");

        gridLayout_12->addWidget(pushButtonConfigureDSOColors, 10, 0, 1, 1);

        gridLayout_17 = new QGridLayout();
        gridLayout_17->setObjectName("gridLayout_17");
        nebulaLimitSizeCheckBox = new QCheckBox(groupBoxDSOLabelsAndMarkers);
        nebulaLimitSizeCheckBox->setObjectName("nebulaLimitSizeCheckBox");
        sizePolicy2.setHeightForWidth(nebulaLimitSizeCheckBox->sizePolicy().hasHeightForWidth());
        nebulaLimitSizeCheckBox->setSizePolicy(sizePolicy2);

        gridLayout_17->addWidget(nebulaLimitSizeCheckBox, 1, 0, 1, 1);

        nebulaLimitMagnitudeDoubleSpinBox = new QDoubleSpinBox(groupBoxDSOLabelsAndMarkers);
        nebulaLimitMagnitudeDoubleSpinBox->setObjectName("nebulaLimitMagnitudeDoubleSpinBox");
        nebulaLimitMagnitudeDoubleSpinBox->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        nebulaLimitMagnitudeDoubleSpinBox->setMinimum(3.000000000000000);
        nebulaLimitMagnitudeDoubleSpinBox->setMaximum(21.000000000000000);
        nebulaLimitMagnitudeDoubleSpinBox->setSingleStep(0.250000000000000);
        nebulaLimitMagnitudeDoubleSpinBox->setValue(8.500000000000000);

        gridLayout_17->addWidget(nebulaLimitMagnitudeDoubleSpinBox, 0, 2, 1, 1);

        nebulaLimitSizeMaxDoubleSpinBox = new QDoubleSpinBox(groupBoxDSOLabelsAndMarkers);
        nebulaLimitSizeMaxDoubleSpinBox->setObjectName("nebulaLimitSizeMaxDoubleSpinBox");
        nebulaLimitSizeMaxDoubleSpinBox->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        nebulaLimitSizeMaxDoubleSpinBox->setSuffix(QString::fromUtf8("'"));
        nebulaLimitSizeMaxDoubleSpinBox->setDecimals(2);
        nebulaLimitSizeMaxDoubleSpinBox->setMinimum(0.010000000000000);
        nebulaLimitSizeMaxDoubleSpinBox->setMaximum(1200.000000000000000);

        gridLayout_17->addWidget(nebulaLimitSizeMaxDoubleSpinBox, 1, 2, 1, 1);

        nebulaLimitMagnitudeCheckBox = new QCheckBox(groupBoxDSOLabelsAndMarkers);
        nebulaLimitMagnitudeCheckBox->setObjectName("nebulaLimitMagnitudeCheckBox");
        sizePolicy2.setHeightForWidth(nebulaLimitMagnitudeCheckBox->sizePolicy().hasHeightForWidth());
        nebulaLimitMagnitudeCheckBox->setSizePolicy(sizePolicy2);

        gridLayout_17->addWidget(nebulaLimitMagnitudeCheckBox, 0, 0, 1, 1);

        nebulaLimitSizeMinDoubleSpinBox = new QDoubleSpinBox(groupBoxDSOLabelsAndMarkers);
        nebulaLimitSizeMinDoubleSpinBox->setObjectName("nebulaLimitSizeMinDoubleSpinBox");
        nebulaLimitSizeMinDoubleSpinBox->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        nebulaLimitSizeMinDoubleSpinBox->setSuffix(QString::fromUtf8("'"));
        nebulaLimitSizeMinDoubleSpinBox->setDecimals(2);
        nebulaLimitSizeMinDoubleSpinBox->setMinimum(0.010000000000000);
        nebulaLimitSizeMinDoubleSpinBox->setMaximum(600.000000000000000);

        gridLayout_17->addWidget(nebulaLimitSizeMinDoubleSpinBox, 1, 1, 1, 1);


        gridLayout_12->addLayout(gridLayout_17, 9, 0, 1, 1);


        verticalLayout_4->addWidget(groupBoxDSOLabelsAndMarkers);


        gridLayout_11->addLayout(verticalLayout_4, 1, 1, 1, 1);

        stackedWidget->addWidget(page_DSO);
        page_markings = new QWidget();
        page_markings->setObjectName("page_markings");
        gridLayout_2 = new QGridLayout(page_markings);
        gridLayout_2->setSpacing(0);
        gridLayout_2->setObjectName("gridLayout_2");
        gridLayout_2->setContentsMargins(0, 0, 0, 0);
        celestialSphereGroupBox = new QGroupBox(page_markings);
        celestialSphereGroupBox->setObjectName("celestialSphereGroupBox");
        celestialSphereGroupBox->setFlat(true);
        celestialSphereGroupBox->setCheckable(true);
        verticalLayout_10 = new QVBoxLayout(celestialSphereGroupBox);
        verticalLayout_10->setObjectName("verticalLayout_10");
        verticalLayout_10->setContentsMargins(0, 0, 0, 0);
        markingsGridLayout = new QGridLayout();
        markingsGridLayout->setObjectName("markingsGridLayout");
        showApexPointsCheckBox = new QCheckBox(celestialSphereGroupBox);
        showApexPointsCheckBox->setObjectName("showApexPointsCheckBox");

        markingsGridLayout->addWidget(showApexPointsCheckBox, 12, 1, 1, 1);

        solarEquatorPartsCheckBox = new QCheckBox(celestialSphereGroupBox);
        solarEquatorPartsCheckBox->setObjectName("solarEquatorPartsCheckBox");

        markingsGridLayout->addWidget(solarEquatorPartsCheckBox, 9, 5, 1, 1);

        currentVerticalPartsCheckBox = new QCheckBox(celestialSphereGroupBox);
        currentVerticalPartsCheckBox->setObjectName("currentVerticalPartsCheckBox");

        markingsGridLayout->addWidget(currentVerticalPartsCheckBox, 11, 5, 1, 1);

        colureLabelsCheckBox = new QCheckBox(celestialSphereGroupBox);
        colureLabelsCheckBox->setObjectName("colureLabelsCheckBox");

        markingsGridLayout->addWidget(colureLabelsCheckBox, 12, 6, 1, 1);

        colorGalacticCenter = new ColorButton(celestialSphereGroupBox);
        colorGalacticCenter->setObjectName("colorGalacticCenter");

        markingsGridLayout->addWidget(colorGalacticCenter, 13, 0, 1, 1);

        colorCircumpolarCircles = new ColorButton(celestialSphereGroupBox);
        colorCircumpolarCircles->setObjectName("colorCircumpolarCircles");
        colorCircumpolarCircles->setText(QString::fromUtf8(""));

        markingsGridLayout->addWidget(colorCircumpolarCircles, 2, 9, 1, 1);

        galacticEquatorLabel = new QLabel(celestialSphereGroupBox);
        galacticEquatorLabel->setObjectName("galacticEquatorLabel");

        markingsGridLayout->addWidget(galacticEquatorLabel, 6, 7, 1, 1);

        horizontalLayout_27 = new QHBoxLayout();
        horizontalLayout_27->setObjectName("horizontalLayout_27");
        horizontalLayout_27->setContentsMargins(-1, 0, -1, -1);
        showUmbraCheckBox = new QCheckBox(celestialSphereGroupBox);
        showUmbraCheckBox->setObjectName("showUmbraCheckBox");
        sizePolicy2.setHeightForWidth(showUmbraCheckBox->sizePolicy().hasHeightForWidth());
        showUmbraCheckBox->setSizePolicy(sizePolicy2);

        horizontalLayout_27->addWidget(showUmbraCheckBox);

        showUmbraCenterCheckBox = new QCheckBox(celestialSphereGroupBox);
        showUmbraCenterCheckBox->setObjectName("showUmbraCenterCheckBox");

        horizontalLayout_27->addWidget(showUmbraCenterCheckBox);


        markingsGridLayout->addLayout(horizontalLayout_27, 10, 10, 1, 1);

        colorSolsticePoints = new ColorButton(celestialSphereGroupBox);
        colorSolsticePoints->setObjectName("colorSolsticePoints");

        markingsGridLayout->addWidget(colorSolsticePoints, 11, 0, 1, 1);

        colorEquinoxPoints = new ColorButton(celestialSphereGroupBox);
        colorEquinoxPoints->setObjectName("colorEquinoxPoints");
        colorEquinoxPoints->setText(QString::fromUtf8(""));

        markingsGridLayout->addWidget(colorEquinoxPoints, 9, 0, 1, 1);

        colorUmbraCircle = new ColorButton(celestialSphereGroupBox);
        colorUmbraCircle->setObjectName("colorUmbraCircle");

        markingsGridLayout->addWidget(colorUmbraCircle, 10, 9, 1, 1);

        fixedEquatorLabelsCheckBox = new QCheckBox(celestialSphereGroupBox);
        fixedEquatorLabelsCheckBox->setObjectName("fixedEquatorLabelsCheckBox");

        markingsGridLayout->addWidget(fixedEquatorLabelsCheckBox, 2, 6, 1, 1);

        primeVerticalPartsCheckBox = new QCheckBox(celestialSphereGroupBox);
        primeVerticalPartsCheckBox->setObjectName("primeVerticalPartsCheckBox");

        markingsGridLayout->addWidget(primeVerticalPartsCheckBox, 14, 5, 1, 1);

        colorAntisolarPoint = new ColorButton(celestialSphereGroupBox);
        colorAntisolarPoint->setObjectName("colorAntisolarPoint");

        markingsGridLayout->addWidget(colorAntisolarPoint, 9, 9, 1, 1);

        colureLabel = new QLabel(celestialSphereGroupBox);
        colureLabel->setObjectName("colureLabel");

        markingsGridLayout->addWidget(colureLabel, 12, 7, 1, 1);

        galacticEquatorPartsCheckBox = new QCheckBox(celestialSphereGroupBox);
        galacticEquatorPartsCheckBox->setObjectName("galacticEquatorPartsCheckBox");

        markingsGridLayout->addWidget(galacticEquatorPartsCheckBox, 6, 5, 1, 1);

        solarEquatorLabelsCheckBox = new QCheckBox(celestialSphereGroupBox);
        solarEquatorLabelsCheckBox->setObjectName("solarEquatorLabelsCheckBox");

        markingsGridLayout->addWidget(solarEquatorLabelsCheckBox, 9, 6, 1, 1);

        showEquinoxJ2000PointsCheckBox = new QCheckBox(celestialSphereGroupBox);
        showEquinoxJ2000PointsCheckBox->setObjectName("showEquinoxJ2000PointsCheckBox");

        markingsGridLayout->addWidget(showEquinoxJ2000PointsCheckBox, 8, 1, 1, 1);

        showEclipticGridOfDateCheckBox = new QCheckBox(celestialSphereGroupBox);
        showEclipticGridOfDateCheckBox->setObjectName("showEclipticGridOfDateCheckBox");

        markingsGridLayout->addWidget(showEclipticGridOfDateCheckBox, 4, 1, 1, 1);

        showEquinoxPointsCheckBox = new QCheckBox(celestialSphereGroupBox);
        showEquinoxPointsCheckBox->setObjectName("showEquinoxPointsCheckBox");

        markingsGridLayout->addWidget(showEquinoxPointsCheckBox, 9, 1, 1, 1);

        colorHorizonLine = new ColorButton(celestialSphereGroupBox);
        colorHorizonLine->setObjectName("colorHorizonLine");
        colorHorizonLine->setText(QString::fromUtf8(""));

        markingsGridLayout->addWidget(colorHorizonLine, 5, 3, 1, 1);

        colurePartsCheckBox = new QCheckBox(celestialSphereGroupBox);
        colurePartsCheckBox->setObjectName("colurePartsCheckBox");

        markingsGridLayout->addWidget(colurePartsCheckBox, 12, 5, 1, 1);

        showEclipticLineOfDateCheckBox = new QCheckBox(celestialSphereGroupBox);
        showEclipticLineOfDateCheckBox->setObjectName("showEclipticLineOfDateCheckBox");

        markingsGridLayout->addWidget(showEclipticLineOfDateCheckBox, 4, 4, 1, 1);

        showEclipticPolesCheckBox = new QCheckBox(celestialSphereGroupBox);
        showEclipticPolesCheckBox->setObjectName("showEclipticPolesCheckBox");

        markingsGridLayout->addWidget(showEclipticPolesCheckBox, 4, 10, 1, 1);

        colorSupergalacticEquatorLine = new ColorButton(celestialSphereGroupBox);
        colorSupergalacticEquatorLine->setObjectName("colorSupergalacticEquatorLine");
        colorSupergalacticEquatorLine->setText(QString::fromUtf8(""));

        markingsGridLayout->addWidget(colorSupergalacticEquatorLine, 7, 3, 1, 1);

        colorGalacticGrid = new ColorButton(celestialSphereGroupBox);
        colorGalacticGrid->setObjectName("colorGalacticGrid");
        colorGalacticGrid->setText(QString::fromUtf8(""));

        markingsGridLayout->addWidget(colorGalacticGrid, 6, 0, 1, 1);

        currentVerticalLabelsCheckBox = new QCheckBox(celestialSphereGroupBox);
        currentVerticalLabelsCheckBox->setObjectName("currentVerticalLabelsCheckBox");

        markingsGridLayout->addWidget(currentVerticalLabelsCheckBox, 11, 6, 1, 1);

        showInvariablePlaneCheckBox = new QCheckBox(celestialSphereGroupBox);
        showInvariablePlaneCheckBox->setObjectName("showInvariablePlaneCheckBox");

        markingsGridLayout->addWidget(showInvariablePlaneCheckBox, 12, 10, 1, 1);

        colorSupergalacticPoles = new ColorButton(celestialSphereGroupBox);
        colorSupergalacticPoles->setObjectName("colorSupergalacticPoles");
        colorSupergalacticPoles->setText(QString::fromUtf8(""));

        markingsGridLayout->addWidget(colorSupergalacticPoles, 7, 9, 1, 1);

        precessionPartsCheckBox = new QCheckBox(celestialSphereGroupBox);
        precessionPartsCheckBox->setObjectName("precessionPartsCheckBox");
        QSizePolicy sizePolicy8(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy8.setHorizontalStretch(0);
        sizePolicy8.setVerticalStretch(0);
        sizePolicy8.setHeightForWidth(precessionPartsCheckBox->sizePolicy().hasHeightForWidth());
        precessionPartsCheckBox->setSizePolicy(sizePolicy8);

        markingsGridLayout->addWidget(precessionPartsCheckBox, 13, 5, 1, 1);

        meridianLabelsCheckBox = new QCheckBox(celestialSphereGroupBox);
        meridianLabelsCheckBox->setObjectName("meridianLabelsCheckBox");

        markingsGridLayout->addWidget(meridianLabelsCheckBox, 10, 6, 1, 1);

        showEclipticGridJ2000CheckBox = new QCheckBox(celestialSphereGroupBox);
        showEclipticGridJ2000CheckBox->setObjectName("showEclipticGridJ2000CheckBox");

        markingsGridLayout->addWidget(showEclipticGridJ2000CheckBox, 3, 1, 1, 1);

        colorPrimeVerticalLine = new ColorButton(celestialSphereGroupBox);
        colorPrimeVerticalLine->setObjectName("colorPrimeVerticalLine");
        colorPrimeVerticalLine->setText(QString::fromUtf8(""));

        markingsGridLayout->addWidget(colorPrimeVerticalLine, 14, 3, 1, 1);

        showSupergalacticPolesCheckBox = new QCheckBox(celestialSphereGroupBox);
        showSupergalacticPolesCheckBox->setObjectName("showSupergalacticPolesCheckBox");

        markingsGridLayout->addWidget(showSupergalacticPolesCheckBox, 7, 10, 1, 1);

        colorCelestialJ2000Poles = new ColorButton(celestialSphereGroupBox);
        colorCelestialJ2000Poles->setObjectName("colorCelestialJ2000Poles");
        colorCelestialJ2000Poles->setText(QString::fromUtf8(""));

        markingsGridLayout->addWidget(colorCelestialJ2000Poles, 0, 9, 1, 1);

        galacticEquatorLabelsCheckBox = new QCheckBox(celestialSphereGroupBox);
        galacticEquatorLabelsCheckBox->setObjectName("galacticEquatorLabelsCheckBox");

        markingsGridLayout->addWidget(galacticEquatorLabelsCheckBox, 6, 6, 1, 1);

        longitudePartsCheckBox = new QCheckBox(celestialSphereGroupBox);
        longitudePartsCheckBox->setObjectName("longitudePartsCheckBox");

        markingsGridLayout->addWidget(longitudePartsCheckBox, 8, 5, 1, 1);

        showZenithNadirCheckBox = new QCheckBox(celestialSphereGroupBox);
        showZenithNadirCheckBox->setObjectName("showZenithNadirCheckBox");

        markingsGridLayout->addWidget(showZenithNadirCheckBox, 5, 10, 1, 1);

        fixedEquatorPartsCheckBox = new QCheckBox(celestialSphereGroupBox);
        fixedEquatorPartsCheckBox->setObjectName("fixedEquatorPartsCheckBox");

        markingsGridLayout->addWidget(fixedEquatorPartsCheckBox, 2, 5, 1, 1);

        colorSolarEquatorLine = new ColorButton(celestialSphereGroupBox);
        colorSolarEquatorLine->setObjectName("colorSolarEquatorLine");

        markingsGridLayout->addWidget(colorSolarEquatorLine, 9, 3, 1, 1);

        showFixedEquatorialGridCheckBox = new QCheckBox(celestialSphereGroupBox);
        showFixedEquatorialGridCheckBox->setObjectName("showFixedEquatorialGridCheckBox");

        markingsGridLayout->addWidget(showFixedEquatorialGridCheckBox, 2, 1, 1, 1);

        showGalacticEquatorLineCheckBox = new QCheckBox(celestialSphereGroupBox);
        showGalacticEquatorLineCheckBox->setObjectName("showGalacticEquatorLineCheckBox");

        markingsGridLayout->addWidget(showGalacticEquatorLineCheckBox, 6, 4, 1, 1);

        colorPenumbraCircle = new ColorButton(celestialSphereGroupBox);
        colorPenumbraCircle->setObjectName("colorPenumbraCircle");

        markingsGridLayout->addWidget(colorPenumbraCircle, 11, 9, 1, 1);

        colorEclipticGridJ2000 = new ColorButton(celestialSphereGroupBox);
        colorEclipticGridJ2000->setObjectName("colorEclipticGridJ2000");
        colorEclipticGridJ2000->setText(QString::fromUtf8(""));

        markingsGridLayout->addWidget(colorEclipticGridJ2000, 3, 0, 1, 1);

        colorSupergalacticGrid = new ColorButton(celestialSphereGroupBox);
        colorSupergalacticGrid->setObjectName("colorSupergalacticGrid");
        colorSupergalacticGrid->setText(QString::fromUtf8(""));

        markingsGridLayout->addWidget(colorSupergalacticGrid, 7, 0, 1, 1);

        longitudeLabel = new QLabel(celestialSphereGroupBox);
        longitudeLabel->setObjectName("longitudeLabel");

        markingsGridLayout->addWidget(longitudeLabel, 8, 7, 1, 1);

        colorEquatorLine = new ColorButton(celestialSphereGroupBox);
        colorEquatorLine->setObjectName("colorEquatorLine");
        colorEquatorLine->setText(QString::fromUtf8(""));

        markingsGridLayout->addWidget(colorEquatorLine, 1, 3, 1, 1);

        primeVerticalLabelsCheckBox = new QCheckBox(celestialSphereGroupBox);
        primeVerticalLabelsCheckBox->setObjectName("primeVerticalLabelsCheckBox");

        markingsGridLayout->addWidget(primeVerticalLabelsCheckBox, 14, 6, 1, 1);

        equatorJ2000LabelsCheckBox = new QCheckBox(celestialSphereGroupBox);
        equatorJ2000LabelsCheckBox->setObjectName("equatorJ2000LabelsCheckBox");

        markingsGridLayout->addWidget(equatorJ2000LabelsCheckBox, 0, 6, 1, 1);

        showSupergalacticEquatorLineCheckBox = new QCheckBox(celestialSphereGroupBox);
        showSupergalacticEquatorLineCheckBox->setObjectName("showSupergalacticEquatorLineCheckBox");

        markingsGridLayout->addWidget(showSupergalacticEquatorLineCheckBox, 7, 4, 1, 1);

        equatorJ2000PartsCheckBox = new QCheckBox(celestialSphereGroupBox);
        equatorJ2000PartsCheckBox->setObjectName("equatorJ2000PartsCheckBox");

        markingsGridLayout->addWidget(equatorJ2000PartsCheckBox, 0, 5, 1, 1);

        eclipticPartsCheckBox = new QCheckBox(celestialSphereGroupBox);
        eclipticPartsCheckBox->setObjectName("eclipticPartsCheckBox");

        markingsGridLayout->addWidget(eclipticPartsCheckBox, 4, 5, 1, 1);

        colorGalacticPoles = new ColorButton(celestialSphereGroupBox);
        colorGalacticPoles->setObjectName("colorGalacticPoles");
        colorGalacticPoles->setText(QString::fromUtf8(""));

        markingsGridLayout->addWidget(colorGalacticPoles, 6, 9, 1, 1);

        showAzimuthalGridCheckBox = new QCheckBox(celestialSphereGroupBox);
        showAzimuthalGridCheckBox->setObjectName("showAzimuthalGridCheckBox");

        markingsGridLayout->addWidget(showAzimuthalGridCheckBox, 5, 1, 1, 1);

        showEquatorLineCheckBox = new QCheckBox(celestialSphereGroupBox);
        showEquatorLineCheckBox->setObjectName("showEquatorLineCheckBox");

        markingsGridLayout->addWidget(showEquatorLineCheckBox, 1, 4, 1, 1);

        supergalacticEquatorLabelsCheckBox = new QCheckBox(celestialSphereGroupBox);
        supergalacticEquatorLabelsCheckBox->setObjectName("supergalacticEquatorLabelsCheckBox");

        markingsGridLayout->addWidget(supergalacticEquatorLabelsCheckBox, 7, 6, 1, 1);

        supergalacticEquatorLabel = new QLabel(celestialSphereGroupBox);
        supergalacticEquatorLabel->setObjectName("supergalacticEquatorLabel");

        markingsGridLayout->addWidget(supergalacticEquatorLabel, 7, 7, 1, 1);

        colorEclipticLineJ2000 = new ColorButton(celestialSphereGroupBox);
        colorEclipticLineJ2000->setObjectName("colorEclipticLineJ2000");
        colorEclipticLineJ2000->setText(QString::fromUtf8(""));

        markingsGridLayout->addWidget(colorEclipticLineJ2000, 3, 3, 1, 1);

        colorFixedEquatorialGrid = new ColorButton(celestialSphereGroupBox);
        colorFixedEquatorialGrid->setObjectName("colorFixedEquatorialGrid");

        markingsGridLayout->addWidget(colorFixedEquatorialGrid, 2, 0, 1, 1);

        colorFOVCenterMarker = new ColorButton(celestialSphereGroupBox);
        colorFOVCenterMarker->setObjectName("colorFOVCenterMarker");

        markingsGridLayout->addWidget(colorFOVCenterMarker, 13, 9, 1, 1);

        meridianPartsCheckBox = new QCheckBox(celestialSphereGroupBox);
        meridianPartsCheckBox->setObjectName("meridianPartsCheckBox");

        markingsGridLayout->addWidget(meridianPartsCheckBox, 10, 5, 1, 1);

        colorCardinalPoints = new ColorButton(celestialSphereGroupBox);
        colorCardinalPoints->setObjectName("colorCardinalPoints");
        colorCardinalPoints->setText(QString::fromUtf8(""));

        markingsGridLayout->addWidget(colorCardinalPoints, 14, 0, 1, 1);

        colorAzimuthalGrid = new ColorButton(celestialSphereGroupBox);
        colorAzimuthalGrid->setObjectName("colorAzimuthalGrid");
        colorAzimuthalGrid->setText(QString::fromUtf8(""));

        markingsGridLayout->addWidget(colorAzimuthalGrid, 5, 0, 1, 1);

        colorLongitudeLine = new ColorButton(celestialSphereGroupBox);
        colorLongitudeLine->setObjectName("colorLongitudeLine");
        colorLongitudeLine->setText(QString::fromUtf8(""));

        markingsGridLayout->addWidget(colorLongitudeLine, 8, 3, 1, 1);

        showEclipticLineJ2000CheckBox = new QCheckBox(celestialSphereGroupBox);
        showEclipticLineJ2000CheckBox->setObjectName("showEclipticLineJ2000CheckBox");

        markingsGridLayout->addWidget(showEclipticLineJ2000CheckBox, 3, 4, 1, 1);

        horizonPartsCheckBox = new QCheckBox(celestialSphereGroupBox);
        horizonPartsCheckBox->setObjectName("horizonPartsCheckBox");

        markingsGridLayout->addWidget(horizonPartsCheckBox, 5, 5, 1, 1);

        gridLayout_23 = new QGridLayout();
        gridLayout_23->setObjectName("gridLayout_23");
        fovRectangularMarkerWidthDoubleSpinBox = new QDoubleSpinBox(celestialSphereGroupBox);
        fovRectangularMarkerWidthDoubleSpinBox->setObjectName("fovRectangularMarkerWidthDoubleSpinBox");
        fovRectangularMarkerWidthDoubleSpinBox->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        fovRectangularMarkerWidthDoubleSpinBox->setMinimum(0.100000000000000);
        fovRectangularMarkerWidthDoubleSpinBox->setMaximum(180.000000000000000);
        fovRectangularMarkerWidthDoubleSpinBox->setSingleStep(0.100000000000000);
        fovRectangularMarkerWidthDoubleSpinBox->setValue(4.000000000000000);

        gridLayout_23->addWidget(fovRectangularMarkerWidthDoubleSpinBox, 1, 3, 1, 1);

        fovCircularMarkerSizeDoubleSpinBox = new QDoubleSpinBox(celestialSphereGroupBox);
        fovCircularMarkerSizeDoubleSpinBox->setObjectName("fovCircularMarkerSizeDoubleSpinBox");
        fovCircularMarkerSizeDoubleSpinBox->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        fovCircularMarkerSizeDoubleSpinBox->setDecimals(2);
        fovCircularMarkerSizeDoubleSpinBox->setMinimum(0.100000000000000);
        fovCircularMarkerSizeDoubleSpinBox->setMaximum(28.000000000000000);
        fovCircularMarkerSizeDoubleSpinBox->setSingleStep(0.100000000000000);
        fovCircularMarkerSizeDoubleSpinBox->setValue(1.000000000000000);

        gridLayout_23->addWidget(fovCircularMarkerSizeDoubleSpinBox, 0, 5, 1, 1);

        horizontalSpacer_19 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_23->addItem(horizontalSpacer_19, 0, 2, 1, 1);

        showFOVCircularMarkerCheckBox = new QCheckBox(celestialSphereGroupBox);
        showFOVCircularMarkerCheckBox->setObjectName("showFOVCircularMarkerCheckBox");

        gridLayout_23->addWidget(showFOVCircularMarkerCheckBox, 0, 1, 1, 1);

        fovRectangularMarkerRotationAngleDoubleSpinBox = new QDoubleSpinBox(celestialSphereGroupBox);
        fovRectangularMarkerRotationAngleDoubleSpinBox->setObjectName("fovRectangularMarkerRotationAngleDoubleSpinBox");
        fovRectangularMarkerRotationAngleDoubleSpinBox->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        fovRectangularMarkerRotationAngleDoubleSpinBox->setDecimals(1);
        fovRectangularMarkerRotationAngleDoubleSpinBox->setMinimum(-90.000000000000000);
        fovRectangularMarkerRotationAngleDoubleSpinBox->setMaximum(90.000000000000000);

        gridLayout_23->addWidget(fovRectangularMarkerRotationAngleDoubleSpinBox, 1, 5, 1, 1);

        fovRectangularMarkerHeightDoubleSpinBox = new QDoubleSpinBox(celestialSphereGroupBox);
        fovRectangularMarkerHeightDoubleSpinBox->setObjectName("fovRectangularMarkerHeightDoubleSpinBox");
        fovRectangularMarkerHeightDoubleSpinBox->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        fovRectangularMarkerHeightDoubleSpinBox->setMinimum(0.100000000000000);
        fovRectangularMarkerHeightDoubleSpinBox->setMaximum(180.000000000000000);
        fovRectangularMarkerHeightDoubleSpinBox->setSingleStep(0.100000000000000);
        fovRectangularMarkerHeightDoubleSpinBox->setValue(3.000000000000000);

        gridLayout_23->addWidget(fovRectangularMarkerHeightDoubleSpinBox, 1, 4, 1, 1);

        showFOVRectangularMarkerCheckBox = new QCheckBox(celestialSphereGroupBox);
        showFOVRectangularMarkerCheckBox->setObjectName("showFOVRectangularMarkerCheckBox");

        gridLayout_23->addWidget(showFOVRectangularMarkerCheckBox, 1, 1, 1, 1);

        colorFOVCircularMarker = new ColorButton(celestialSphereGroupBox);
        colorFOVCircularMarker->setObjectName("colorFOVCircularMarker");

        gridLayout_23->addWidget(colorFOVCircularMarker, 0, 0, 1, 1);

        colorFOVRectangularMarker = new ColorButton(celestialSphereGroupBox);
        colorFOVRectangularMarker->setObjectName("colorFOVRectangularMarker");

        gridLayout_23->addWidget(colorFOVRectangularMarker, 1, 0, 1, 1);


        markingsGridLayout->addLayout(gridLayout_23, 14, 9, 2, 2);

        equatorLabelsCheckBox = new QCheckBox(celestialSphereGroupBox);
        equatorLabelsCheckBox->setObjectName("equatorLabelsCheckBox");

        markingsGridLayout->addWidget(equatorLabelsCheckBox, 1, 6, 1, 1);

        colorApexPoints = new ColorButton(celestialSphereGroupBox);
        colorApexPoints->setObjectName("colorApexPoints");
        colorApexPoints->setText(QString::fromUtf8(""));

        markingsGridLayout->addWidget(colorApexPoints, 12, 0, 1, 1);

        equatorLabel = new QLabel(celestialSphereGroupBox);
        equatorLabel->setObjectName("equatorLabel");

        markingsGridLayout->addWidget(equatorLabel, 1, 7, 1, 1);

        precessionLabelsCheckBox = new QCheckBox(celestialSphereGroupBox);
        precessionLabelsCheckBox->setObjectName("precessionLabelsCheckBox");

        markingsGridLayout->addWidget(precessionLabelsCheckBox, 13, 6, 1, 1);

        equatorJ2000Label = new QLabel(celestialSphereGroupBox);
        equatorJ2000Label->setObjectName("equatorJ2000Label");

        markingsGridLayout->addWidget(equatorJ2000Label, 0, 7, 1, 1);

        colorQuadratureLine = new ColorButton(celestialSphereGroupBox);
        colorQuadratureLine->setObjectName("colorQuadratureLine");

        markingsGridLayout->addWidget(colorQuadratureLine, 8, 9, 1, 1);

        showSolarEquatorCheckBox = new QCheckBox(celestialSphereGroupBox);
        showSolarEquatorCheckBox->setObjectName("showSolarEquatorCheckBox");

        markingsGridLayout->addWidget(showSolarEquatorCheckBox, 9, 4, 1, 1);

        showSupergalacticGridCheckBox = new QCheckBox(celestialSphereGroupBox);
        showSupergalacticGridCheckBox->setObjectName("showSupergalacticGridCheckBox");

        markingsGridLayout->addWidget(showSupergalacticGridCheckBox, 7, 1, 1, 1);

        showEquatorJ2000LineCheckBox = new QCheckBox(celestialSphereGroupBox);
        showEquatorJ2000LineCheckBox->setObjectName("showEquatorJ2000LineCheckBox");

        markingsGridLayout->addWidget(showEquatorJ2000LineCheckBox, 0, 4, 1, 1);

        eclipticJ2000PartsCheckBox = new QCheckBox(celestialSphereGroupBox);
        eclipticJ2000PartsCheckBox->setObjectName("eclipticJ2000PartsCheckBox");

        markingsGridLayout->addWidget(eclipticJ2000PartsCheckBox, 3, 5, 1, 1);

        eclipticLabelsCheckBox = new QCheckBox(celestialSphereGroupBox);
        eclipticLabelsCheckBox->setObjectName("eclipticLabelsCheckBox");

        markingsGridLayout->addWidget(eclipticLabelsCheckBox, 4, 6, 1, 1);

        colorCelestialPoles = new ColorButton(celestialSphereGroupBox);
        colorCelestialPoles->setObjectName("colorCelestialPoles");
        colorCelestialPoles->setText(QString::fromUtf8(""));

        markingsGridLayout->addWidget(colorCelestialPoles, 1, 9, 1, 1);

        showSolsticeJ2000PointsCheckBox = new QCheckBox(celestialSphereGroupBox);
        showSolsticeJ2000PointsCheckBox->setObjectName("showSolsticeJ2000PointsCheckBox");

        markingsGridLayout->addWidget(showSolsticeJ2000PointsCheckBox, 10, 1, 1, 1);

        horizonLabel = new QLabel(celestialSphereGroupBox);
        horizonLabel->setObjectName("horizonLabel");

        markingsGridLayout->addWidget(horizonLabel, 5, 7, 1, 1);

        colorEquatorialGrid = new ColorButton(celestialSphereGroupBox);
        colorEquatorialGrid->setObjectName("colorEquatorialGrid");
        colorEquatorialGrid->setText(QString::fromUtf8(""));

        markingsGridLayout->addWidget(colorEquatorialGrid, 1, 0, 1, 1);

        longitudeLabelsCheckBox = new QCheckBox(celestialSphereGroupBox);
        longitudeLabelsCheckBox->setObjectName("longitudeLabelsCheckBox");

        markingsGridLayout->addWidget(longitudeLabelsCheckBox, 8, 6, 1, 1);

        colorEclipticGridOfDate = new ColorButton(celestialSphereGroupBox);
        colorEclipticGridOfDate->setObjectName("colorEclipticGridOfDate");
        colorEclipticGridOfDate->setText(QString::fromUtf8(""));

        markingsGridLayout->addWidget(colorEclipticGridOfDate, 4, 0, 1, 1);

        showCelestialJ2000PolesCheckBox = new QCheckBox(celestialSphereGroupBox);
        showCelestialJ2000PolesCheckBox->setObjectName("showCelestialJ2000PolesCheckBox");

        markingsGridLayout->addWidget(showCelestialJ2000PolesCheckBox, 0, 10, 1, 1);

        eclipticJ2000Label = new QLabel(celestialSphereGroupBox);
        eclipticJ2000Label->setObjectName("eclipticJ2000Label");

        markingsGridLayout->addWidget(eclipticJ2000Label, 3, 7, 1, 1);

        solarEquatorLabel = new QLabel(celestialSphereGroupBox);
        solarEquatorLabel->setObjectName("solarEquatorLabel");

        markingsGridLayout->addWidget(solarEquatorLabel, 9, 7, 1, 1);

        showPenumbraCheckBox = new QCheckBox(celestialSphereGroupBox);
        showPenumbraCheckBox->setObjectName("showPenumbraCheckBox");

        markingsGridLayout->addWidget(showPenumbraCheckBox, 11, 10, 1, 1);

        colorEclipticLineOfDate = new ColorButton(celestialSphereGroupBox);
        colorEclipticLineOfDate->setObjectName("colorEclipticLineOfDate");
        colorEclipticLineOfDate->setText(QString::fromUtf8(""));

        markingsGridLayout->addWidget(colorEclipticLineOfDate, 4, 3, 1, 1);

        showEquatorialJ2000GridCheckBox = new QCheckBox(celestialSphereGroupBox);
        showEquatorialJ2000GridCheckBox->setObjectName("showEquatorialJ2000GridCheckBox");

        markingsGridLayout->addWidget(showEquatorialJ2000GridCheckBox, 0, 1, 1, 1);

        colorSolsticeJ2000Points = new ColorButton(celestialSphereGroupBox);
        colorSolsticeJ2000Points->setObjectName("colorSolsticeJ2000Points");

        markingsGridLayout->addWidget(colorSolsticeJ2000Points, 10, 0, 1, 1);

        eclipticJ2000LabelsCheckBox = new QCheckBox(celestialSphereGroupBox);
        eclipticJ2000LabelsCheckBox->setObjectName("eclipticJ2000LabelsCheckBox");

        markingsGridLayout->addWidget(eclipticJ2000LabelsCheckBox, 3, 6, 1, 1);

        showSolsticePointsCheckBox = new QCheckBox(celestialSphereGroupBox);
        showSolsticePointsCheckBox->setObjectName("showSolsticePointsCheckBox");

        markingsGridLayout->addWidget(showSolsticePointsCheckBox, 11, 1, 1, 1);

        showPrimeVerticalLineCheckBox = new QCheckBox(celestialSphereGroupBox);
        showPrimeVerticalLineCheckBox->setObjectName("showPrimeVerticalLineCheckBox");

        markingsGridLayout->addWidget(showPrimeVerticalLineCheckBox, 14, 4, 1, 1);

        showCelestialPolesCheckBox = new QCheckBox(celestialSphereGroupBox);
        showCelestialPolesCheckBox->setObjectName("showCelestialPolesCheckBox");

        markingsGridLayout->addWidget(showCelestialPolesCheckBox, 1, 10, 1, 1);

        colorCurrentVerticalLine = new ColorButton(celestialSphereGroupBox);
        colorCurrentVerticalLine->setObjectName("colorCurrentVerticalLine");

        markingsGridLayout->addWidget(colorCurrentVerticalLine, 11, 3, 1, 1);

        primeVerticalLabel = new QLabel(celestialSphereGroupBox);
        primeVerticalLabel->setObjectName("primeVerticalLabel");

        markingsGridLayout->addWidget(primeVerticalLabel, 14, 7, 1, 1);

        showLongitudeLineCheckBox = new QCheckBox(celestialSphereGroupBox);
        showLongitudeLineCheckBox->setObjectName("showLongitudeLineCheckBox");

        markingsGridLayout->addWidget(showLongitudeLineCheckBox, 8, 4, 1, 1);

        showEquatorialGridCheckBox = new QCheckBox(celestialSphereGroupBox);
        showEquatorialGridCheckBox->setObjectName("showEquatorialGridCheckBox");

        markingsGridLayout->addWidget(showEquatorialGridCheckBox, 1, 1, 1, 1);

        showPrecessionCirclesCheckBox = new QCheckBox(celestialSphereGroupBox);
        showPrecessionCirclesCheckBox->setObjectName("showPrecessionCirclesCheckBox");
        sizePolicy8.setHeightForWidth(showPrecessionCirclesCheckBox->sizePolicy().hasHeightForWidth());
        showPrecessionCirclesCheckBox->setSizePolicy(sizePolicy8);

        markingsGridLayout->addWidget(showPrecessionCirclesCheckBox, 13, 4, 1, 1);

        horizontalSpacer_3 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        markingsGridLayout->addItem(horizontalSpacer_3, 0, 8, 1, 1);

        showMeridianLineCheckBox = new QCheckBox(celestialSphereGroupBox);
        showMeridianLineCheckBox->setObjectName("showMeridianLineCheckBox");

        markingsGridLayout->addWidget(showMeridianLineCheckBox, 10, 4, 1, 1);

        precessionLabel = new QLabel(celestialSphereGroupBox);
        precessionLabel->setObjectName("precessionLabel");

        markingsGridLayout->addWidget(precessionLabel, 13, 7, 1, 1);

        showGalacticPolesCheckBox = new QCheckBox(celestialSphereGroupBox);
        showGalacticPolesCheckBox->setObjectName("showGalacticPolesCheckBox");

        markingsGridLayout->addWidget(showGalacticPolesCheckBox, 6, 10, 1, 1);

        currentVerticalLabel = new QLabel(celestialSphereGroupBox);
        currentVerticalLabel->setObjectName("currentVerticalLabel");

        markingsGridLayout->addWidget(currentVerticalLabel, 11, 7, 1, 1);

        showCompassMarksCheckBox = new QCheckBox(celestialSphereGroupBox);
        showCompassMarksCheckBox->setObjectName("showCompassMarksCheckBox");

        markingsGridLayout->addWidget(showCompassMarksCheckBox, 15, 1, 1, 1);

        colorEquatorJ2000Line = new ColorButton(celestialSphereGroupBox);
        colorEquatorJ2000Line->setObjectName("colorEquatorJ2000Line");
        colorEquatorJ2000Line->setText(QString::fromUtf8(""));

        markingsGridLayout->addWidget(colorEquatorJ2000Line, 0, 3, 1, 1);

        colorEquatorialJ2000Grid = new ColorButton(celestialSphereGroupBox);
        colorEquatorialJ2000Grid->setObjectName("colorEquatorialJ2000Grid");
        colorEquatorialJ2000Grid->setText(QString::fromUtf8(""));

        markingsGridLayout->addWidget(colorEquatorialJ2000Grid, 0, 0, 1, 1);

        showGalacticGridCheckBox = new QCheckBox(celestialSphereGroupBox);
        showGalacticGridCheckBox->setObjectName("showGalacticGridCheckBox");

        markingsGridLayout->addWidget(showGalacticGridCheckBox, 6, 1, 1, 1);

        colorMeridianLine = new ColorButton(celestialSphereGroupBox);
        colorMeridianLine->setObjectName("colorMeridianLine");
        colorMeridianLine->setText(QString::fromUtf8(""));

        markingsGridLayout->addWidget(colorMeridianLine, 10, 3, 1, 1);

        showCurrentVerticalLineCheckBox = new QCheckBox(celestialSphereGroupBox);
        showCurrentVerticalLineCheckBox->setObjectName("showCurrentVerticalLineCheckBox");

        markingsGridLayout->addWidget(showCurrentVerticalLineCheckBox, 11, 4, 1, 1);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        markingsGridLayout->addItem(horizontalSpacer_2, 0, 2, 1, 1);

        horizontalLayout_26 = new QHBoxLayout();
        horizontalLayout_26->setObjectName("horizontalLayout_26");
        showCardinalPointsCheckBox = new QCheckBox(celestialSphereGroupBox);
        showCardinalPointsCheckBox->setObjectName("showCardinalPointsCheckBox");

        horizontalLayout_26->addWidget(showCardinalPointsCheckBox);

        horizontalSpacer_7 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_26->addItem(horizontalSpacer_7);

        showOrdinal8WRPointsCheckBox = new QCheckBox(celestialSphereGroupBox);
        showOrdinal8WRPointsCheckBox->setObjectName("showOrdinal8WRPointsCheckBox");
        showOrdinal8WRPointsCheckBox->setText(QString::fromUtf8("8"));

        horizontalLayout_26->addWidget(showOrdinal8WRPointsCheckBox);

        showOrdinal16WRPointsCheckBox = new QCheckBox(celestialSphereGroupBox);
        showOrdinal16WRPointsCheckBox->setObjectName("showOrdinal16WRPointsCheckBox");
        showOrdinal16WRPointsCheckBox->setText(QString::fromUtf8("16"));

        horizontalLayout_26->addWidget(showOrdinal16WRPointsCheckBox);

        showOrdinal32WRPointsCheckBox = new QCheckBox(celestialSphereGroupBox);
        showOrdinal32WRPointsCheckBox->setObjectName("showOrdinal32WRPointsCheckBox");
        showOrdinal32WRPointsCheckBox->setText(QString::fromUtf8("32"));

        horizontalLayout_26->addWidget(showOrdinal32WRPointsCheckBox);


        markingsGridLayout->addLayout(horizontalLayout_26, 14, 1, 1, 1);

        showAntisolarPointCheckBox = new QCheckBox(celestialSphereGroupBox);
        showAntisolarPointCheckBox->setObjectName("showAntisolarPointCheckBox");

        markingsGridLayout->addWidget(showAntisolarPointCheckBox, 9, 10, 1, 1);

        colorGalacticEquatorLine = new ColorButton(celestialSphereGroupBox);
        colorGalacticEquatorLine->setObjectName("colorGalacticEquatorLine");
        colorGalacticEquatorLine->setText(QString::fromUtf8(""));

        markingsGridLayout->addWidget(colorGalacticEquatorLine, 6, 3, 1, 1);

        showCircumpolarCirclesCheckBox = new QCheckBox(celestialSphereGroupBox);
        showCircumpolarCirclesCheckBox->setObjectName("showCircumpolarCirclesCheckBox");

        markingsGridLayout->addWidget(showCircumpolarCirclesCheckBox, 2, 10, 1, 1);

        showHorizonLineCheckBox = new QCheckBox(celestialSphereGroupBox);
        showHorizonLineCheckBox->setObjectName("showHorizonLineCheckBox");

        markingsGridLayout->addWidget(showHorizonLineCheckBox, 5, 4, 1, 1);

        colorEclipticPoles = new ColorButton(celestialSphereGroupBox);
        colorEclipticPoles->setObjectName("colorEclipticPoles");
        colorEclipticPoles->setText(QString::fromUtf8(""));

        markingsGridLayout->addWidget(colorEclipticPoles, 4, 9, 1, 1);

        showFixedEquatorLineCheckBox = new QCheckBox(celestialSphereGroupBox);
        showFixedEquatorLineCheckBox->setObjectName("showFixedEquatorLineCheckBox");

        markingsGridLayout->addWidget(showFixedEquatorLineCheckBox, 2, 4, 1, 1);

        horizonLabelsCheckBox = new QCheckBox(celestialSphereGroupBox);
        horizonLabelsCheckBox->setObjectName("horizonLabelsCheckBox");

        markingsGridLayout->addWidget(horizonLabelsCheckBox, 5, 6, 1, 1);

        showEclipticJ2000PolesCheckBox = new QCheckBox(celestialSphereGroupBox);
        showEclipticJ2000PolesCheckBox->setObjectName("showEclipticJ2000PolesCheckBox");

        markingsGridLayout->addWidget(showEclipticJ2000PolesCheckBox, 3, 10, 1, 1);

        colorFixedEquatorLine = new ColorButton(celestialSphereGroupBox);
        colorFixedEquatorLine->setObjectName("colorFixedEquatorLine");

        markingsGridLayout->addWidget(colorFixedEquatorLine, 2, 3, 1, 1);

        showQuadratureLineCheckBox = new QCheckBox(celestialSphereGroupBox);
        showQuadratureLineCheckBox->setObjectName("showQuadratureLineCheckBox");

        markingsGridLayout->addWidget(showQuadratureLineCheckBox, 8, 10, 1, 1);

        showColuresLineCheckBox = new QCheckBox(celestialSphereGroupBox);
        showColuresLineCheckBox->setObjectName("showColuresLineCheckBox");

        markingsGridLayout->addWidget(showColuresLineCheckBox, 12, 4, 1, 1);

        fixedEquatorLabel = new QLabel(celestialSphereGroupBox);
        fixedEquatorLabel->setObjectName("fixedEquatorLabel");

        markingsGridLayout->addWidget(fixedEquatorLabel, 2, 7, 1, 1);

        showGalacticCenterCheckBox = new QCheckBox(celestialSphereGroupBox);
        showGalacticCenterCheckBox->setObjectName("showGalacticCenterCheckBox");

        markingsGridLayout->addWidget(showGalacticCenterCheckBox, 13, 1, 1, 1);

        horizontalLayout_eclipticLine = new QHBoxLayout();
        horizontalLayout_eclipticLine->setObjectName("horizontalLayout_eclipticLine");
        eclipticLabel = new QLabel(celestialSphereGroupBox);
        eclipticLabel->setObjectName("eclipticLabel");

        horizontalLayout_eclipticLine->addWidget(eclipticLabel);

        withSolarTicksCheckbox = new QCheckBox(celestialSphereGroupBox);
        withSolarTicksCheckbox->setObjectName("withSolarTicksCheckbox");

        horizontalLayout_eclipticLine->addWidget(withSolarTicksCheckbox);


        markingsGridLayout->addLayout(horizontalLayout_eclipticLine, 4, 7, 1, 1);

        equatorPartsCheckBox = new QCheckBox(celestialSphereGroupBox);
        equatorPartsCheckBox->setObjectName("equatorPartsCheckBox");

        markingsGridLayout->addWidget(equatorPartsCheckBox, 1, 5, 1, 1);

        supergalacticEquatorPartsCheckBox = new QCheckBox(celestialSphereGroupBox);
        supergalacticEquatorPartsCheckBox->setObjectName("supergalacticEquatorPartsCheckBox");

        markingsGridLayout->addWidget(supergalacticEquatorPartsCheckBox, 7, 5, 1, 1);

        colorCompassMarks = new ColorButton(celestialSphereGroupBox);
        colorCompassMarks->setObjectName("colorCompassMarks");

        markingsGridLayout->addWidget(colorCompassMarks, 15, 0, 1, 1);

        colorColuresLine = new ColorButton(celestialSphereGroupBox);
        colorColuresLine->setObjectName("colorColuresLine");
        colorColuresLine->setText(QString::fromUtf8(""));

        markingsGridLayout->addWidget(colorColuresLine, 12, 3, 1, 1);

        colorZenithNadir = new ColorButton(celestialSphereGroupBox);
        colorZenithNadir->setObjectName("colorZenithNadir");
        colorZenithNadir->setText(QString::fromUtf8(""));

        markingsGridLayout->addWidget(colorZenithNadir, 5, 9, 1, 1);

        colorEquinoxJ2000Points = new ColorButton(celestialSphereGroupBox);
        colorEquinoxJ2000Points->setObjectName("colorEquinoxJ2000Points");
        colorEquinoxJ2000Points->setText(QString::fromUtf8(""));

        markingsGridLayout->addWidget(colorEquinoxJ2000Points, 8, 0, 1, 1);

        meridianLabel = new QLabel(celestialSphereGroupBox);
        meridianLabel->setObjectName("meridianLabel");

        markingsGridLayout->addWidget(meridianLabel, 10, 7, 1, 1);

        colorEclipticJ2000Poles = new ColorButton(celestialSphereGroupBox);
        colorEclipticJ2000Poles->setObjectName("colorEclipticJ2000Poles");
        colorEclipticJ2000Poles->setText(QString::fromUtf8(""));

        markingsGridLayout->addWidget(colorEclipticJ2000Poles, 3, 9, 1, 1);

        showFOVCenterMarkerCheckBox = new QCheckBox(celestialSphereGroupBox);
        showFOVCenterMarkerCheckBox->setObjectName("showFOVCenterMarkerCheckBox");

        markingsGridLayout->addWidget(showFOVCenterMarkerCheckBox, 13, 10, 1, 1);

        colorInvariablePlane = new ColorButton(celestialSphereGroupBox);
        colorInvariablePlane->setObjectName("colorInvariablePlane");

        markingsGridLayout->addWidget(colorInvariablePlane, 12, 9, 1, 1);

        colorPrecessionCircles = new ColorButton(celestialSphereGroupBox);
        colorPrecessionCircles->setObjectName("colorPrecessionCircles");
        colorPrecessionCircles->setText(QString::fromUtf8(""));

        markingsGridLayout->addWidget(colorPrecessionCircles, 13, 3, 1, 1);


        verticalLayout_10->addLayout(markingsGridLayout);

        lineDivider = new QFrame(celestialSphereGroupBox);
        lineDivider->setObjectName("lineDivider");
        lineDivider->setMinimumSize(QSize(0, 1));
        lineDivider->setMaximumSize(QSize(16777215, 1));
        lineDivider->setFrameShape(QFrame::Shape::HLine);
        lineDivider->setFrameShadow(QFrame::Shadow::Sunken);

        verticalLayout_10->addWidget(lineDivider);

        horizontalLayout_5 = new QHBoxLayout();
        horizontalLayout_5->setObjectName("horizontalLayout_5");
        horizontalLayout_5->setContentsMargins(-1, 0, -1, -1);
        horizontalSpacer_13 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_5->addItem(horizontalSpacer_13);

        gridSpacingLabel = new QLabel(celestialSphereGroupBox);
        gridSpacingLabel->setObjectName("gridSpacingLabel");

        horizontalLayout_5->addWidget(gridSpacingLabel);

        gridSpacingComboBox = new QComboBox(celestialSphereGroupBox);
        gridSpacingComboBox->addItem(QString());
        gridSpacingComboBox->addItem(QString());
        gridSpacingComboBox->addItem(QString());
        gridSpacingComboBox->setObjectName("gridSpacingComboBox");

        horizontalLayout_5->addWidget(gridSpacingComboBox);

        horizontalSpacer_12 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_5->addItem(horizontalSpacer_12);

        label_2 = new QLabel(celestialSphereGroupBox);
        label_2->setObjectName("label_2");

        horizontalLayout_5->addWidget(label_2);

        lineThicknessSpinBox = new QSpinBox(celestialSphereGroupBox);
        lineThicknessSpinBox->setObjectName("lineThicknessSpinBox");
        lineThicknessSpinBox->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        lineThicknessSpinBox->setMinimum(1);
        lineThicknessSpinBox->setMaximum(5);

        horizontalLayout_5->addWidget(lineThicknessSpinBox);

        partThicknessLabel = new QLabel(celestialSphereGroupBox);
        partThicknessLabel->setObjectName("partThicknessLabel");

        horizontalLayout_5->addWidget(partThicknessLabel);

        partThicknessSpinBox = new QSpinBox(celestialSphereGroupBox);
        partThicknessSpinBox->setObjectName("partThicknessSpinBox");
        sizePolicy5.setHeightForWidth(partThicknessSpinBox->sizePolicy().hasHeightForWidth());
        partThicknessSpinBox->setSizePolicy(sizePolicy5);
        partThicknessSpinBox->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        partThicknessSpinBox->setMinimum(1);
        partThicknessSpinBox->setMaximum(5);

        horizontalLayout_5->addWidget(partThicknessSpinBox);

        pointSizeLabel = new QLabel(celestialSphereGroupBox);
        pointSizeLabel->setObjectName("pointSizeLabel");

        horizontalLayout_5->addWidget(pointSizeLabel);

        pointSizeSpinBox = new QSpinBox(celestialSphereGroupBox);
        pointSizeSpinBox->setObjectName("pointSizeSpinBox");
        pointSizeSpinBox->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        pointSizeSpinBox->setMinimum(5);
        pointSizeSpinBox->setMaximum(25);

        horizontalLayout_5->addWidget(pointSizeSpinBox);

        horizontalSpacer_11 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_5->addItem(horizontalSpacer_11);


        verticalLayout_10->addLayout(horizontalLayout_5);


        gridLayout_2->addWidget(celestialSphereGroupBox, 0, 0, 1, 1);

        verticalSpacer_4 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_2->addItem(verticalSpacer_4, 1, 0, 1, 1);

        stackedWidget->addWidget(page_markings);
        page_landscape = new QWidget();
        page_landscape->setObjectName("page_landscape");
        gridLayout_3 = new QGridLayout(page_landscape);
        gridLayout_3->setSpacing(0);
        gridLayout_3->setObjectName("gridLayout_3");
        gridLayout_3->setContentsMargins(0, 0, 0, 0);
        landscapeTextBrowser = new QTextBrowser(page_landscape);
        landscapeTextBrowser->setObjectName("landscapeTextBrowser");
        landscapeTextBrowser->setEnabled(true);
        sizePolicy4.setHeightForWidth(landscapeTextBrowser->sizePolicy().hasHeightForWidth());
        landscapeTextBrowser->setSizePolicy(sizePolicy4);
        landscapeTextBrowser->setFrameShape(QFrame::StyledPanel);
        landscapeTextBrowser->setLineWidth(1);
        landscapeTextBrowser->setVerticalScrollBarPolicy(Qt::ScrollBarAsNeeded);
        landscapeTextBrowser->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
        landscapeTextBrowser->setOpenExternalLinks(true);

        gridLayout_3->addWidget(landscapeTextBrowser, 0, 1, 1, 1);

        landscapeButtonsGridLayout = new QGridLayout();
        landscapeButtonsGridLayout->setObjectName("landscapeButtonsGridLayout");
        landscapeButtonsGridLayout->setContentsMargins(0, 0, 0, 0);
        pushButtonAddRemoveLandscapes = new QPushButton(page_landscape);
        pushButtonAddRemoveLandscapes->setObjectName("pushButtonAddRemoveLandscapes");
        pushButtonAddRemoveLandscapes->setStyleSheet(QString::fromUtf8("margin-left: 10px; margin-right: 10px; margin-bottom:10px;"));

        landscapeButtonsGridLayout->addWidget(pushButtonAddRemoveLandscapes, 0, 0, 1, 3);

        pushButtonLandscapes_say = new QPushButton(page_landscape);
        pushButtonLandscapes_say->setObjectName("pushButtonLandscapes_say");
        pushButtonLandscapes_say->setStyleSheet(QString::fromUtf8("margin-left: 10px; margin-right: 10px; margin-bottom:10px;"));
        QIcon icon10;
        icon10.addFile(QString::fromUtf8(":/graphicGui/uibtStart.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        icon10.addFile(QString::fromUtf8(":/graphicGui/uibtStart-disabled.png"), QSize(), QIcon::Mode::Disabled, QIcon::State::Off);
        pushButtonLandscapes_say->setIcon(icon10);

        landscapeButtonsGridLayout->addWidget(pushButtonLandscapes_say, 0, 3, 1, 1);

        pushButtonLandscapes_stop = new QPushButton(page_landscape);
        pushButtonLandscapes_stop->setObjectName("pushButtonLandscapes_stop");
        pushButtonLandscapes_stop->setStyleSheet(QString::fromUtf8("margin-left: 10px; margin-right: 10px; margin-bottom:10px;"));
        QIcon icon11;
        icon11.addFile(QString::fromUtf8(":/graphicGui/uibtStop.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        icon11.addFile(QString::fromUtf8(":/graphicGui/uibtStop-disabled.png"), QSize(), QIcon::Mode::Disabled, QIcon::State::Off);
        pushButtonLandscapes_stop->setIcon(icon11);

        landscapeButtonsGridLayout->addWidget(pushButtonLandscapes_stop, 0, 4, 1, 1);


        gridLayout_3->addLayout(landscapeButtonsGridLayout, 3, 1, 1, 1);

        landscapeOptionsGroupBox = new QGroupBox(page_landscape);
        landscapeOptionsGroupBox->setObjectName("landscapeOptionsGroupBox");
        sizePolicy1.setHeightForWidth(landscapeOptionsGroupBox->sizePolicy().hasHeightForWidth());
        landscapeOptionsGroupBox->setSizePolicy(sizePolicy1);
        landscapeOptionsGroupBox->setCheckable(false);
        gridLayout_7 = new QGridLayout(landscapeOptionsGroupBox);
        gridLayout_7->setObjectName("gridLayout_7");
        gridLayout_7->setContentsMargins(0, 0, 0, 0);
        horizontalLayout_25 = new QHBoxLayout();
        horizontalLayout_25->setObjectName("horizontalLayout_25");
        horizontalLayout_25->setContentsMargins(22, -1, -1, -1);
        localLandscapeBrightnessCheckBox = new QCheckBox(landscapeOptionsGroupBox);
        localLandscapeBrightnessCheckBox->setObjectName("localLandscapeBrightnessCheckBox");
        localLandscapeBrightnessCheckBox->setEnabled(false);

        horizontalLayout_25->addWidget(localLandscapeBrightnessCheckBox);


        gridLayout_7->addLayout(horizontalLayout_25, 5, 0, 1, 1);

        landscapeIlluminationCheckBox = new QCheckBox(landscapeOptionsGroupBox);
        landscapeIlluminationCheckBox->setObjectName("landscapeIlluminationCheckBox");
        landscapeIlluminationCheckBox->setChecked(true);

        gridLayout_7->addWidget(landscapeIlluminationCheckBox, 3, 2, 1, 1);

        horizontalLayout_13 = new QHBoxLayout();
        horizontalLayout_13->setObjectName("horizontalLayout_13");
        landscapeTransparencyCheckBox = new QCheckBox(landscapeOptionsGroupBox);
        landscapeTransparencyCheckBox->setObjectName("landscapeTransparencyCheckBox");
        QSizePolicy sizePolicy9(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy9.setHorizontalStretch(0);
        sizePolicy9.setVerticalStretch(0);
        sizePolicy9.setHeightForWidth(landscapeTransparencyCheckBox->sizePolicy().hasHeightForWidth());
        landscapeTransparencyCheckBox->setSizePolicy(sizePolicy9);

        horizontalLayout_13->addWidget(landscapeTransparencyCheckBox);

        landscapeTransparencySpinBox = new QDoubleSpinBox(landscapeOptionsGroupBox);
        landscapeTransparencySpinBox->setObjectName("landscapeTransparencySpinBox");
        landscapeTransparencySpinBox->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        landscapeTransparencySpinBox->setMinimum(0.000000000000000);
        landscapeTransparencySpinBox->setMaximum(1.000000000000000);
        landscapeTransparencySpinBox->setSingleStep(0.010000000000000);
        landscapeTransparencySpinBox->setValue(0.000000000000000);

        horizontalLayout_13->addWidget(landscapeTransparencySpinBox);


        gridLayout_7->addLayout(horizontalLayout_13, 6, 0, 1, 1);

        landscapePolylineHorizontalLayout = new QHBoxLayout();
        landscapePolylineHorizontalLayout->setObjectName("landscapePolylineHorizontalLayout");
        landscapePolylineCheckBox = new QCheckBox(landscapeOptionsGroupBox);
        landscapePolylineCheckBox->setObjectName("landscapePolylineCheckBox");
        sizePolicy2.setHeightForWidth(landscapePolylineCheckBox->sizePolicy().hasHeightForWidth());
        landscapePolylineCheckBox->setSizePolicy(sizePolicy2);

        landscapePolylineHorizontalLayout->addWidget(landscapePolylineCheckBox);

        landscapePolylineThicknessSpinBox = new QSpinBox(landscapeOptionsGroupBox);
        landscapePolylineThicknessSpinBox->setObjectName("landscapePolylineThicknessSpinBox");
        landscapePolylineThicknessSpinBox->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        landscapePolylineThicknessSpinBox->setMinimum(0);
        landscapePolylineThicknessSpinBox->setMaximum(5);

        landscapePolylineHorizontalLayout->addWidget(landscapePolylineThicknessSpinBox);


        gridLayout_7->addLayout(landscapePolylineHorizontalLayout, 5, 2, 1, 1);

        horizontalLayout_11 = new QHBoxLayout();
        horizontalLayout_11->setObjectName("horizontalLayout_11");
        landscapeBrightnessCheckBox = new QCheckBox(landscapeOptionsGroupBox);
        landscapeBrightnessCheckBox->setObjectName("landscapeBrightnessCheckBox");
        sizePolicy2.setHeightForWidth(landscapeBrightnessCheckBox->sizePolicy().hasHeightForWidth());
        landscapeBrightnessCheckBox->setSizePolicy(sizePolicy2);

        horizontalLayout_11->addWidget(landscapeBrightnessCheckBox);

        landscapeBrightnessSpinBox = new QDoubleSpinBox(landscapeOptionsGroupBox);
        landscapeBrightnessSpinBox->setObjectName("landscapeBrightnessSpinBox");
        landscapeBrightnessSpinBox->setEnabled(false);
        landscapeBrightnessSpinBox->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        landscapeBrightnessSpinBox->setMaximum(1.000000000000000);
        landscapeBrightnessSpinBox->setSingleStep(0.010000000000000);

        horizontalLayout_11->addWidget(landscapeBrightnessSpinBox);


        gridLayout_7->addLayout(horizontalLayout_11, 4, 0, 1, 1);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        landscapeLabelsCheckBox = new QCheckBox(landscapeOptionsGroupBox);
        landscapeLabelsCheckBox->setObjectName("landscapeLabelsCheckBox");
        sizePolicy9.setHeightForWidth(landscapeLabelsCheckBox->sizePolicy().hasHeightForWidth());
        landscapeLabelsCheckBox->setSizePolicy(sizePolicy9);

        horizontalLayout_3->addWidget(landscapeLabelsCheckBox);

        landscapeLabelsFontSizeSpinBox = new QSpinBox(landscapeOptionsGroupBox);
        landscapeLabelsFontSizeSpinBox->setObjectName("landscapeLabelsFontSizeSpinBox");
        landscapeLabelsFontSizeSpinBox->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        landscapeLabelsFontSizeSpinBox->setMinimum(5);
        landscapeLabelsFontSizeSpinBox->setMaximum(48);
        landscapeLabelsFontSizeSpinBox->setValue(18);

        horizontalLayout_3->addWidget(landscapeLabelsFontSizeSpinBox);

        landscapeLabelsAngleSpinBox = new QSpinBox(landscapeOptionsGroupBox);
        landscapeLabelsAngleSpinBox->setObjectName("landscapeLabelsAngleSpinBox");
        landscapeLabelsAngleSpinBox->setSuffix(QString::fromUtf8("\302\260"));
        landscapeLabelsAngleSpinBox->setMinimum(0);
        landscapeLabelsAngleSpinBox->setMaximum(90);
        landscapeLabelsAngleSpinBox->setSingleStep(5);
        landscapeLabelsAngleSpinBox->setValue(45);

        horizontalLayout_3->addWidget(landscapeLabelsAngleSpinBox);


        gridLayout_7->addLayout(horizontalLayout_3, 6, 2, 1, 1);

        labelsColorButton = new ColorButton(landscapeOptionsGroupBox);
        labelsColorButton->setObjectName("labelsColorButton");
        labelsColorButton->setText(QString::fromUtf8(""));

        gridLayout_7->addWidget(labelsColorButton, 6, 1, 1, 1);

        polygonColorButton = new ColorButton(landscapeOptionsGroupBox);
        polygonColorButton->setObjectName("polygonColorButton");

        gridLayout_7->addWidget(polygonColorButton, 5, 1, 1, 1);

        showFogCheckBox = new QCheckBox(landscapeOptionsGroupBox);
        showFogCheckBox->setObjectName("showFogCheckBox");

        gridLayout_7->addWidget(showFogCheckBox, 4, 2, 1, 1);

        showGroundCheckBox = new QCheckBox(landscapeOptionsGroupBox);
        showGroundCheckBox->setObjectName("showGroundCheckBox");

        gridLayout_7->addWidget(showGroundCheckBox, 2, 2, 1, 1);

        landscapeLocationCheckBox = new QCheckBox(landscapeOptionsGroupBox);
        landscapeLocationCheckBox->setObjectName("landscapeLocationCheckBox");

        gridLayout_7->addWidget(landscapeLocationCheckBox, 3, 0, 1, 1);

        useAsDefaultLandscapeCheckBox = new QCheckBox(landscapeOptionsGroupBox);
        useAsDefaultLandscapeCheckBox->setObjectName("useAsDefaultLandscapeCheckBox");

        gridLayout_7->addWidget(useAsDefaultLandscapeCheckBox, 2, 0, 1, 1);


        gridLayout_3->addWidget(landscapeOptionsGroupBox, 1, 1, 1, 1);

        landscapesListWidget = new QListWidget(page_landscape);
        landscapesListWidget->setObjectName("landscapesListWidget");
        QSizePolicy sizePolicy10(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Expanding);
        sizePolicy10.setHorizontalStretch(0);
        sizePolicy10.setVerticalStretch(0);
        sizePolicy10.setHeightForWidth(landscapesListWidget->sizePolicy().hasHeightForWidth());
        landscapesListWidget->setSizePolicy(sizePolicy10);
        landscapesListWidget->setFocusPolicy(Qt::NoFocus);
        landscapesListWidget->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);

        gridLayout_3->addWidget(landscapesListWidget, 0, 0, 5, 1);

        stackedWidget->addWidget(page_landscape);
        page_skyCulture = new QWidget();
        page_skyCulture->setObjectName("page_skyCulture");
        gridLayout_4 = new QGridLayout(page_skyCulture);
        gridLayout_4->setSpacing(0);
        gridLayout_4->setObjectName("gridLayout_4");
        gridLayout_4->setContentsMargins(0, 0, 0, 0);
        skyCultureTabWidget = new QTabWidget(page_skyCulture);
        skyCultureTabWidget->setObjectName("skyCultureTabWidget");
        skyCultureTabWidget->setTabPosition(QTabWidget::South);
        skyCultureDetailsTab = new QWidget();
        skyCultureDetailsTab->setObjectName("skyCultureDetailsTab");
        skyCultureDetailsPageGridLayout = new QGridLayout(skyCultureDetailsTab);
        skyCultureDetailsPageGridLayout->setSpacing(0);
        skyCultureDetailsPageGridLayout->setObjectName("skyCultureDetailsPageGridLayout");
        skyCultureDetailsPageGridLayout->setContentsMargins(0, 0, 0, 0);
        skyCultureTextBrowser = new QTextBrowser(skyCultureDetailsTab);
        skyCultureTextBrowser->setObjectName("skyCultureTextBrowser");
        sizePolicy4.setHeightForWidth(skyCultureTextBrowser->sizePolicy().hasHeightForWidth());
        skyCultureTextBrowser->setSizePolicy(sizePolicy4);
        skyCultureTextBrowser->setFrameShape(QFrame::StyledPanel);
        skyCultureTextBrowser->setVerticalScrollBarPolicy(Qt::ScrollBarAsNeeded);
        skyCultureTextBrowser->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
        skyCultureTextBrowser->setOpenExternalLinks(true);

        skyCultureDetailsPageGridLayout->addWidget(skyCultureTextBrowser, 0, 0, 1, 1);

        skyCultureOptionsGroupBox = new QGroupBox(skyCultureDetailsTab);
        skyCultureOptionsGroupBox->setObjectName("skyCultureOptionsGroupBox");
        skyCultureOptionsGroupBox->setEnabled(true);
        QSizePolicy sizePolicy11(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);
        sizePolicy11.setHorizontalStretch(0);
        sizePolicy11.setVerticalStretch(0);
        sizePolicy11.setHeightForWidth(skyCultureOptionsGroupBox->sizePolicy().hasHeightForWidth());
        skyCultureOptionsGroupBox->setSizePolicy(sizePolicy11);
        formLayout_2 = new QGridLayout(skyCultureOptionsGroupBox);
        formLayout_2->setObjectName("formLayout_2");
        formLayout_2->setContentsMargins(0, 0, 0, 0);
        gridLayout_CulturalLabeling = new QGridLayout();
        gridLayout_CulturalLabeling->setObjectName("gridLayout_CulturalLabeling");
        useAsDefaultSkyCultureCheckBox = new QCheckBox(skyCultureOptionsGroupBox);
        useAsDefaultSkyCultureCheckBox->setObjectName("useAsDefaultSkyCultureCheckBox");

        gridLayout_CulturalLabeling->addWidget(useAsDefaultSkyCultureCheckBox, 0, 0, 1, 5);

        pushButtonSkyculture_say = new QPushButton(skyCultureOptionsGroupBox);
        pushButtonSkyculture_say->setObjectName("pushButtonSkyculture_say");
        pushButtonSkyculture_say->setIcon(icon10);

        gridLayout_CulturalLabeling->addWidget(pushButtonSkyculture_say, 0, 6, 1, 1);

        pushButtonSkyculture_stop = new QPushButton(skyCultureOptionsGroupBox);
        pushButtonSkyculture_stop->setObjectName("pushButtonSkyculture_stop");
        pushButtonSkyculture_stop->setIcon(icon11);

        gridLayout_CulturalLabeling->addWidget(pushButtonSkyculture_stop, 0, 7, 1, 1);

        labelInfoLabel2 = new QLabel(skyCultureOptionsGroupBox);
        labelInfoLabel2->setObjectName("labelInfoLabel2");

        gridLayout_CulturalLabeling->addWidget(labelInfoLabel2, 1, 0, 1, 1);

        labelScreenLabel2 = new QLabel(skyCultureOptionsGroupBox);
        labelScreenLabel2->setObjectName("labelScreenLabel2");

        gridLayout_CulturalLabeling->addWidget(labelScreenLabel2, 2, 0, 1, 1);

        screenLabelTranslationCheckBox = new QCheckBox(skyCultureOptionsGroupBox);
        screenLabelTranslationCheckBox->setObjectName("screenLabelTranslationCheckBox");
        sizePolicy2.setHeightForWidth(screenLabelTranslationCheckBox->sizePolicy().hasHeightForWidth());
        screenLabelTranslationCheckBox->setSizePolicy(sizePolicy2);

        gridLayout_CulturalLabeling->addWidget(screenLabelTranslationCheckBox, 2, 5, 1, 1);

        infoLabelTranslationCheckBox = new QCheckBox(skyCultureOptionsGroupBox);
        infoLabelTranslationCheckBox->setObjectName("infoLabelTranslationCheckBox");
        sizePolicy2.setHeightForWidth(infoLabelTranslationCheckBox->sizePolicy().hasHeightForWidth());
        infoLabelTranslationCheckBox->setSizePolicy(sizePolicy2);

        gridLayout_CulturalLabeling->addWidget(infoLabelTranslationCheckBox, 1, 5, 1, 1);

        screenLabelPronounceCheckBox = new QCheckBox(skyCultureOptionsGroupBox);
        screenLabelPronounceCheckBox->setObjectName("screenLabelPronounceCheckBox");
        sizePolicy2.setHeightForWidth(screenLabelPronounceCheckBox->sizePolicy().hasHeightForWidth());
        screenLabelPronounceCheckBox->setSizePolicy(sizePolicy2);

        gridLayout_CulturalLabeling->addWidget(screenLabelPronounceCheckBox, 2, 2, 1, 1);

        screenLabelModernCheckBox = new QCheckBox(skyCultureOptionsGroupBox);
        screenLabelModernCheckBox->setObjectName("screenLabelModernCheckBox");
        sizePolicy2.setHeightForWidth(screenLabelModernCheckBox->sizePolicy().hasHeightForWidth());
        screenLabelModernCheckBox->setSizePolicy(sizePolicy2);

        gridLayout_CulturalLabeling->addWidget(screenLabelModernCheckBox, 2, 7, 1, 1);

        screenLabelTransliterationCheckBox = new QCheckBox(skyCultureOptionsGroupBox);
        screenLabelTransliterationCheckBox->setObjectName("screenLabelTransliterationCheckBox");
        sizePolicy2.setHeightForWidth(screenLabelTransliterationCheckBox->sizePolicy().hasHeightForWidth());
        screenLabelTransliterationCheckBox->setSizePolicy(sizePolicy2);

        gridLayout_CulturalLabeling->addWidget(screenLabelTransliterationCheckBox, 2, 3, 1, 1);

        infoLabelNativeCheckBox = new QCheckBox(skyCultureOptionsGroupBox);
        infoLabelNativeCheckBox->setObjectName("infoLabelNativeCheckBox");
        sizePolicy2.setHeightForWidth(infoLabelNativeCheckBox->sizePolicy().hasHeightForWidth());
        infoLabelNativeCheckBox->setSizePolicy(sizePolicy2);

        gridLayout_CulturalLabeling->addWidget(infoLabelNativeCheckBox, 1, 1, 1, 1);

        infoLabelTransliterationCheckBox = new QCheckBox(skyCultureOptionsGroupBox);
        infoLabelTransliterationCheckBox->setObjectName("infoLabelTransliterationCheckBox");
        sizePolicy2.setHeightForWidth(infoLabelTransliterationCheckBox->sizePolicy().hasHeightForWidth());
        infoLabelTransliterationCheckBox->setSizePolicy(sizePolicy2);

        gridLayout_CulturalLabeling->addWidget(infoLabelTransliterationCheckBox, 1, 3, 1, 1);

        infoLabelIPACheckBox = new QCheckBox(skyCultureOptionsGroupBox);
        infoLabelIPACheckBox->setObjectName("infoLabelIPACheckBox");
        sizePolicy2.setHeightForWidth(infoLabelIPACheckBox->sizePolicy().hasHeightForWidth());
        infoLabelIPACheckBox->setSizePolicy(sizePolicy2);

        gridLayout_CulturalLabeling->addWidget(infoLabelIPACheckBox, 1, 4, 1, 1);

        screenLabelNativeCheckBox = new QCheckBox(skyCultureOptionsGroupBox);
        screenLabelNativeCheckBox->setObjectName("screenLabelNativeCheckBox");
        sizePolicy2.setHeightForWidth(screenLabelNativeCheckBox->sizePolicy().hasHeightForWidth());
        screenLabelNativeCheckBox->setSizePolicy(sizePolicy2);

        gridLayout_CulturalLabeling->addWidget(screenLabelNativeCheckBox, 2, 1, 1, 1);

        infoLabelPronounceCheckBox = new QCheckBox(skyCultureOptionsGroupBox);
        infoLabelPronounceCheckBox->setObjectName("infoLabelPronounceCheckBox");
        sizePolicy2.setHeightForWidth(infoLabelPronounceCheckBox->sizePolicy().hasHeightForWidth());
        infoLabelPronounceCheckBox->setSizePolicy(sizePolicy2);

        gridLayout_CulturalLabeling->addWidget(infoLabelPronounceCheckBox, 1, 2, 1, 1);

        screenLabelIPACheckBox = new QCheckBox(skyCultureOptionsGroupBox);
        screenLabelIPACheckBox->setObjectName("screenLabelIPACheckBox");
        sizePolicy2.setHeightForWidth(screenLabelIPACheckBox->sizePolicy().hasHeightForWidth());
        screenLabelIPACheckBox->setSizePolicy(sizePolicy2);

        gridLayout_CulturalLabeling->addWidget(screenLabelIPACheckBox, 2, 4, 1, 1);

        infoLabelModernCheckBox = new QCheckBox(skyCultureOptionsGroupBox);
        infoLabelModernCheckBox->setObjectName("infoLabelModernCheckBox");
        sizePolicy2.setHeightForWidth(infoLabelModernCheckBox->sizePolicy().hasHeightForWidth());
        infoLabelModernCheckBox->setSizePolicy(sizePolicy2);

        gridLayout_CulturalLabeling->addWidget(infoLabelModernCheckBox, 1, 7, 1, 1);

        infoLabelBynameCheckBox = new QCheckBox(skyCultureOptionsGroupBox);
        infoLabelBynameCheckBox->setObjectName("infoLabelBynameCheckBox");
        sizePolicy2.setHeightForWidth(infoLabelBynameCheckBox->sizePolicy().hasHeightForWidth());
        infoLabelBynameCheckBox->setSizePolicy(sizePolicy2);

        gridLayout_CulturalLabeling->addWidget(infoLabelBynameCheckBox, 1, 6, 1, 1);

        screenLabelBynameCheckBox = new QCheckBox(skyCultureOptionsGroupBox);
        screenLabelBynameCheckBox->setObjectName("screenLabelBynameCheckBox");
        sizePolicy2.setHeightForWidth(screenLabelBynameCheckBox->sizePolicy().hasHeightForWidth());
        screenLabelBynameCheckBox->setSizePolicy(sizePolicy2);

        gridLayout_CulturalLabeling->addWidget(screenLabelBynameCheckBox, 2, 6, 1, 1);


        formLayout_2->addLayout(gridLayout_CulturalLabeling, 3, 0, 1, 1);

        skyCultureGridLayout = new QGridLayout();
        skyCultureGridLayout->setObjectName("skyCultureGridLayout");
        horizontalSpacer_10 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        skyCultureGridLayout->addItem(horizontalSpacer_10, 4, 9, 1, 1);

        zodiacCheckBox = new QCheckBox(skyCultureOptionsGroupBox);
        zodiacCheckBox->setObjectName("zodiacCheckBox");

        skyCultureGridLayout->addWidget(zodiacCheckBox, 6, 1, 1, 2);

        constellationsFontSizeSpinBox = new QSpinBox(skyCultureOptionsGroupBox);
        constellationsFontSizeSpinBox->setObjectName("constellationsFontSizeSpinBox");
        constellationsFontSizeSpinBox->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        constellationsFontSizeSpinBox->setMinimum(8);
        constellationsFontSizeSpinBox->setMaximum(40);
        constellationsFontSizeSpinBox->setValue(14);

        skyCultureGridLayout->addWidget(constellationsFontSizeSpinBox, 1, 4, 1, 1);

        zodiacColorButton = new ColorButton(skyCultureOptionsGroupBox);
        zodiacColorButton->setObjectName("zodiacColorButton");

        skyCultureGridLayout->addWidget(zodiacColorButton, 6, 0, 1, 1);

        zodiacThicknessSpinBox = new QSpinBox(skyCultureOptionsGroupBox);
        zodiacThicknessSpinBox->setObjectName("zodiacThicknessSpinBox");
        zodiacThicknessSpinBox->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        zodiacThicknessSpinBox->setMinimum(1);
        zodiacThicknessSpinBox->setMaximum(5);

        skyCultureGridLayout->addWidget(zodiacThicknessSpinBox, 6, 4, 1, 1);

        asterismLinesFadeDurationDoubleSpinBox = new QDoubleSpinBox(skyCultureOptionsGroupBox);
        asterismLinesFadeDurationDoubleSpinBox->setObjectName("asterismLinesFadeDurationDoubleSpinBox");
        asterismLinesFadeDurationDoubleSpinBox->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        asterismLinesFadeDurationDoubleSpinBox->setDecimals(1);
        asterismLinesFadeDurationDoubleSpinBox->setMinimum(0.100000000000000);
        asterismLinesFadeDurationDoubleSpinBox->setMaximum(10.000000000000000);
        asterismLinesFadeDurationDoubleSpinBox->setSingleStep(0.100000000000000);

        skyCultureGridLayout->addWidget(asterismLinesFadeDurationDoubleSpinBox, 2, 11, 1, 1);

        showConstellationLabelsCheckBox = new QCheckBox(skyCultureOptionsGroupBox);
        showConstellationLabelsCheckBox->setObjectName("showConstellationLabelsCheckBox");
        sizePolicy2.setHeightForWidth(showConstellationLabelsCheckBox->sizePolicy().hasHeightForWidth());
        showConstellationLabelsCheckBox->setSizePolicy(sizePolicy2);

        skyCultureGridLayout->addWidget(showConstellationLabelsCheckBox, 1, 1, 1, 2);

        colorAsterismLines = new ColorButton(skyCultureOptionsGroupBox);
        colorAsterismLines->setObjectName("colorAsterismLines");

        skyCultureGridLayout->addWidget(colorAsterismLines, 2, 6, 1, 1);

        constellationHullsColorButton = new ColorButton(skyCultureOptionsGroupBox);
        constellationHullsColorButton->setObjectName("constellationHullsColorButton");

        skyCultureGridLayout->addWidget(constellationHullsColorButton, 4, 6, 1, 1);

        constellationPickCheckBox = new QCheckBox(skyCultureOptionsGroupBox);
        constellationPickCheckBox->setObjectName("constellationPickCheckBox");

        skyCultureGridLayout->addWidget(constellationPickCheckBox, 0, 10, 1, 2);

        constellationBoundariesThicknessSpinBox = new QSpinBox(skyCultureOptionsGroupBox);
        constellationBoundariesThicknessSpinBox->setObjectName("constellationBoundariesThicknessSpinBox");
        constellationBoundariesThicknessSpinBox->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        constellationBoundariesThicknessSpinBox->setMinimum(1);
        constellationBoundariesThicknessSpinBox->setMaximum(5);

        skyCultureGridLayout->addWidget(constellationBoundariesThicknessSpinBox, 4, 4, 1, 1);

        showAsterismLinesCheckBox = new QCheckBox(skyCultureOptionsGroupBox);
        showAsterismLinesCheckBox->setObjectName("showAsterismLinesCheckBox");
        sizePolicy2.setHeightForWidth(showAsterismLinesCheckBox->sizePolicy().hasHeightForWidth());
        showAsterismLinesCheckBox->setSizePolicy(sizePolicy2);

        skyCultureGridLayout->addWidget(showAsterismLinesCheckBox, 2, 7, 1, 2);

        colorRayHelpers = new ColorButton(skyCultureOptionsGroupBox);
        colorRayHelpers->setObjectName("colorRayHelpers");

        skyCultureGridLayout->addWidget(colorRayHelpers, 3, 6, 1, 1);

        constellationHullsCheckBox = new QCheckBox(skyCultureOptionsGroupBox);
        constellationHullsCheckBox->setObjectName("constellationHullsCheckBox");
        sizePolicy2.setHeightForWidth(constellationHullsCheckBox->sizePolicy().hasHeightForWidth());
        constellationHullsCheckBox->setSizePolicy(sizePolicy2);

        skyCultureGridLayout->addWidget(constellationHullsCheckBox, 4, 7, 1, 2);

        colorConstellationBoundaries = new ColorButton(skyCultureOptionsGroupBox);
        colorConstellationBoundaries->setObjectName("colorConstellationBoundaries");

        skyCultureGridLayout->addWidget(colorConstellationBoundaries, 4, 0, 1, 1);

        abbreviatedNamesCheckBox = new QCheckBox(skyCultureOptionsGroupBox);
        abbreviatedNamesCheckBox->setObjectName("abbreviatedNamesCheckBox");
        sizePolicy2.setHeightForWidth(abbreviatedNamesCheckBox->sizePolicy().hasHeightForWidth());
        abbreviatedNamesCheckBox->setSizePolicy(sizePolicy2);

        skyCultureGridLayout->addWidget(abbreviatedNamesCheckBox, 0, 1, 1, 5);

        colorAsterismLabels = new ColorButton(skyCultureOptionsGroupBox);
        colorAsterismLabels->setObjectName("colorAsterismLabels");

        skyCultureGridLayout->addWidget(colorAsterismLabels, 1, 6, 1, 1);

        showConstellationArtCheckBox = new QCheckBox(skyCultureOptionsGroupBox);
        showConstellationArtCheckBox->setObjectName("showConstellationArtCheckBox");
        sizePolicy2.setHeightForWidth(showConstellationArtCheckBox->sizePolicy().hasHeightForWidth());
        showConstellationArtCheckBox->setSizePolicy(sizePolicy2);

        skyCultureGridLayout->addWidget(showConstellationArtCheckBox, 3, 1, 1, 2);

        lunarSystemCheckBox = new QCheckBox(skyCultureOptionsGroupBox);
        lunarSystemCheckBox->setObjectName("lunarSystemCheckBox");

        skyCultureGridLayout->addWidget(lunarSystemCheckBox, 6, 7, 1, 2);

        constellationArtBrightnessSpinBox = new QDoubleSpinBox(skyCultureOptionsGroupBox);
        constellationArtBrightnessSpinBox->setObjectName("constellationArtBrightnessSpinBox");
        constellationArtBrightnessSpinBox->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        constellationArtBrightnessSpinBox->setMaximum(1.000000000000000);
        constellationArtBrightnessSpinBox->setSingleStep(0.050000000000000);

        skyCultureGridLayout->addWidget(constellationArtBrightnessSpinBox, 3, 4, 1, 1);

        showConstellationBoundariesCheckBox = new QCheckBox(skyCultureOptionsGroupBox);
        showConstellationBoundariesCheckBox->setObjectName("showConstellationBoundariesCheckBox");
        sizePolicy2.setHeightForWidth(showConstellationBoundariesCheckBox->sizePolicy().hasHeightForWidth());
        showConstellationBoundariesCheckBox->setSizePolicy(sizePolicy2);

        skyCultureGridLayout->addWidget(showConstellationBoundariesCheckBox, 4, 1, 1, 2);

        rayHelpersFadeDurationDoubleSpinBox = new QDoubleSpinBox(skyCultureOptionsGroupBox);
        rayHelpersFadeDurationDoubleSpinBox->setObjectName("rayHelpersFadeDurationDoubleSpinBox");
        rayHelpersFadeDurationDoubleSpinBox->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        rayHelpersFadeDurationDoubleSpinBox->setDecimals(1);
        rayHelpersFadeDurationDoubleSpinBox->setMinimum(0.100000000000000);
        rayHelpersFadeDurationDoubleSpinBox->setMaximum(10.000000000000000);
        rayHelpersFadeDurationDoubleSpinBox->setSingleStep(0.100000000000000);

        skyCultureGridLayout->addWidget(rayHelpersFadeDurationDoubleSpinBox, 3, 11, 1, 1);

        showConstellationLinesCheckBox = new QCheckBox(skyCultureOptionsGroupBox);
        showConstellationLinesCheckBox->setObjectName("showConstellationLinesCheckBox");
        sizePolicy2.setHeightForWidth(showConstellationLinesCheckBox->sizePolicy().hasHeightForWidth());
        showConstellationLinesCheckBox->setSizePolicy(sizePolicy2);

        skyCultureGridLayout->addWidget(showConstellationLinesCheckBox, 2, 1, 1, 2);

        namesFadeDurationDoubleSpinBox = new QDoubleSpinBox(skyCultureOptionsGroupBox);
        namesFadeDurationDoubleSpinBox->setObjectName("namesFadeDurationDoubleSpinBox");
        namesFadeDurationDoubleSpinBox->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        namesFadeDurationDoubleSpinBox->setDecimals(1);
        namesFadeDurationDoubleSpinBox->setMinimum(0.100000000000000);
        namesFadeDurationDoubleSpinBox->setMaximum(10.000000000000000);
        namesFadeDurationDoubleSpinBox->setSingleStep(0.100000000000000);

        skyCultureGridLayout->addWidget(namesFadeDurationDoubleSpinBox, 1, 5, 1, 1);

        constellationHullsThicknessSpinBox = new QSpinBox(skyCultureOptionsGroupBox);
        constellationHullsThicknessSpinBox->setObjectName("constellationHullsThicknessSpinBox");
        constellationHullsThicknessSpinBox->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        skyCultureGridLayout->addWidget(constellationHullsThicknessSpinBox, 4, 10, 1, 1);

        lunarSystemFadeDurationDoubleSpinBox = new QDoubleSpinBox(skyCultureOptionsGroupBox);
        lunarSystemFadeDurationDoubleSpinBox->setObjectName("lunarSystemFadeDurationDoubleSpinBox");
        lunarSystemFadeDurationDoubleSpinBox->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        lunarSystemFadeDurationDoubleSpinBox->setDecimals(1);
        lunarSystemFadeDurationDoubleSpinBox->setMinimum(0.100000000000000);
        lunarSystemFadeDurationDoubleSpinBox->setMaximum(10.000000000000000);
        lunarSystemFadeDurationDoubleSpinBox->setSingleStep(0.100000000000000);

        skyCultureGridLayout->addWidget(lunarSystemFadeDurationDoubleSpinBox, 6, 11, 1, 1);

        asterismNamesFadeDurationDoubleSpinBox = new QDoubleSpinBox(skyCultureOptionsGroupBox);
        asterismNamesFadeDurationDoubleSpinBox->setObjectName("asterismNamesFadeDurationDoubleSpinBox");
        asterismNamesFadeDurationDoubleSpinBox->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        asterismNamesFadeDurationDoubleSpinBox->setDecimals(1);
        asterismNamesFadeDurationDoubleSpinBox->setMinimum(0.100000000000000);
        asterismNamesFadeDurationDoubleSpinBox->setMaximum(10.000000000000000);
        asterismNamesFadeDurationDoubleSpinBox->setSingleStep(0.100000000000000);

        skyCultureGridLayout->addWidget(asterismNamesFadeDurationDoubleSpinBox, 1, 11, 1, 1);

        lunarSystemThicknessSpinBox = new QSpinBox(skyCultureOptionsGroupBox);
        lunarSystemThicknessSpinBox->setObjectName("lunarSystemThicknessSpinBox");
        lunarSystemThicknessSpinBox->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        lunarSystemThicknessSpinBox->setMinimum(1);
        lunarSystemThicknessSpinBox->setMaximum(5);

        skyCultureGridLayout->addWidget(lunarSystemThicknessSpinBox, 6, 10, 1, 1);

        showRayHelpersCheckBox = new QCheckBox(skyCultureOptionsGroupBox);
        showRayHelpersCheckBox->setObjectName("showRayHelpersCheckBox");
        sizePolicy2.setHeightForWidth(showRayHelpersCheckBox->sizePolicy().hasHeightForWidth());
        showRayHelpersCheckBox->setSizePolicy(sizePolicy2);

        skyCultureGridLayout->addWidget(showRayHelpersCheckBox, 3, 7, 1, 2);

        artFadeDurationDoubleSpinBox = new QDoubleSpinBox(skyCultureOptionsGroupBox);
        artFadeDurationDoubleSpinBox->setObjectName("artFadeDurationDoubleSpinBox");
        artFadeDurationDoubleSpinBox->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        artFadeDurationDoubleSpinBox->setDecimals(1);
        artFadeDurationDoubleSpinBox->setMinimum(0.100000000000000);
        artFadeDurationDoubleSpinBox->setMaximum(10.000000000000000);
        artFadeDurationDoubleSpinBox->setSingleStep(0.100000000000000);

        skyCultureGridLayout->addWidget(artFadeDurationDoubleSpinBox, 3, 5, 1, 1);

        colorConstellationLabels = new ColorButton(skyCultureOptionsGroupBox);
        colorConstellationLabels->setObjectName("colorConstellationLabels");

        skyCultureGridLayout->addWidget(colorConstellationLabels, 1, 0, 1, 1);

        constellationHullsFadeDurationDoubleSpinBox = new QDoubleSpinBox(skyCultureOptionsGroupBox);
        constellationHullsFadeDurationDoubleSpinBox->setObjectName("constellationHullsFadeDurationDoubleSpinBox");
        constellationHullsFadeDurationDoubleSpinBox->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        constellationHullsFadeDurationDoubleSpinBox->setDecimals(1);
        constellationHullsFadeDurationDoubleSpinBox->setMinimum(0.100000000000000);
        constellationHullsFadeDurationDoubleSpinBox->setMaximum(10.000000000000000);
        constellationHullsFadeDurationDoubleSpinBox->setSingleStep(0.100000000000000);
        constellationHullsFadeDurationDoubleSpinBox->setValue(0.100000000000000);

        skyCultureGridLayout->addWidget(constellationHullsFadeDurationDoubleSpinBox, 4, 11, 1, 1);

        asterismLineThicknessSpinBox = new QSpinBox(skyCultureOptionsGroupBox);
        asterismLineThicknessSpinBox->setObjectName("asterismLineThicknessSpinBox");
        asterismLineThicknessSpinBox->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        asterismLineThicknessSpinBox->setMinimum(1);
        asterismLineThicknessSpinBox->setMaximum(5);

        skyCultureGridLayout->addWidget(asterismLineThicknessSpinBox, 2, 10, 1, 1);

        colorConstellationLines = new ColorButton(skyCultureOptionsGroupBox);
        colorConstellationLines->setObjectName("colorConstellationLines");

        skyCultureGridLayout->addWidget(colorConstellationLines, 2, 0, 1, 1);

        constellationLineThicknessSpinBox = new QSpinBox(skyCultureOptionsGroupBox);
        constellationLineThicknessSpinBox->setObjectName("constellationLineThicknessSpinBox");
        constellationLineThicknessSpinBox->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        constellationLineThicknessSpinBox->setMinimum(1);
        constellationLineThicknessSpinBox->setMaximum(5);

        skyCultureGridLayout->addWidget(constellationLineThicknessSpinBox, 2, 4, 1, 1);

        selectSingleConstellationCheckBox = new QCheckBox(skyCultureOptionsGroupBox);
        selectSingleConstellationCheckBox->setObjectName("selectSingleConstellationCheckBox");
        sizePolicy2.setHeightForWidth(selectSingleConstellationCheckBox->sizePolicy().hasHeightForWidth());
        selectSingleConstellationCheckBox->setSizePolicy(sizePolicy2);

        skyCultureGridLayout->addWidget(selectSingleConstellationCheckBox, 0, 7, 1, 2);

        showAsterismLabelsCheckBox = new QCheckBox(skyCultureOptionsGroupBox);
        showAsterismLabelsCheckBox->setObjectName("showAsterismLabelsCheckBox");
        sizePolicy2.setHeightForWidth(showAsterismLabelsCheckBox->sizePolicy().hasHeightForWidth());
        showAsterismLabelsCheckBox->setSizePolicy(sizePolicy2);

        skyCultureGridLayout->addWidget(showAsterismLabelsCheckBox, 1, 7, 1, 2);

        zodiacFadeDurationDoubleSpinBox = new QDoubleSpinBox(skyCultureOptionsGroupBox);
        zodiacFadeDurationDoubleSpinBox->setObjectName("zodiacFadeDurationDoubleSpinBox");
        zodiacFadeDurationDoubleSpinBox->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        zodiacFadeDurationDoubleSpinBox->setDecimals(1);
        zodiacFadeDurationDoubleSpinBox->setMinimum(0.100000000000000);
        zodiacFadeDurationDoubleSpinBox->setMaximum(10.000000000000000);
        zodiacFadeDurationDoubleSpinBox->setSingleStep(0.100000000000000);
        zodiacFadeDurationDoubleSpinBox->setValue(0.100000000000000);

        skyCultureGridLayout->addWidget(zodiacFadeDurationDoubleSpinBox, 6, 5, 1, 1);

        asterismsFontSizeSpinBox = new QSpinBox(skyCultureOptionsGroupBox);
        asterismsFontSizeSpinBox->setObjectName("asterismsFontSizeSpinBox");
        asterismsFontSizeSpinBox->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        asterismsFontSizeSpinBox->setMinimum(8);
        asterismsFontSizeSpinBox->setMaximum(40);
        asterismsFontSizeSpinBox->setValue(14);

        skyCultureGridLayout->addWidget(asterismsFontSizeSpinBox, 1, 10, 1, 1);

        rayHelperThicknessSpinBox = new QSpinBox(skyCultureOptionsGroupBox);
        rayHelperThicknessSpinBox->setObjectName("rayHelperThicknessSpinBox");
        rayHelperThicknessSpinBox->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        rayHelperThicknessSpinBox->setMinimum(1);
        rayHelperThicknessSpinBox->setMaximum(5);

        skyCultureGridLayout->addWidget(rayHelperThicknessSpinBox, 3, 10, 1, 1);

        lunarSystemColorButton = new ColorButton(skyCultureOptionsGroupBox);
        lunarSystemColorButton->setObjectName("lunarSystemColorButton");

        skyCultureGridLayout->addWidget(lunarSystemColorButton, 6, 6, 1, 1);

        horizontalSpacer_9 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        skyCultureGridLayout->addItem(horizontalSpacer_9, 4, 3, 1, 1);

        linesFadeDurationDoubleSpinBox = new QDoubleSpinBox(skyCultureOptionsGroupBox);
        linesFadeDurationDoubleSpinBox->setObjectName("linesFadeDurationDoubleSpinBox");
        linesFadeDurationDoubleSpinBox->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        linesFadeDurationDoubleSpinBox->setDecimals(1);
        linesFadeDurationDoubleSpinBox->setMinimum(0.100000000000000);
        linesFadeDurationDoubleSpinBox->setMaximum(10.000000000000000);
        linesFadeDurationDoubleSpinBox->setSingleStep(0.100000000000000);

        skyCultureGridLayout->addWidget(linesFadeDurationDoubleSpinBox, 2, 5, 1, 1);

        boundariesFadeDurationDoubleSpinBox = new QDoubleSpinBox(skyCultureOptionsGroupBox);
        boundariesFadeDurationDoubleSpinBox->setObjectName("boundariesFadeDurationDoubleSpinBox");
        boundariesFadeDurationDoubleSpinBox->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        boundariesFadeDurationDoubleSpinBox->setDecimals(1);
        boundariesFadeDurationDoubleSpinBox->setMinimum(0.100000000000000);
        boundariesFadeDurationDoubleSpinBox->setMaximum(10.000000000000000);
        boundariesFadeDurationDoubleSpinBox->setSingleStep(0.100000000000000);

        skyCultureGridLayout->addWidget(boundariesFadeDurationDoubleSpinBox, 4, 5, 1, 1);

        line_3 = new QFrame(skyCultureOptionsGroupBox);
        line_3->setObjectName("line_3");
        line_3->setMinimumSize(QSize(0, 1));
        line_3->setMaximumSize(QSize(16777215, 1));
        line_3->setFrameShape(QFrame::Shape::HLine);
        line_3->setFrameShadow(QFrame::Shadow::Sunken);

        skyCultureGridLayout->addWidget(line_3, 5, 0, 1, 12);

        zodiacLabelComboBox = new QComboBox(skyCultureOptionsGroupBox);
        zodiacLabelComboBox->setObjectName("zodiacLabelComboBox");

        skyCultureGridLayout->addWidget(zodiacLabelComboBox, 6, 3, 1, 1);

        lunarSystemLabelComboBox = new QComboBox(skyCultureOptionsGroupBox);
        lunarSystemLabelComboBox->setObjectName("lunarSystemLabelComboBox");

        skyCultureGridLayout->addWidget(lunarSystemLabelComboBox, 6, 9, 1, 1);


        formLayout_2->addLayout(skyCultureGridLayout, 6, 0, 2, 1);

        line_2 = new QFrame(skyCultureOptionsGroupBox);
        line_2->setObjectName("line_2");
        line_2->setMinimumSize(QSize(0, 1));
        line_2->setMaximumSize(QSize(16777215, 1));
        line_2->setFrameShape(QFrame::Shape::HLine);
        line_2->setFrameShadow(QFrame::Shadow::Sunken);

        formLayout_2->addWidget(line_2, 4, 0, 1, 1);


        skyCultureDetailsPageGridLayout->addWidget(skyCultureOptionsGroupBox, 1, 0, 1, 1);

        skyCultureTabWidget->addTab(skyCultureDetailsTab, QString());
        skyCultureMapTab = new QWidget();
        skyCultureMapTab->setObjectName("skyCultureMapTab");
        skyCultureMapPageGridLayout = new QGridLayout(skyCultureMapTab);
        skyCultureMapPageGridLayout->setSpacing(0);
        skyCultureMapPageGridLayout->setObjectName("skyCultureMapPageGridLayout");
        skyCultureMapPageGridLayout->setContentsMargins(0, 0, 0, 0);
        gridLayout_25 = new QGridLayout();
        gridLayout_25->setObjectName("gridLayout_25");
        gridLayout_25->setHorizontalSpacing(10);
        gridLayout_25->setVerticalSpacing(6);
        gridLayout_25->setContentsMargins(8, 8, 8, 0);
        skyCultureMapGraphicsView = new SkyCultureMapGraphicsView(skyCultureMapTab);
        skyCultureMapGraphicsView->setObjectName("skyCultureMapGraphicsView");

        gridLayout_25->addWidget(skyCultureMapGraphicsView, 0, 0, 1, 1);


        skyCultureMapPageGridLayout->addLayout(gridLayout_25, 0, 1, 1, 1);

        skyCultureTimeOptionsGroupBox = new QGroupBox(skyCultureMapTab);
        skyCultureTimeOptionsGroupBox->setObjectName("skyCultureTimeOptionsGroupBox");
        skyCultureTimeOptionsGroupBox->setEnabled(true);
        sizePolicy11.setHeightForWidth(skyCultureTimeOptionsGroupBox->sizePolicy().hasHeightForWidth());
        skyCultureTimeOptionsGroupBox->setSizePolicy(sizePolicy11);
        skyCultureTimeOptionsGridLayout = new QGridLayout(skyCultureTimeOptionsGroupBox);
        skyCultureTimeOptionsGridLayout->setObjectName("skyCultureTimeOptionsGridLayout");
        skyCultureTimeOptionsGridLayout->setVerticalSpacing(10);
        skyCultureTimeOptionsGridLayout->setContentsMargins(0, 0, 0, 0);
        skyCultureTimeSliderGridLayout = new QGridLayout();
        skyCultureTimeSliderGridLayout->setObjectName("skyCultureTimeSliderGridLayout");
        skyCultureTimeSliderGridLayout->setHorizontalSpacing(10);
        skyCultureCurrentTimeLabel = new QLabel(skyCultureTimeOptionsGroupBox);
        skyCultureCurrentTimeLabel->setObjectName("skyCultureCurrentTimeLabel");

        skyCultureTimeSliderGridLayout->addWidget(skyCultureCurrentTimeLabel, 0, 0, 1, 1);

        skyCultureTimeSlider = new QSlider(skyCultureTimeOptionsGroupBox);
        skyCultureTimeSlider->setObjectName("skyCultureTimeSlider");
        skyCultureTimeSlider->setMinimum(-2000);
        skyCultureTimeSlider->setMaximum(2000);
        skyCultureTimeSlider->setSingleStep(1);
        skyCultureTimeSlider->setOrientation(Qt::Horizontal);
        skyCultureTimeSlider->setTickPosition(QSlider::TickPosition::TicksBelow);
        skyCultureTimeSlider->setTickInterval(150);

        skyCultureTimeSliderGridLayout->addWidget(skyCultureTimeSlider, 0, 1, 1, 1);

        skyCultureCurrentTimeSpinBox = new QSpinBox(skyCultureTimeOptionsGroupBox);
        skyCultureCurrentTimeSpinBox->setObjectName("skyCultureCurrentTimeSpinBox");
        skyCultureCurrentTimeSpinBox->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        skyCultureCurrentTimeSpinBox->setMinimum(-2000);
        skyCultureCurrentTimeSpinBox->setMaximum(2000);

        skyCultureTimeSliderGridLayout->addWidget(skyCultureCurrentTimeSpinBox, 0, 2, 1, 1);


        skyCultureTimeOptionsGridLayout->addLayout(skyCultureTimeSliderGridLayout, 0, 0, 1, 1);

        skyCultureMinMaxTimeGridLayout = new QGridLayout();
        skyCultureMinMaxTimeGridLayout->setObjectName("skyCultureMinMaxTimeGridLayout");
        skyCultureMinMaxTimeGridLayout->setHorizontalSpacing(20);
        skyCultureMinMaxTimeGridLayout->setVerticalSpacing(10);
        skyCultureMinMaxTimeGridLayout->setContentsMargins(10, 0, 10, 0);
        skyCultureMinTimeLabel = new QLabel(skyCultureTimeOptionsGroupBox);
        skyCultureMinTimeLabel->setObjectName("skyCultureMinTimeLabel");
        sizePolicy5.setHeightForWidth(skyCultureMinTimeLabel->sizePolicy().hasHeightForWidth());
        skyCultureMinTimeLabel->setSizePolicy(sizePolicy5);

        skyCultureMinMaxTimeGridLayout->addWidget(skyCultureMinTimeLabel, 0, 0, 1, 1);

        skyCultureMinTimeSpinBox = new QSpinBox(skyCultureTimeOptionsGroupBox);
        skyCultureMinTimeSpinBox->setObjectName("skyCultureMinTimeSpinBox");
        skyCultureMinTimeSpinBox->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        skyCultureMinTimeSpinBox->setMinimum(-2000);
        skyCultureMinTimeSpinBox->setMaximum(2000);

        skyCultureMinMaxTimeGridLayout->addWidget(skyCultureMinTimeSpinBox, 0, 1, 1, 1);

        timeOptionsHorizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        skyCultureMinMaxTimeGridLayout->addItem(timeOptionsHorizontalSpacer, 0, 3, 4, 1);

        skyCultureMaxTimeLabel = new QLabel(skyCultureTimeOptionsGroupBox);
        skyCultureMaxTimeLabel->setObjectName("skyCultureMaxTimeLabel");
        sizePolicy5.setHeightForWidth(skyCultureMaxTimeLabel->sizePolicy().hasHeightForWidth());
        skyCultureMaxTimeLabel->setSizePolicy(sizePolicy5);

        skyCultureMinMaxTimeGridLayout->addWidget(skyCultureMaxTimeLabel, 0, 6, 1, 1);

        skyCultureMaxTimeSpinBox = new QSpinBox(skyCultureTimeOptionsGroupBox);
        skyCultureMaxTimeSpinBox->setObjectName("skyCultureMaxTimeSpinBox");
        skyCultureMaxTimeSpinBox->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        skyCultureMaxTimeSpinBox->setMinimum(-2000);
        skyCultureMaxTimeSpinBox->setMaximum(2000);

        skyCultureMinMaxTimeGridLayout->addWidget(skyCultureMaxTimeSpinBox, 0, 7, 1, 1);

        applyTimeOnListCheckBox = new QCheckBox(skyCultureTimeOptionsGroupBox);
        applyTimeOnListCheckBox->setObjectName("applyTimeOnListCheckBox");
        sizePolicy2.setHeightForWidth(applyTimeOnListCheckBox->sizePolicy().hasHeightForWidth());
        applyTimeOnListCheckBox->setSizePolicy(sizePolicy2);

        skyCultureMinMaxTimeGridLayout->addWidget(applyTimeOnListCheckBox, 2, 4, 1, 3);

        selectedCultureMinTimeLabel = new QLabel(skyCultureTimeOptionsGroupBox);
        selectedCultureMinTimeLabel->setObjectName("selectedCultureMinTimeLabel");

        skyCultureMinMaxTimeGridLayout->addWidget(selectedCultureMinTimeLabel, 2, 0, 1, 2);

        selectedCultureMinTimeValueLabel = new QLabel(skyCultureTimeOptionsGroupBox);
        selectedCultureMinTimeValueLabel->setObjectName("selectedCultureMinTimeValueLabel");
        selectedCultureMinTimeValueLabel->setText(QString::fromUtf8("0"));
        selectedCultureMinTimeValueLabel->setAlignment(Qt::AlignRight);

        skyCultureMinMaxTimeGridLayout->addWidget(selectedCultureMinTimeValueLabel, 2, 2, 1, 1);

        selectedCultureMaxTimeLabel = new QLabel(skyCultureTimeOptionsGroupBox);
        selectedCultureMaxTimeLabel->setObjectName("selectedCultureMaxTimeLabel");

        skyCultureMinMaxTimeGridLayout->addWidget(selectedCultureMaxTimeLabel, 3, 0, 1, 2);

        selectedCultureMaxTimeValueLabel = new QLabel(skyCultureTimeOptionsGroupBox);
        selectedCultureMaxTimeValueLabel->setObjectName("selectedCultureMaxTimeValueLabel");
        selectedCultureMaxTimeValueLabel->setText(QString::fromUtf8("0"));
        selectedCultureMaxTimeValueLabel->setAlignment(Qt::AlignRight);

        skyCultureMinMaxTimeGridLayout->addWidget(selectedCultureMaxTimeValueLabel, 3, 2, 1, 1);

        useLocationForRotationCheckBox = new QCheckBox(skyCultureTimeOptionsGroupBox);
        useLocationForRotationCheckBox->setObjectName("useLocationForRotationCheckBox");
        sizePolicy2.setHeightForWidth(useLocationForRotationCheckBox->sizePolicy().hasHeightForWidth());
        useLocationForRotationCheckBox->setSizePolicy(sizePolicy2);

        skyCultureMinMaxTimeGridLayout->addWidget(useLocationForRotationCheckBox, 3, 4, 1, 3);


        skyCultureTimeOptionsGridLayout->addLayout(skyCultureMinMaxTimeGridLayout, 1, 0, 1, 1);


        skyCultureMapPageGridLayout->addWidget(skyCultureTimeOptionsGroupBox, 1, 1, 1, 1);

        verticalLayout_5 = new QVBoxLayout();
        verticalLayout_5->setSpacing(5);
        verticalLayout_5->setObjectName("verticalLayout_5");
        verticalLayout_5->setContentsMargins(0, 0, 0, 5);
        culturesListWidget = new QListWidget(skyCultureMapTab);
        culturesListWidget->setObjectName("culturesListWidget");
        QSizePolicy sizePolicy12(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Expanding);
        sizePolicy12.setHorizontalStretch(100);
        sizePolicy12.setVerticalStretch(0);
        sizePolicy12.setHeightForWidth(culturesListWidget->sizePolicy().hasHeightForWidth());
        culturesListWidget->setSizePolicy(sizePolicy12);
        culturesListWidget->setFocusPolicy(Qt::NoFocus);
        culturesListWidget->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
        culturesListWidget->setSelectionRectVisible(false);

        verticalLayout_5->addWidget(culturesListWidget);

        culturesListSearchLineEdit = new QLineEdit(skyCultureMapTab);
        culturesListSearchLineEdit->setObjectName("culturesListSearchLineEdit");
        sizePolicy1.setHeightForWidth(culturesListSearchLineEdit->sizePolicy().hasHeightForWidth());
        culturesListSearchLineEdit->setSizePolicy(sizePolicy1);
        culturesListSearchLineEdit->setMinimumSize(QSize(0, 30));
        culturesListSearchLineEdit->setStyleSheet(QString::fromUtf8("\n"
"                    border: 5px solid rgb(47, 48, 50);\n"
"                    border-radius: 10px;\n"
"                    background-color: rgb(47, 48, 50);\n"
"                    padding-left: 28px;\n"
"                    padding-right: 10px;\n"
"                    background-image: url(:/graphicGui/uieSearchBoxBackground.png);\n"
"                    background-repeat: none;\n"
"                    background-position: left center;\n"
"                   "));
        culturesListSearchLineEdit->setContentsMargins(5, -1, 5, -1);

        verticalLayout_5->addWidget(culturesListSearchLineEdit);


        skyCultureMapPageGridLayout->addLayout(verticalLayout_5, 0, 0, 2, 1);

        skyCultureTabWidget->addTab(skyCultureMapTab, QString());

        gridLayout_4->addWidget(skyCultureTabWidget, 0, 0, 1, 1);

        stackedWidget->addWidget(page_skyCulture);
        page_surveys = new QWidget();
        page_surveys->setObjectName("page_surveys");
        gridLayout_21 = new QGridLayout(page_surveys);
        gridLayout_21->setSpacing(3);
        gridLayout_21->setObjectName("gridLayout_21");
        gridLayout_21->setContentsMargins(3, 3, 3, 3);
        surveysTextBrowser = new QTextBrowser(page_surveys);
        surveysTextBrowser->setObjectName("surveysTextBrowser");
        surveysTextBrowser->setOpenExternalLinks(true);

        gridLayout_21->addWidget(surveysTextBrowser, 0, 1, 3, 1);

        surveyTypeComboBox = new QComboBox(page_surveys);
        surveyTypeComboBox->setObjectName("surveyTypeComboBox");

        gridLayout_21->addWidget(surveyTypeComboBox, 0, 0, 1, 1);

        surveysFilter = new QLineEdit(page_surveys);
        surveysFilter->setObjectName("surveysFilter");
        surveysFilter->setClearButtonEnabled(true);

        gridLayout_21->addWidget(surveysFilter, 1, 0, 1, 1);

        surveysTreeWidget = new QTreeWidget(page_surveys);
        surveysTreeWidget->headerItem()->setText(0, QString());
        surveysTreeWidget->setObjectName("surveysTreeWidget");
        surveysTreeWidget->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
        surveysTreeWidget->setRootIsDecorated(false);
        surveysTreeWidget->setHeaderHidden(true);

        gridLayout_21->addWidget(surveysTreeWidget, 2, 0, 1, 1);

        stackedWidget->addWidget(page_surveys);

        gridLayout_8->addWidget(stackedWidget, 1, 0, 1, 1);


        vboxLayout->addWidget(viewContent);

        QWidget::setTabOrder(page_sky, starGroupBox);
        QWidget::setTabOrder(starGroupBox, starScaleRadiusDoubleSpinBox);
        QWidget::setTabOrder(starScaleRadiusDoubleSpinBox, starRelativeScaleDoubleSpinBox);
        QWidget::setTabOrder(starRelativeScaleDoubleSpinBox, starTwinkleCheckBox);
        QWidget::setTabOrder(starTwinkleCheckBox, starTwinkleAmountDoubleSpinBox);
        QWidget::setTabOrder(starTwinkleAmountDoubleSpinBox, starLimitMagnitudeCheckBox);
        QWidget::setTabOrder(starLimitMagnitudeCheckBox, starLimitMagnitudeDoubleSpinBox);
        QWidget::setTabOrder(starLimitMagnitudeDoubleSpinBox, starLabelCheckBox);
        QWidget::setTabOrder(starLabelCheckBox, starsLabelsHorizontalSlider);
        QWidget::setTabOrder(starsLabelsHorizontalSlider, milkyWayCheckBox);
        QWidget::setTabOrder(milkyWayCheckBox, milkyWayBrightnessDoubleSpinBox);
        QWidget::setTabOrder(milkyWayBrightnessDoubleSpinBox, zodiacalLightCheckBox);
        QWidget::setTabOrder(zodiacalLightCheckBox, zodiacalLightBrightnessDoubleSpinBox);
        QWidget::setTabOrder(zodiacalLightBrightnessDoubleSpinBox, adaptationCheckbox);
        QWidget::setTabOrder(adaptationCheckbox, zhrSlider);
        QWidget::setTabOrder(zhrSlider, zhrSpinBox);
        QWidget::setTabOrder(zhrSpinBox, page_DSO);
        QWidget::setTabOrder(page_DSO, checkBoxM);
        QWidget::setTabOrder(checkBoxM, checkBoxC);
        QWidget::setTabOrder(checkBoxC, checkBoxNGC);
        QWidget::setTabOrder(checkBoxNGC, checkBoxIC);
        QWidget::setTabOrder(checkBoxIC, checkBoxB);
        QWidget::setTabOrder(checkBoxB, checkBoxSh2);
        QWidget::setTabOrder(checkBoxSh2, checkBoxVdB);
        QWidget::setTabOrder(checkBoxVdB, checkBoxRCW);
        QWidget::setTabOrder(checkBoxRCW, checkBoxLBN);
        QWidget::setTabOrder(checkBoxLBN, checkBoxLDN);
        QWidget::setTabOrder(checkBoxLDN, checkBoxCr);
        QWidget::setTabOrder(checkBoxCr, checkBoxMel);
        QWidget::setTabOrder(checkBoxMel, checkBoxPGC);
        QWidget::setTabOrder(checkBoxPGC, checkBoxUGC);
        QWidget::setTabOrder(checkBoxUGC, checkBoxCed);
        QWidget::setTabOrder(checkBoxCed, checkBoxArp);
        QWidget::setTabOrder(checkBoxArp, checkBoxVV);
        QWidget::setTabOrder(checkBoxVV, checkBoxPK);
        QWidget::setTabOrder(checkBoxPK, checkBoxPNG);
        QWidget::setTabOrder(checkBoxPNG, checkBoxSNRG);
        QWidget::setTabOrder(checkBoxSNRG, checkBoxACO);
        QWidget::setTabOrder(checkBoxACO, groupBoxDSOTypeFilters);
        QWidget::setTabOrder(groupBoxDSOTypeFilters, checkBoxGalaxiesType);
        QWidget::setTabOrder(checkBoxGalaxiesType, checkBoxActiveGalaxiesType);
        QWidget::setTabOrder(checkBoxActiveGalaxiesType, checkBoxInteractingGalaxiesType);
        QWidget::setTabOrder(checkBoxInteractingGalaxiesType, checkBoxGalaxyClustersType);
        QWidget::setTabOrder(checkBoxGalaxyClustersType, checkBoxOpenStarClustersType);
        QWidget::setTabOrder(checkBoxOpenStarClustersType, checkBoxBrightNebulaeType);
        QWidget::setTabOrder(checkBoxBrightNebulaeType, checkBoxDarkNebulaeType);
        QWidget::setTabOrder(checkBoxDarkNebulaeType, checkBoxPlanetaryNebulaeType);
        QWidget::setTabOrder(checkBoxPlanetaryNebulaeType, checkBoxSupernovaRemnantsType);
        QWidget::setTabOrder(checkBoxSupernovaRemnantsType, checkBoxHydrogenRegionsType);
        QWidget::setTabOrder(checkBoxHydrogenRegionsType, groupBoxDSOLabelsAndMarkers);
        QWidget::setTabOrder(groupBoxDSOLabelsAndMarkers, nebulasLabelsHorizontalSlider);
        QWidget::setTabOrder(nebulasLabelsHorizontalSlider, nebulasHintsHorizontalSlider);
        QWidget::setTabOrder(nebulasHintsHorizontalSlider, checkBoxDesignationsOnlyUsage);
        QWidget::setTabOrder(checkBoxDesignationsOnlyUsage, checkBoxOutlines);
        QWidget::setTabOrder(checkBoxOutlines, checkBoxProportionalHints);
        QWidget::setTabOrder(checkBoxProportionalHints, checkBoxSurfaceBrightnessUsage);
        QWidget::setTabOrder(checkBoxSurfaceBrightnessUsage, nebulaLimitMagnitudeCheckBox);
        QWidget::setTabOrder(nebulaLimitMagnitudeCheckBox, nebulaLimitMagnitudeDoubleSpinBox);
        QWidget::setTabOrder(nebulaLimitMagnitudeDoubleSpinBox, pushButtonConfigureDSOColors);
        QWidget::setTabOrder(pushButtonConfigureDSOColors, page_markings);
        QWidget::setTabOrder(page_markings, celestialSphereGroupBox);
        QWidget::setTabOrder(celestialSphereGroupBox, showEquatorialJ2000GridCheckBox);
        QWidget::setTabOrder(showEquatorialJ2000GridCheckBox, showEquatorialGridCheckBox);
        QWidget::setTabOrder(showEquatorialGridCheckBox, showEclipticGridJ2000CheckBox);
        QWidget::setTabOrder(showEclipticGridJ2000CheckBox, showEclipticGridOfDateCheckBox);
        QWidget::setTabOrder(showEclipticGridOfDateCheckBox, showAzimuthalGridCheckBox);
        QWidget::setTabOrder(showAzimuthalGridCheckBox, showGalacticGridCheckBox);
        QWidget::setTabOrder(showGalacticGridCheckBox, showSupergalacticGridCheckBox);
        QWidget::setTabOrder(showSupergalacticGridCheckBox, showEquinoxJ2000PointsCheckBox);
        QWidget::setTabOrder(showEquinoxJ2000PointsCheckBox, showEquinoxPointsCheckBox);
        QWidget::setTabOrder(showEquinoxPointsCheckBox, showSolsticeJ2000PointsCheckBox);
        QWidget::setTabOrder(showSolsticeJ2000PointsCheckBox, showSolsticePointsCheckBox);
        QWidget::setTabOrder(showSolsticePointsCheckBox, page_landscape);
        QWidget::setTabOrder(page_landscape, landscapesListWidget);
        QWidget::setTabOrder(landscapesListWidget, landscapeTextBrowser);
        QWidget::setTabOrder(landscapeTextBrowser, landscapeBrightnessCheckBox);
        QWidget::setTabOrder(landscapeBrightnessCheckBox, landscapeBrightnessSpinBox);
        QWidget::setTabOrder(landscapeBrightnessSpinBox, landscapeLabelsCheckBox);
        QWidget::setTabOrder(landscapeLabelsCheckBox, landscapeIlluminationCheckBox);
        QWidget::setTabOrder(landscapeIlluminationCheckBox, pushButtonAddRemoveLandscapes);
        QWidget::setTabOrder(pushButtonAddRemoveLandscapes, useAsDefaultSkyCultureCheckBox);
        QWidget::setTabOrder(useAsDefaultSkyCultureCheckBox, showConstellationLabelsCheckBox);
        QWidget::setTabOrder(showConstellationLabelsCheckBox, constellationsFontSizeSpinBox);
        QWidget::setTabOrder(constellationsFontSizeSpinBox, selectSingleConstellationCheckBox);
        QWidget::setTabOrder(selectSingleConstellationCheckBox, showConstellationLinesCheckBox);
        QWidget::setTabOrder(showConstellationLinesCheckBox, constellationLineThicknessSpinBox);
        QWidget::setTabOrder(constellationLineThicknessSpinBox, showConstellationArtCheckBox);
        QWidget::setTabOrder(showConstellationArtCheckBox, constellationArtBrightnessSpinBox);
        QWidget::setTabOrder(constellationArtBrightnessSpinBox, constellationBoundariesThicknessSpinBox);
        QWidget::setTabOrder(constellationBoundariesThicknessSpinBox, showAsterismLabelsCheckBox);
        QWidget::setTabOrder(showAsterismLabelsCheckBox, asterismsFontSizeSpinBox);
        QWidget::setTabOrder(asterismsFontSizeSpinBox, showAsterismLinesCheckBox);
        QWidget::setTabOrder(showAsterismLinesCheckBox, asterismLineThicknessSpinBox);
        QWidget::setTabOrder(asterismLineThicknessSpinBox, showRayHelpersCheckBox);
        QWidget::setTabOrder(showRayHelpersCheckBox, rayHelperThicknessSpinBox);

        retranslateUi(viewDialogForm);

        stackedWidget->setCurrentIndex(0);
        skyCultureTabWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(viewDialogForm);
    } // setupUi

    void retranslateUi(QWidget *viewDialogForm)
    {
        titleBar->setProperty("title", QVariant(QCoreApplication::translate("viewDialogForm", "View", nullptr)));

        const bool __sortingEnabled = stackListWidget->isSortingEnabled();
        stackListWidget->setSortingEnabled(false);
        QListWidgetItem *___qlistwidgetitem = stackListWidget->item(0);
        ___qlistwidgetitem->setText(QCoreApplication::translate("viewDialogForm", "Sky", nullptr));
        QListWidgetItem *___qlistwidgetitem1 = stackListWidget->item(1);
        ___qlistwidgetitem1->setText(QCoreApplication::translate("viewDialogForm", "SSO", "Solar system objects"));
#if QT_CONFIG(tooltip)
        ___qlistwidgetitem1->setToolTip(QCoreApplication::translate("viewDialogForm", "Solar system objects", nullptr));
#endif // QT_CONFIG(tooltip)
        QListWidgetItem *___qlistwidgetitem2 = stackListWidget->item(2);
        ___qlistwidgetitem2->setText(QCoreApplication::translate("viewDialogForm", "DSO", "Deep-Sky Objects"));
#if QT_CONFIG(tooltip)
        ___qlistwidgetitem2->setToolTip(QCoreApplication::translate("viewDialogForm", "Deep-Sky Objects", nullptr));
#endif // QT_CONFIG(tooltip)
        QListWidgetItem *___qlistwidgetitem3 = stackListWidget->item(3);
        ___qlistwidgetitem3->setText(QCoreApplication::translate("viewDialogForm", "Markings", nullptr));
        QListWidgetItem *___qlistwidgetitem4 = stackListWidget->item(4);
        ___qlistwidgetitem4->setText(QCoreApplication::translate("viewDialogForm", "Landscape", nullptr));
        QListWidgetItem *___qlistwidgetitem5 = stackListWidget->item(5);
        ___qlistwidgetitem5->setText(QCoreApplication::translate("viewDialogForm", "Sky Culture", nullptr));
        QListWidgetItem *___qlistwidgetitem6 = stackListWidget->item(6);
        ___qlistwidgetitem6->setText(QCoreApplication::translate("viewDialogForm", "Surveys", nullptr));
        stackListWidget->setSortingEnabled(__sortingEnabled);

        largeObjectsGroupbox->setTitle(QCoreApplication::translate("viewDialogForm", "Sky", nullptr));
        zhrLabel->setText(QString());
#if QT_CONFIG(tooltip)
        zhrSlider->setToolTip(QCoreApplication::translate("viewDialogForm", "The zenithal hourly rate for the sporadic meteors", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        zhrSpinBox->setToolTip(QCoreApplication::translate("viewDialogForm", "The zenithal hourly rate for the sporadic meteors", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        label_14->setToolTip(QCoreApplication::translate("viewDialogForm", "Settings for sporadic meteors", nullptr));
#endif // QT_CONFIG(tooltip)
        label_14->setText(QCoreApplication::translate("viewDialogForm", "Shooting stars:", "Zenithal Hourly Rate"));
        twilightLabel->setText(QCoreApplication::translate("viewDialogForm", "Solar altitude for Twilight Finder:", nullptr));
        atmosphereCheckBox->setText(QCoreApplication::translate("viewDialogForm", "Atmosphere visualization", nullptr));
#if QT_CONFIG(tooltip)
        pushButtonAtmosphereDetails->setToolTip(QCoreApplication::translate("viewDialogForm", "Atmosphere settings: visual model, pressure, temperature, extinction coefficient, etc.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        pushButtonSkylightDetails->setToolTip(QCoreApplication::translate("viewDialogForm", "Open skylight details (color tweaks for the atmosphere)", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        tonemappingPushButton->setToolTip(QCoreApplication::translate("viewDialogForm", "Open tone mapping details.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        milkyWaySaturationDoubleSpinBox->setToolTip(QCoreApplication::translate("viewDialogForm", "Changing saturation from totally unsaturated (0.00) to default (1.00) value.", nullptr));
#endif // QT_CONFIG(tooltip)
        label_4->setText(QCoreApplication::translate("viewDialogForm", "Light pollution:", nullptr));
        zodiacalLightCheckBox->setText(QCoreApplication::translate("viewDialogForm", "Zodiacal Light brightness:", nullptr));
        milkyWayCheckBox->setText(QCoreApplication::translate("viewDialogForm", "Milky Way brightness/saturation:", nullptr));
#if QT_CONFIG(tooltip)
        adaptationCheckbox->setToolTip(QCoreApplication::translate("viewDialogForm", "Dim faint stars when a very bright object is visible", nullptr));
#endif // QT_CONFIG(tooltip)
        adaptationCheckbox->setText(QCoreApplication::translate("viewDialogForm", "Dynamic eye adaptation", nullptr));
        starGroupBox->setTitle(QCoreApplication::translate("viewDialogForm", "Stars", nullptr));
        label_5->setText(QCoreApplication::translate("viewDialogForm", "Absolute scale:", nullptr));
#if QT_CONFIG(tooltip)
        starTwinkleAmountDoubleSpinBox->setToolTip(QCoreApplication::translate("viewDialogForm", "Twinkle amount (magnitudes) along horizon (less in zenith)", nullptr));
#endif // QT_CONFIG(tooltip)
        starTwinkleCheckBox->setText(QCoreApplication::translate("viewDialogForm", "Twinkle:", nullptr));
        starLabelCheckBox->setText(QCoreApplication::translate("viewDialogForm", "Labels and Markers", nullptr));
#if QT_CONFIG(tooltip)
        checkBoxAdditionalNamesStars->setToolTip(QCoreApplication::translate("viewDialogForm", "Show all available proper names", nullptr));
#endif // QT_CONFIG(tooltip)
        checkBoxAdditionalNamesStars->setText(QCoreApplication::translate("viewDialogForm", "Show additional star names", nullptr));
#if QT_CONFIG(tooltip)
        checkBoxStarDesignationsOnlyUsage->setToolTip(QCoreApplication::translate("viewDialogForm", "Use designations of stars instead of their common names for screen labels", nullptr));
#endif // QT_CONFIG(tooltip)
        checkBoxStarDesignationsOnlyUsage->setText(QCoreApplication::translate("viewDialogForm", "Use designations for screen labels", nullptr));
#if QT_CONFIG(tooltip)
        starLimitMagnitudeCheckBox->setToolTip(QCoreApplication::translate("viewDialogForm", "Limit the magnitude of stars", nullptr));
#endif // QT_CONFIG(tooltip)
        starLimitMagnitudeCheckBox->setText(QCoreApplication::translate("viewDialogForm", "Limit magnitude:", nullptr));
        label_7->setText(QCoreApplication::translate("viewDialogForm", "Relative scale:", nullptr));
#if QT_CONFIG(tooltip)
        dblStarsDesignationsCheckBox->setToolTip(QCoreApplication::translate("viewDialogForm", "Show traditional designations of double stars if proper name, Bayer or Flamsteed designations do not exist for the star.", nullptr));
#endif // QT_CONFIG(tooltip)
        dblStarsDesignationsCheckBox->setText(QCoreApplication::translate("viewDialogForm", "Dbl. stars", "double stars"));
#if QT_CONFIG(tooltip)
        varStarsDesignationsCheckBox->setToolTip(QCoreApplication::translate("viewDialogForm", "Show designations of variable stars if proper name, Bayer or Flamsteed designations, or designation of double star do not exist for the star.", nullptr));
#endif // QT_CONFIG(tooltip)
        varStarsDesignationsCheckBox->setText(QCoreApplication::translate("viewDialogForm", "Var. stars", "variable stars"));
#if QT_CONFIG(tooltip)
        hipDesignationsCheckBox->setToolTip(QCoreApplication::translate("viewDialogForm", "Show designations from Hipparcos catalog (HIP) if available and star doesn't have other traditional designations.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        spikyStarsCheckBox->setToolTip(QCoreApplication::translate("viewDialogForm", "Show stars with pointed rays", nullptr));
#endif // QT_CONFIG(tooltip)
        spikyStarsCheckBox->setText(QCoreApplication::translate("viewDialogForm", "Spiky stars", nullptr));
#if QT_CONFIG(tooltip)
        starTwinkleWithoutAtmosphereCheckBox->setToolTip(QCoreApplication::translate("viewDialogForm", "Twinkle is caused by atmospheric turbulence. This option forces its display regardless of atmosphere (for artistic purpose).", nullptr));
#endif // QT_CONFIG(tooltip)
        starTwinkleWithoutAtmosphereCheckBox->setText(QCoreApplication::translate("viewDialogForm", "even without atmosphere", nullptr));
        setProjectionGroupBox->setTitle(QCoreApplication::translate("viewDialogForm", "Projection", nullptr));
        currentFovLabel->setText(QCoreApplication::translate("viewDialogForm", "Current FoV", nullptr));
        viewportOffsetLabel->setText(QCoreApplication::translate("viewDialogForm", "Vertical viewport offset", nullptr));
        userMaxFovLabel->setText(QCoreApplication::translate("viewDialogForm", "Custom FoV limit", nullptr));
#if QT_CONFIG(tooltip)
        userMaxFovSpinBox->setToolTip(QCoreApplication::translate("viewDialogForm", "Additional custom limitation (e.g. for planetarium use)", nullptr));
#endif // QT_CONFIG(tooltip)
        planetsGroupBox->setTitle(QCoreApplication::translate("viewDialogForm", "Solar System objects", nullptr));
        planetLabelCheckBox->setText(QCoreApplication::translate("viewDialogForm", "Labels and Markers", nullptr));
#if QT_CONFIG(tooltip)
        planetLabelColor->setToolTip(QCoreApplication::translate("viewDialogForm", "Color of planet labels", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        planetDetailsLabel->setToolTip(QCoreApplication::translate("viewDialogForm", "Planets magnitude algorithm", nullptr));
#endif // QT_CONFIG(tooltip)
        planetDetailsLabel->setText(QCoreApplication::translate("viewDialogForm", "Planets magnitude algorithm:", nullptr));
#if QT_CONFIG(tooltip)
        planetTrailsColor->setToolTip(QCoreApplication::translate("viewDialogForm", "Color of trails", nullptr));
#endif // QT_CONFIG(tooltip)
        planetTrailsCheckBox->setText(QCoreApplication::translate("viewDialogForm", "Show trails", nullptr));
#if QT_CONFIG(tooltip)
        planetTrailsThicknessSpinBox->setToolTip(QCoreApplication::translate("viewDialogForm", "Trails thickness in pixels", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        shadowEnlargementDanjonCheckBox->setToolTip(QCoreApplication::translate("viewDialogForm", "Astronomical Almanac (default) has 2% enlargement, Danjon (1951) uses a slightly different model", nullptr));
#endif // QT_CONFIG(tooltip)
        shadowEnlargementDanjonCheckBox->setText(QCoreApplication::translate("viewDialogForm", "Earth shadow enlargement after Danjon", nullptr));
#if QT_CONFIG(tooltip)
        planetLimitMagnitudeCheckBox->setToolTip(QCoreApplication::translate("viewDialogForm", "Limit the magnitude of solar system objects", nullptr));
#endif // QT_CONFIG(tooltip)
        planetLimitMagnitudeCheckBox->setText(QCoreApplication::translate("viewDialogForm", "Limit magnitude:", nullptr));
        planetOrbitCheckBox->setText(QCoreApplication::translate("viewDialogForm", "Show orbits", nullptr));
#if QT_CONFIG(tooltip)
        planetOrbitPermanentCheckBox->setToolTip(QCoreApplication::translate("viewDialogForm", "Show orbit even if object is off screen", nullptr));
#endif // QT_CONFIG(tooltip)
        planetOrbitPermanentCheckBox->setText(QCoreApplication::translate("viewDialogForm", "permanently", nullptr));
#if QT_CONFIG(tooltip)
        planetOrbitMajorPlanetsCheckBox->setToolTip(QCoreApplication::translate("viewDialogForm", "Show orbits of major planets", nullptr));
#endif // QT_CONFIG(tooltip)
        planetOrbitMajorPlanetsCheckBox->setText(QCoreApplication::translate("viewDialogForm", "Major planets", nullptr));
#if QT_CONFIG(tooltip)
        pushButtonOrbitColors->setToolTip(QCoreApplication::translate("viewDialogForm", "Configure colors of orbit lines", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        planetOrbitsThicknessSpinBox->setToolTip(QCoreApplication::translate("viewDialogForm", "Orbits thickness in pixels", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        planetNomenclatureColor->setToolTip(QCoreApplication::translate("viewDialogForm", "Color of nomenclature labels", nullptr));
#endif // QT_CONFIG(tooltip)
        planetNomenclatureColor->setText(QString());
#if QT_CONFIG(tooltip)
        planetNomenclatureCheckBox->setToolTip(QCoreApplication::translate("viewDialogForm", "Show hints and labels for planetary features", nullptr));
#endif // QT_CONFIG(tooltip)
        planetNomenclatureCheckBox->setText(QCoreApplication::translate("viewDialogForm", "Show planetary nomenclature", nullptr));
#if QT_CONFIG(tooltip)
        planetIsolatedTrailsCheckBox->setToolTip(QCoreApplication::translate("viewDialogForm", "Deactivate this option if you want to see the trails for all Solar system bodies.", nullptr));
#endif // QT_CONFIG(tooltip)
        planetIsolatedTrailsCheckBox->setText(QCoreApplication::translate("viewDialogForm", "Only for N latest selected objects:", nullptr));
#if QT_CONFIG(tooltip)
        planetOrbitOnlyCheckBox->setToolTip(QCoreApplication::translate("viewDialogForm", "Hide orbits of minor bodies.", nullptr));
#endif // QT_CONFIG(tooltip)
        planetOrbitOnlyCheckBox->setText(QCoreApplication::translate("viewDialogForm", "Only orbits of major planets...", nullptr));
#if QT_CONFIG(tooltip)
        planetIsolatedOrbitCheckBox->setToolTip(QCoreApplication::translate("viewDialogForm", "Show orbit only for selected SSO", nullptr));
#endif // QT_CONFIG(tooltip)
        planetIsolatedOrbitCheckBox->setText(QCoreApplication::translate("viewDialogForm", "Only orbit for selected object...", nullptr));
#if QT_CONFIG(tooltip)
        planetOrbitsMoonCheckBox->setToolTip(QCoreApplication::translate("viewDialogForm", "Also show moons of selected object or planets.", nullptr));
#endif // QT_CONFIG(tooltip)
        planetOrbitsMoonCheckBox->setText(QCoreApplication::translate("viewDialogForm", "... and moons", nullptr));
        planetMarkerCheckBox->setText(QCoreApplication::translate("viewDialogForm", "Planet markers", nullptr));
#if QT_CONFIG(tooltip)
        drawSunCoronaCheckBox->setToolTip(QCoreApplication::translate("viewDialogForm", "Toggle permanent drawing of Sun's corona when atmosphere is disabled", nullptr));
#endif // QT_CONFIG(tooltip)
        drawSunCoronaCheckBox->setText(QCoreApplication::translate("viewDialogForm", "Sun's corona", nullptr));
#if QT_CONFIG(tooltip)
        drawMoonHaloCheckBox->setToolTip(QCoreApplication::translate("viewDialogForm", "Toggle drawing halo around the Moon", nullptr));
#endif // QT_CONFIG(tooltip)
        drawMoonHaloCheckBox->setText(QCoreApplication::translate("viewDialogForm", "Moon's halo", nullptr));
        labelShow->setText(QCoreApplication::translate("viewDialogForm", "Show:", nullptr));
#if QT_CONFIG(tooltip)
        drawSunGlareCheckBox->setToolTip(QCoreApplication::translate("viewDialogForm", "Toggle drawing Sun's glare", nullptr));
#endif // QT_CONFIG(tooltip)
        drawSunGlareCheckBox->setText(QCoreApplication::translate("viewDialogForm", "Sun's glare", nullptr));
#if QT_CONFIG(tooltip)
        minorPlanetMarkersCheckBox->setToolTip(QCoreApplication::translate("viewDialogForm", "Show tiny circles for minor bodies regardless of magnitude", nullptr));
#endif // QT_CONFIG(tooltip)
        minorPlanetMarkersCheckBox->setText(QCoreApplication::translate("viewDialogForm", "Mark minor bodies", nullptr));
#if QT_CONFIG(tooltip)
        minorPlanetMarkerMagThresholdSpinBox->setToolTip(QCoreApplication::translate("viewDialogForm", "Draw markers for objects with magnitude brighter than this", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        planetUseObjModelsCheckBox->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
        planetUseObjModelsCheckBox->setText(QCoreApplication::translate("viewDialogForm", "Use more accurate 3D models (where available)", nullptr));
#if QT_CONFIG(tooltip)
        planetLightSpeedCheckBox->setToolTip(QCoreApplication::translate("viewDialogForm", "Activate this option to simulate the effect of real speed of light (recommended).", nullptr));
#endif // QT_CONFIG(tooltip)
        planetLightSpeedCheckBox->setText(QCoreApplication::translate("viewDialogForm", "Simulate light speed", nullptr));
#if QT_CONFIG(tooltip)
        pushButtonGrsDetails->setToolTip(QCoreApplication::translate("viewDialogForm", "Jupiter's Great Red Spot...", nullptr));
#endif // QT_CONFIG(tooltip)
        pushButtonGrsDetails->setText(QCoreApplication::translate("viewDialogForm", "GRS details...", nullptr));
        pushButtonSSE->setText(QCoreApplication::translate("viewDialogForm", "Solar System Editor...", nullptr));
        planetScalePlanetsCheckBox->setText(QCoreApplication::translate("viewDialogForm", "Planets", "scale"));
        planetScaleMinorBodyCheckBox->setText(QCoreApplication::translate("viewDialogForm", "Minor bodies", "scale"));
#if QT_CONFIG(tooltip)
        moonScaleFactor->setToolTip(QCoreApplication::translate("viewDialogForm", "Scale factor", nullptr));
#endif // QT_CONFIG(tooltip)
        planetScaleSunCheckBox->setText(QCoreApplication::translate("viewDialogForm", "Sun", "scale"));
        labelScale->setText(QCoreApplication::translate("viewDialogForm", "Scale:", nullptr));
        planetScaleMoonCheckBox->setText(QCoreApplication::translate("viewDialogForm", "Moon", "scale"));
#if QT_CONFIG(tooltip)
        moonScaleDynamicCheckBox->setToolTip(QCoreApplication::translate("viewDialogForm", "When enabled, the Moon scales smoothly between 1\303\227 (natural size) at the minimum FOV and the configured scale factor at the maximum FOV. Outside those bounds the scale is held constant.", nullptr));
#endif // QT_CONFIG(tooltip)
        moonScaleDynamicCheckBox->setText(QCoreApplication::translate("viewDialogForm", "Dynamic (FOV-based) Moon size", nullptr));
#if QT_CONFIG(tooltip)
        moonScaleMinFovLabel->setToolTip(QCoreApplication::translate("viewDialogForm", "FOV at and below which the Moon is drawn at 1\303\227 (natural) size.", nullptr));
#endif // QT_CONFIG(tooltip)
        moonScaleMinFovLabel->setText(QCoreApplication::translate("viewDialogForm", "1\303\227 below", nullptr));
#if QT_CONFIG(tooltip)
        moonScaleMinFovSpinBox->setToolTip(QCoreApplication::translate("viewDialogForm", "FOV at and below which the Moon is drawn at 1\303\227 (natural) size.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        moonScaleMaxFovLabel->setToolTip(QCoreApplication::translate("viewDialogForm", "FOV at and above which the Moon is drawn at the configured scale factor.", nullptr));
#endif // QT_CONFIG(tooltip)
        moonScaleMaxFovLabel->setText(QCoreApplication::translate("viewDialogForm", "Nx above", nullptr));
#if QT_CONFIG(tooltip)
        moonScaleMaxFovSpinBox->setToolTip(QCoreApplication::translate("viewDialogForm", "FOV at and above which the Moon is drawn at the configured scale factor.", nullptr));
#endif // QT_CONFIG(tooltip)
        hidePlanetNomenclatureCheckBox->setText(QCoreApplication::translate("viewDialogForm", "Hide nomenclature on the celestial body of observer", nullptr));
#if QT_CONFIG(tooltip)
        showTerminatorNomenclatureOnlyCheckBox->setToolTip(QCoreApplication::translate("viewDialogForm", "Label only features along the terminator", nullptr));
#endif // QT_CONFIG(tooltip)
        showTerminatorNomenclatureOnlyCheckBox->setText(QCoreApplication::translate("viewDialogForm", "Only for Solar elevation", nullptr));
#if QT_CONFIG(tooltip)
        terminatorMinAltSpinbox->setToolTip(QCoreApplication::translate("viewDialogForm", "Minimum Solar altitude", nullptr));
#endif // QT_CONFIG(tooltip)
        labelTerminator->setText(QCoreApplication::translate("viewDialogForm", "...", nullptr));
#if QT_CONFIG(tooltip)
        terminatorMaxAltSpinbox->setToolTip(QCoreApplication::translate("viewDialogForm", "Maximum Solar altitude", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        outlineCratersCheckBox->setToolTip(QCoreApplication::translate("viewDialogForm", "Mark impact features with ellipses", nullptr));
#endif // QT_CONFIG(tooltip)
        outlineCratersCheckBox->setText(QCoreApplication::translate("viewDialogForm", "Outline craters", nullptr));
#if QT_CONFIG(tooltip)
        showSpecialNomenclatureOnlyCheckBox->setToolTip(QCoreApplication::translate("viewDialogForm", "Show special nomenclature points only", nullptr));
#endif // QT_CONFIG(tooltip)
        showSpecialNomenclatureOnlyCheckBox->setText(QCoreApplication::translate("viewDialogForm", "Special points only", nullptr));
#if QT_CONFIG(tooltip)
        planetShowObjSelfShadowsCheckBox->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
        planetShowObjSelfShadowsCheckBox->setText(QCoreApplication::translate("viewDialogForm", "Simulate self-shadowing", nullptr));
        groupDSOCatalogs->setTitle(QCoreApplication::translate("viewDialogForm", "Display objects from catalogs", nullptr));
        label->setText(QCoreApplication::translate("viewDialogForm", "Quick selection:", nullptr));
#if QT_CONFIG(tooltip)
        selectAllCatalogs->setToolTip(QCoreApplication::translate("viewDialogForm", "Select all catalogs", nullptr));
#endif // QT_CONFIG(tooltip)
        selectAllCatalogs->setText(QCoreApplication::translate("viewDialogForm", "select all", nullptr));
#if QT_CONFIG(tooltip)
        selectStandardCatalogs->setToolTip(QCoreApplication::translate("viewDialogForm", "Select standard catalogs (NGC/IC and M)", nullptr));
#endif // QT_CONFIG(tooltip)
        selectStandardCatalogs->setText(QCoreApplication::translate("viewDialogForm", "select standard", nullptr));
        selectPreferredCatalogs->setText(QCoreApplication::translate("viewDialogForm", "select preference", nullptr));
        storePreferredCatalogs->setText(QCoreApplication::translate("viewDialogForm", "store preference", nullptr));
#if QT_CONFIG(tooltip)
        selectNoneCatalogs->setToolTip(QCoreApplication::translate("viewDialogForm", "Deselect all catalogs", nullptr));
#endif // QT_CONFIG(tooltip)
        selectNoneCatalogs->setText(QCoreApplication::translate("viewDialogForm", "select none", nullptr));
#if QT_CONFIG(tooltip)
        checkBoxArp->setToolTip(QCoreApplication::translate("viewDialogForm", "Atlas of Peculiar Galaxies (Arp, 1966)", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        checkBoxUGC->setToolTip(QCoreApplication::translate("viewDialogForm", "The Uppsala General Catalogue of Galaxies", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        checkBoxLBN->setToolTip(QCoreApplication::translate("viewDialogForm", "Lynds' Catalogue of Bright Nebulae (Lynds, 1965)", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        checkBoxRCW->setToolTip(QCoreApplication::translate("viewDialogForm", "A catalogue of H\316\261-emission regions in the southern Milky Way (Rodgers+, 1960)", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        checkBoxSh2->setToolTip(QCoreApplication::translate("viewDialogForm", "Catalogue of HII Regions (Sharpless, 1959)", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        checkBoxNGC->setToolTip(QCoreApplication::translate("viewDialogForm", "New General Catalogue of Nebulae and Clusters of Stars", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        checkBoxSt->setToolTip(QCoreApplication::translate("viewDialogForm", "Stock Catalogue", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        checkBoxRu->setToolTip(QCoreApplication::translate("viewDialogForm", "Ruprecht Catalogue", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        checkBoxACO->setToolTip(QCoreApplication::translate("viewDialogForm", "A Catalog of Rich Clusters of Galaxies (Abell+, 1989)", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        checkBoxMel->setToolTip(QCoreApplication::translate("viewDialogForm", "A Catalogue of Star Clusters shown on Franklin-Adams Chart Plates (Melotte, 1915)", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        checkBoxVV->setToolTip(QCoreApplication::translate("viewDialogForm", "The Catalogue of Interacting Galaxies (Vorontsov-Velyaminov+, 2001)", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        checkBoxVdB->setToolTip(QCoreApplication::translate("viewDialogForm", "Catalogue of Reflection Nebulae (van den Bergh, 1966)", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        checkBoxPK->setToolTip(QCoreApplication::translate("viewDialogForm", "The Catalogue of Galactic Planetary Nebulae (Kohoutek, 2001)", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        checkBoxCr->setToolTip(QCoreApplication::translate("viewDialogForm", "Catalog of Open Galactic Clusters (Collinder, 1931)", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        checkBoxVdBH->setToolTip(QCoreApplication::translate("viewDialogForm", "Catalogue of southern stars embedded in nebulosity (van den Bergh and Herbst, 1975)", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        checkBoxHCG->setToolTip(QCoreApplication::translate("viewDialogForm", "Hickson Compact Group (Hickson+, 1982)", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        checkBoxPNG->setToolTip(QCoreApplication::translate("viewDialogForm", "The Strasbourg-ESO Catalogue of Galactic Planetary Nebulae (Acker+, 1992)", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        checkBoxDWB->setToolTip(QCoreApplication::translate("viewDialogForm", "Catalogue and distances of optically visible H II regions (Dickel+, 1969)", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        checkBoxESO->setToolTip(QCoreApplication::translate("viewDialogForm", "ESO/Uppsala Survey of the ESO(B) Atlas (Lauberts, 1982)", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        checkBoxSNRG->setToolTip(QCoreApplication::translate("viewDialogForm", "A catalogue of Galactic supernova remnants (Green, 2014)", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        checkBoxLDN->setToolTip(QCoreApplication::translate("viewDialogForm", "Lynds' Catalogue of Dark Nebulae (Lynds, 1962)", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        checkBoxB->setToolTip(QCoreApplication::translate("viewDialogForm", "Barnard's Catalogue of 349 Dark Objects in the Sky (Barnard, 1927)", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        checkBoxIC->setToolTip(QCoreApplication::translate("viewDialogForm", "Index Catalogue of Nebulae and Clusters of Stars", nullptr));
#endif // QT_CONFIG(tooltip)
        checkBoxOther->setText(QCoreApplication::translate("viewDialogForm", "Other", "other catalogs"));
#if QT_CONFIG(tooltip)
        checkBoxPGC->setToolTip(QCoreApplication::translate("viewDialogForm", "Principal Galaxy Catalog", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        checkBoxCed->setToolTip(QCoreApplication::translate("viewDialogForm", "Catalog of bright diffuse Galactic nebulae (Cederblad, 1946)", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        checkBoxVdBHa->setToolTip(QCoreApplication::translate("viewDialogForm", "van den Bergh-Hagen Catalogue (Uniform survey of clusters in the Southern Milky Way; van den Bergh and Hagen, 1975)", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        checkBoxM->setToolTip(QCoreApplication::translate("viewDialogForm", "Messier Catalogue", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        checkBoxTr->setToolTip(QCoreApplication::translate("viewDialogForm", "Trumpler Catalogue", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        checkBoxC->setToolTip(QCoreApplication::translate("viewDialogForm", "Caldwell Catalogue", nullptr));
#endif // QT_CONFIG(tooltip)
        groupBoxDSOTypeFilters->setTitle(QCoreApplication::translate("viewDialogForm", "Filter by type", nullptr));
        checkBoxActiveGalaxiesType->setText(QCoreApplication::translate("viewDialogForm", "Active galaxies", nullptr));
        checkBoxPlanetaryNebulaeType->setText(QCoreApplication::translate("viewDialogForm", "Planetary nebulae", nullptr));
        checkBoxBrightNebulaeType->setText(QCoreApplication::translate("viewDialogForm", "Bright nebulae", nullptr));
        checkBoxDarkNebulaeType->setText(QCoreApplication::translate("viewDialogForm", "Dark nebulae", nullptr));
        checkBoxHydrogenRegionsType->setText(QCoreApplication::translate("viewDialogForm", "Hydrogen regions", nullptr));
        checkBoxGalaxyClustersType->setText(QCoreApplication::translate("viewDialogForm", "Clusters of galaxies", nullptr));
        checkBoxGalaxiesType->setText(QCoreApplication::translate("viewDialogForm", "Galaxies", nullptr));
        checkBoxInteractingGalaxiesType->setText(QCoreApplication::translate("viewDialogForm", "Interacting galaxies", nullptr));
        checkBoxSupernovaRemnantsType->setText(QCoreApplication::translate("viewDialogForm", "Supernova remnants", nullptr));
        checkBoxOpenStarClustersType->setText(QCoreApplication::translate("viewDialogForm", "Open star clusters", nullptr));
        checkBoxOtherType->setText(QCoreApplication::translate("viewDialogForm", "Other", nullptr));
        checkBoxGlobularStarClustersType->setText(QCoreApplication::translate("viewDialogForm", "Globular star clusters", nullptr));
        groupBoxDSOLabelsAndMarkers->setTitle(QCoreApplication::translate("viewDialogForm", "Labels and Markers", nullptr));
#if QT_CONFIG(tooltip)
        checkBoxDesignationsOnlyUsage->setToolTip(QCoreApplication::translate("viewDialogForm", "Use designations of deep-sky objects instead of their common names for screen labels", nullptr));
#endif // QT_CONFIG(tooltip)
        checkBoxDesignationsOnlyUsage->setText(QCoreApplication::translate("viewDialogForm", "Use designations for screen labels", nullptr));
        checkBoxAdditionalNamesDSO->setText(QCoreApplication::translate("viewDialogForm", "Use additional names of DSO", nullptr));
        checkBoxShowOnlyNamedDSO->setText(QCoreApplication::translate("viewDialogForm", "Show only named DSO", nullptr));
        checkBoxOutlines->setText(QCoreApplication::translate("viewDialogForm", "Use outlines for big deep-sky objects", nullptr));
#if QT_CONFIG(tooltip)
        checkBoxProportionalHints->setToolTip(QCoreApplication::translate("viewDialogForm", "Use hints proportional to angular size of deep-sky objects", nullptr));
#endif // QT_CONFIG(tooltip)
        checkBoxProportionalHints->setText(QCoreApplication::translate("viewDialogForm", "Use proportional hints", nullptr));
        labelLabels->setText(QCoreApplication::translate("viewDialogForm", "Labels", nullptr));
#if QT_CONFIG(tooltip)
        labelsBrightnessDoubleSpinBox->setToolTip(QCoreApplication::translate("viewDialogForm", "Brightness", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        hintsBrightnessDoubleSpinBox->setToolTip(QCoreApplication::translate("viewDialogForm", "Brightness", nullptr));
#endif // QT_CONFIG(tooltip)
        labelHints->setText(QCoreApplication::translate("viewDialogForm", "Hints", nullptr));
#if QT_CONFIG(tooltip)
        checkBoxSurfaceBrightnessUsage->setToolTip(QCoreApplication::translate("viewDialogForm", "Use surface brightness of deep-sky objects for scale of the visibility of their markers and labels.", nullptr));
#endif // QT_CONFIG(tooltip)
        checkBoxSurfaceBrightnessUsage->setText(QCoreApplication::translate("viewDialogForm", "Use surface brightness", nullptr));
        pushButtonConfigureDSOColors->setText(QCoreApplication::translate("viewDialogForm", "Configure colors of markers", nullptr));
#if QT_CONFIG(tooltip)
        nebulaLimitSizeCheckBox->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
        nebulaLimitSizeCheckBox->setText(QCoreApplication::translate("viewDialogForm", "Limit angular size:", nullptr));
#if QT_CONFIG(tooltip)
        nebulaLimitSizeMaxDoubleSpinBox->setToolTip(QCoreApplication::translate("viewDialogForm", "Maximum angular size in arcminutes for visible DSO", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        nebulaLimitMagnitudeCheckBox->setToolTip(QCoreApplication::translate("viewDialogForm", "Limit magnitude (for unaided/binocular observers) of deep-sky objects.", nullptr));
#endif // QT_CONFIG(tooltip)
        nebulaLimitMagnitudeCheckBox->setText(QCoreApplication::translate("viewDialogForm", "Limit magnitude:", nullptr));
#if QT_CONFIG(tooltip)
        nebulaLimitSizeMinDoubleSpinBox->setToolTip(QCoreApplication::translate("viewDialogForm", "Minimal angular size in arcminutes for visible DSO", nullptr));
#endif // QT_CONFIG(tooltip)
        celestialSphereGroupBox->setTitle(QCoreApplication::translate("viewDialogForm", "Celestial Sphere", nullptr));
#if QT_CONFIG(tooltip)
        showApexPointsCheckBox->setToolTip(QCoreApplication::translate("viewDialogForm", "Apex and Antapex indicate where the observer's planet is heading to or receding from, respectively.", nullptr));
#endif // QT_CONFIG(tooltip)
        showApexPointsCheckBox->setText(QCoreApplication::translate("viewDialogForm", "Apex points", nullptr));
#if QT_CONFIG(tooltip)
        solarEquatorPartsCheckBox->setToolTip(QCoreApplication::translate("viewDialogForm", "Show partitions", nullptr));
#endif // QT_CONFIG(tooltip)
        solarEquatorPartsCheckBox->setText(QString());
#if QT_CONFIG(tooltip)
        currentVerticalPartsCheckBox->setToolTip(QCoreApplication::translate("viewDialogForm", "Show partitions", nullptr));
#endif // QT_CONFIG(tooltip)
        currentVerticalPartsCheckBox->setText(QString());
#if QT_CONFIG(tooltip)
        colureLabelsCheckBox->setToolTip(QCoreApplication::translate("viewDialogForm", "Label partitions", nullptr));
#endif // QT_CONFIG(tooltip)
        colureLabelsCheckBox->setText(QString());
#if QT_CONFIG(tooltip)
        colorGalacticCenter->setToolTip(QCoreApplication::translate("viewDialogForm", "Color of galactic center and anticenter", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        colorCircumpolarCircles->setToolTip(QCoreApplication::translate("viewDialogForm", "Color of circumpolar circles", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        galacticEquatorLabel->setToolTip(QCoreApplication::translate("viewDialogForm", "Show Galactic equator line.", nullptr));
#endif // QT_CONFIG(tooltip)
        galacticEquatorLabel->setText(QCoreApplication::translate("viewDialogForm", "Galactic equator", nullptr));
#if QT_CONFIG(tooltip)
        showUmbraCheckBox->setToolTip(QCoreApplication::translate("viewDialogForm", "This circle represents the size of Earth's central, deep shadow in the distance of the Moon. Will not show when Moon scaling is enabled!", nullptr));
#endif // QT_CONFIG(tooltip)
        showUmbraCheckBox->setText(QCoreApplication::translate("viewDialogForm", "Earth umbra", nullptr));
#if QT_CONFIG(tooltip)
        showUmbraCenterCheckBox->setToolTip(QCoreApplication::translate("viewDialogForm", "Show center point of Earth's shadow in the distance of the Moon.", nullptr));
#endif // QT_CONFIG(tooltip)
        showUmbraCenterCheckBox->setText(QString());
#if QT_CONFIG(tooltip)
        colorSolsticePoints->setToolTip(QCoreApplication::translate("viewDialogForm", "Color of the solstice points (of date)", nullptr));
#endif // QT_CONFIG(tooltip)
        colorSolsticePoints->setText(QString());
#if QT_CONFIG(tooltip)
        colorEquinoxPoints->setToolTip(QCoreApplication::translate("viewDialogForm", "Color of the equinox points (of date)", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        colorUmbraCircle->setToolTip(QCoreApplication::translate("viewDialogForm", "Color of umbra circle", nullptr));
#endif // QT_CONFIG(tooltip)
        colorUmbraCircle->setText(QString());
#if QT_CONFIG(tooltip)
        fixedEquatorLabelsCheckBox->setToolTip(QCoreApplication::translate("viewDialogForm", "Label partitions", nullptr));
#endif // QT_CONFIG(tooltip)
        fixedEquatorLabelsCheckBox->setText(QString());
#if QT_CONFIG(tooltip)
        primeVerticalPartsCheckBox->setToolTip(QCoreApplication::translate("viewDialogForm", "Show partitions", nullptr));
#endif // QT_CONFIG(tooltip)
        primeVerticalPartsCheckBox->setText(QString());
#if QT_CONFIG(tooltip)
        colorAntisolarPoint->setToolTip(QCoreApplication::translate("viewDialogForm", "Color of antisolar point", nullptr));
#endif // QT_CONFIG(tooltip)
        colorAntisolarPoint->setText(QString());
#if QT_CONFIG(tooltip)
        colureLabel->setToolTip(QCoreApplication::translate("viewDialogForm", "Show colures (great circles through poles and solstices/equinoxes).", nullptr));
#endif // QT_CONFIG(tooltip)
        colureLabel->setText(QCoreApplication::translate("viewDialogForm", "Colures", nullptr));
#if QT_CONFIG(tooltip)
        galacticEquatorPartsCheckBox->setToolTip(QCoreApplication::translate("viewDialogForm", "Show partitions", nullptr));
#endif // QT_CONFIG(tooltip)
        galacticEquatorPartsCheckBox->setText(QString());
#if QT_CONFIG(tooltip)
        solarEquatorLabelsCheckBox->setToolTip(QCoreApplication::translate("viewDialogForm", "Label partitions", nullptr));
#endif // QT_CONFIG(tooltip)
        solarEquatorLabelsCheckBox->setText(QString());
        showEquinoxJ2000PointsCheckBox->setText(QCoreApplication::translate("viewDialogForm", "Equinoxes (J2000)", nullptr));
#if QT_CONFIG(tooltip)
        showEclipticGridOfDateCheckBox->setToolTip(QCoreApplication::translate("viewDialogForm", "Ecliptical coordinates for current date. Displayed on Earth only.", nullptr));
#endif // QT_CONFIG(tooltip)
        showEclipticGridOfDateCheckBox->setText(QCoreApplication::translate("viewDialogForm", "Ecliptic grid (of date)", nullptr));
        showEquinoxPointsCheckBox->setText(QCoreApplication::translate("viewDialogForm", "Equinoxes (of date)", nullptr));
#if QT_CONFIG(tooltip)
        colorHorizonLine->setToolTip(QCoreApplication::translate("viewDialogForm", "Color of horizon", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        colurePartsCheckBox->setToolTip(QCoreApplication::translate("viewDialogForm", "Show partitions", nullptr));
#endif // QT_CONFIG(tooltip)
        colurePartsCheckBox->setText(QString());
#if QT_CONFIG(tooltip)
        showEclipticLineOfDateCheckBox->setToolTip(QCoreApplication::translate("viewDialogForm", "Show line", nullptr));
#endif // QT_CONFIG(tooltip)
        showEclipticLineOfDateCheckBox->setText(QString());
#if QT_CONFIG(tooltip)
        showEclipticPolesCheckBox->setToolTip(QCoreApplication::translate("viewDialogForm", "Show ecliptic poles of current date.", nullptr));
#endif // QT_CONFIG(tooltip)
        showEclipticPolesCheckBox->setText(QCoreApplication::translate("viewDialogForm", "Ecliptic poles (of date)", nullptr));
#if QT_CONFIG(tooltip)
        colorSupergalacticEquatorLine->setToolTip(QCoreApplication::translate("viewDialogForm", "Color of supergalactic equator", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        colorGalacticGrid->setToolTip(QCoreApplication::translate("viewDialogForm", "Color of the galactic grid", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        currentVerticalLabelsCheckBox->setToolTip(QCoreApplication::translate("viewDialogForm", "Label partitions", nullptr));
#endif // QT_CONFIG(tooltip)
        currentVerticalLabelsCheckBox->setText(QString());
#if QT_CONFIG(tooltip)
        showInvariablePlaneCheckBox->setToolTip(QCoreApplication::translate("viewDialogForm", "A plane perpendicular to the angular momentum vector of the Solar system.", nullptr));
#endif // QT_CONFIG(tooltip)
        showInvariablePlaneCheckBox->setText(QCoreApplication::translate("viewDialogForm", "Invariable plane of the Solar system", nullptr));
#if QT_CONFIG(tooltip)
        colorSupergalacticPoles->setToolTip(QCoreApplication::translate("viewDialogForm", "Color of supergalactic poles", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        precessionPartsCheckBox->setToolTip(QCoreApplication::translate("viewDialogForm", "Show partitions", nullptr));
#endif // QT_CONFIG(tooltip)
        precessionPartsCheckBox->setText(QString());
#if QT_CONFIG(tooltip)
        meridianLabelsCheckBox->setToolTip(QCoreApplication::translate("viewDialogForm", "Label partitions", nullptr));
#endif // QT_CONFIG(tooltip)
        meridianLabelsCheckBox->setText(QString());
#if QT_CONFIG(tooltip)
        showEclipticGridJ2000CheckBox->setToolTip(QCoreApplication::translate("viewDialogForm", "Ecliptical coordinates for J2000.0.", nullptr));
#endif // QT_CONFIG(tooltip)
        showEclipticGridJ2000CheckBox->setText(QCoreApplication::translate("viewDialogForm", "Ecliptic grid (J2000)", nullptr));
#if QT_CONFIG(tooltip)
        colorPrimeVerticalLine->setToolTip(QCoreApplication::translate("viewDialogForm", "Color of Prime Vertical", nullptr));
#endif // QT_CONFIG(tooltip)
        showSupergalacticPolesCheckBox->setText(QCoreApplication::translate("viewDialogForm", "Supergalactic poles", nullptr));
#if QT_CONFIG(tooltip)
        colorCelestialJ2000Poles->setToolTip(QCoreApplication::translate("viewDialogForm", "Color of the celestial poles (J2000.0)", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        galacticEquatorLabelsCheckBox->setToolTip(QCoreApplication::translate("viewDialogForm", "Label partitions", nullptr));
#endif // QT_CONFIG(tooltip)
        galacticEquatorLabelsCheckBox->setText(QString());
#if QT_CONFIG(tooltip)
        longitudePartsCheckBox->setToolTip(QCoreApplication::translate("viewDialogForm", "Show partitions", nullptr));
#endif // QT_CONFIG(tooltip)
        longitudePartsCheckBox->setText(QString());
        showZenithNadirCheckBox->setText(QCoreApplication::translate("viewDialogForm", "Zenith and Nadir", nullptr));
#if QT_CONFIG(tooltip)
        fixedEquatorPartsCheckBox->setToolTip(QCoreApplication::translate("viewDialogForm", "Show partitions", nullptr));
#endif // QT_CONFIG(tooltip)
        fixedEquatorPartsCheckBox->setText(QString());
#if QT_CONFIG(tooltip)
        colorSolarEquatorLine->setToolTip(QCoreApplication::translate("viewDialogForm", "Color of the projected Solar equator line", nullptr));
#endif // QT_CONFIG(tooltip)
        colorSolarEquatorLine->setText(QString());
#if QT_CONFIG(tooltip)
        showFixedEquatorialGridCheckBox->setToolTip(QCoreApplication::translate("viewDialogForm", "Fixed equatorial coordinates (hour angle/declination) of current planet.", nullptr));
#endif // QT_CONFIG(tooltip)
        showFixedEquatorialGridCheckBox->setText(QCoreApplication::translate("viewDialogForm", "Fixed Equatorial grid", nullptr));
#if QT_CONFIG(tooltip)
        showGalacticEquatorLineCheckBox->setToolTip(QCoreApplication::translate("viewDialogForm", "Show line", nullptr));
#endif // QT_CONFIG(tooltip)
        showGalacticEquatorLineCheckBox->setText(QString());
#if QT_CONFIG(tooltip)
        colorPenumbraCircle->setToolTip(QCoreApplication::translate("viewDialogForm", "Color of penumbra circle", nullptr));
#endif // QT_CONFIG(tooltip)
        colorPenumbraCircle->setText(QString());
#if QT_CONFIG(tooltip)
        colorEclipticGridJ2000->setToolTip(QCoreApplication::translate("viewDialogForm", "Color of the ecliptical grid (J2000.0)", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        colorSupergalacticGrid->setToolTip(QCoreApplication::translate("viewDialogForm", "Color of the supergalactic grid", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        longitudeLabel->setToolTip(QCoreApplication::translate("viewDialogForm", "Opposition/conjunction longitude line - the line of ecliptic longitude which passes through both ecliptic poles, the Sun and opposition point.", nullptr));
#endif // QT_CONFIG(tooltip)
        longitudeLabel->setText(QCoreApplication::translate("viewDialogForm", "O./C. longitude", nullptr));
#if QT_CONFIG(tooltip)
        colorEquatorLine->setToolTip(QCoreApplication::translate("viewDialogForm", "Color of equator (of date)", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        primeVerticalLabelsCheckBox->setToolTip(QCoreApplication::translate("viewDialogForm", "Label partitions", nullptr));
#endif // QT_CONFIG(tooltip)
        primeVerticalLabelsCheckBox->setText(QString());
#if QT_CONFIG(tooltip)
        equatorJ2000LabelsCheckBox->setToolTip(QCoreApplication::translate("viewDialogForm", "Label partitions", nullptr));
#endif // QT_CONFIG(tooltip)
        equatorJ2000LabelsCheckBox->setText(QString());
#if QT_CONFIG(tooltip)
        showSupergalacticEquatorLineCheckBox->setToolTip(QCoreApplication::translate("viewDialogForm", "Show line", nullptr));
#endif // QT_CONFIG(tooltip)
        showSupergalacticEquatorLineCheckBox->setText(QString());
#if QT_CONFIG(tooltip)
        equatorJ2000PartsCheckBox->setToolTip(QCoreApplication::translate("viewDialogForm", "Show partitions", nullptr));
#endif // QT_CONFIG(tooltip)
        equatorJ2000PartsCheckBox->setText(QString());
#if QT_CONFIG(tooltip)
        eclipticPartsCheckBox->setToolTip(QCoreApplication::translate("viewDialogForm", "Show partitions", nullptr));
#endif // QT_CONFIG(tooltip)
        eclipticPartsCheckBox->setText(QString());
#if QT_CONFIG(tooltip)
        colorGalacticPoles->setToolTip(QCoreApplication::translate("viewDialogForm", "Color of galactic poles", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        showAzimuthalGridCheckBox->setToolTip(QCoreApplication::translate("viewDialogForm", "Altitudes and azimuth (counted from North towards East).", nullptr));
#endif // QT_CONFIG(tooltip)
        showAzimuthalGridCheckBox->setText(QCoreApplication::translate("viewDialogForm", "Azimuthal grid", nullptr));
#if QT_CONFIG(tooltip)
        showEquatorLineCheckBox->setToolTip(QCoreApplication::translate("viewDialogForm", "Show line", nullptr));
#endif // QT_CONFIG(tooltip)
        showEquatorLineCheckBox->setText(QString());
#if QT_CONFIG(tooltip)
        supergalacticEquatorLabelsCheckBox->setToolTip(QCoreApplication::translate("viewDialogForm", "Label partitions", nullptr));
#endif // QT_CONFIG(tooltip)
        supergalacticEquatorLabelsCheckBox->setText(QString());
#if QT_CONFIG(tooltip)
        supergalacticEquatorLabel->setToolTip(QCoreApplication::translate("viewDialogForm", "Show equator of de Vaucouleurs' Supergalactic coordinates (1976).", nullptr));
#endif // QT_CONFIG(tooltip)
        supergalacticEquatorLabel->setText(QCoreApplication::translate("viewDialogForm", "Supergalactic equator", nullptr));
#if QT_CONFIG(tooltip)
        colorEclipticLineJ2000->setToolTip(QCoreApplication::translate("viewDialogForm", "Color of ecliptic (J2000.0)", nullptr));
#endif // QT_CONFIG(tooltip)
        colorFixedEquatorialGrid->setText(QString());
#if QT_CONFIG(tooltip)
        colorFOVCenterMarker->setToolTip(QCoreApplication::translate("viewDialogForm", "Color of marker of center of FOV", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        meridianPartsCheckBox->setToolTip(QCoreApplication::translate("viewDialogForm", "Show partitions", nullptr));
#endif // QT_CONFIG(tooltip)
        meridianPartsCheckBox->setText(QString());
#if QT_CONFIG(tooltip)
        colorCardinalPoints->setToolTip(QCoreApplication::translate("viewDialogForm", "Color of cardinal points", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        colorAzimuthalGrid->setToolTip(QCoreApplication::translate("viewDialogForm", "Color of the azimuthal grid", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        colorLongitudeLine->setToolTip(QCoreApplication::translate("viewDialogForm", "Color of the opposition/conjunction longitude line", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        showEclipticLineJ2000CheckBox->setToolTip(QCoreApplication::translate("viewDialogForm", "Show line", nullptr));
#endif // QT_CONFIG(tooltip)
        showEclipticLineJ2000CheckBox->setText(QString());
#if QT_CONFIG(tooltip)
        horizonPartsCheckBox->setToolTip(QCoreApplication::translate("viewDialogForm", "Show partitions", nullptr));
#endif // QT_CONFIG(tooltip)
        horizonPartsCheckBox->setText(QString());
#if QT_CONFIG(tooltip)
        fovRectangularMarkerWidthDoubleSpinBox->setToolTip(QCoreApplication::translate("viewDialogForm", "Width of rectangle, in degrees", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        fovCircularMarkerSizeDoubleSpinBox->setToolTip(QCoreApplication::translate("viewDialogForm", "Field of view in degrees", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        showFOVCircularMarkerCheckBox->setToolTip(QCoreApplication::translate("viewDialogForm", "Show circular marker of field of view (FOV)", nullptr));
#endif // QT_CONFIG(tooltip)
        showFOVCircularMarkerCheckBox->setText(QCoreApplication::translate("viewDialogForm", "Circular FOV", nullptr));
#if QT_CONFIG(tooltip)
        fovRectangularMarkerRotationAngleDoubleSpinBox->setToolTip(QCoreApplication::translate("viewDialogForm", "Rotation angle of rectangle, in degrees", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        fovRectangularMarkerHeightDoubleSpinBox->setToolTip(QCoreApplication::translate("viewDialogForm", "Height of rectangle, in degrees", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        showFOVRectangularMarkerCheckBox->setToolTip(QCoreApplication::translate("viewDialogForm", "Show rectangular marker of field of view (FOV)", nullptr));
#endif // QT_CONFIG(tooltip)
        showFOVRectangularMarkerCheckBox->setText(QCoreApplication::translate("viewDialogForm", "Rectangular FOV", nullptr));
#if QT_CONFIG(tooltip)
        colorFOVCircularMarker->setToolTip(QCoreApplication::translate("viewDialogForm", "Color of circular marker of FOV", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        colorFOVRectangularMarker->setToolTip(QCoreApplication::translate("viewDialogForm", "Color of rectangular marker of FOV", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        equatorLabelsCheckBox->setToolTip(QCoreApplication::translate("viewDialogForm", "Label partitions", nullptr));
#endif // QT_CONFIG(tooltip)
        equatorLabelsCheckBox->setText(QString());
#if QT_CONFIG(tooltip)
        colorApexPoints->setToolTip(QCoreApplication::translate("viewDialogForm", "Color of Apex and Antapex points", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        equatorLabel->setToolTip(QCoreApplication::translate("viewDialogForm", "Show celestial equator of current planet and date.", nullptr));
#endif // QT_CONFIG(tooltip)
        equatorLabel->setText(QCoreApplication::translate("viewDialogForm", "Equator (of date)", nullptr));
#if QT_CONFIG(tooltip)
        precessionLabelsCheckBox->setToolTip(QCoreApplication::translate("viewDialogForm", "Label partitions", nullptr));
#endif // QT_CONFIG(tooltip)
        precessionLabelsCheckBox->setText(QString());
#if QT_CONFIG(tooltip)
        equatorJ2000Label->setToolTip(QCoreApplication::translate("viewDialogForm", "Show celestial equator of J2000.0.", nullptr));
#endif // QT_CONFIG(tooltip)
        equatorJ2000Label->setText(QCoreApplication::translate("viewDialogForm", "Equator (J2000)", nullptr));
#if QT_CONFIG(tooltip)
        colorQuadratureLine->setToolTip(QCoreApplication::translate("viewDialogForm", "Color of the quadrature circle", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        showSolarEquatorCheckBox->setToolTip(QCoreApplication::translate("viewDialogForm", "Show line", nullptr));
#endif // QT_CONFIG(tooltip)
        showSolarEquatorCheckBox->setText(QString());
#if QT_CONFIG(tooltip)
        showSupergalacticGridCheckBox->setToolTip(QCoreApplication::translate("viewDialogForm", "Show de Vaucouleurs' Supergalactic coordinates (1976), defined by the distribution of nearby galaxies.", nullptr));
#endif // QT_CONFIG(tooltip)
        showSupergalacticGridCheckBox->setText(QCoreApplication::translate("viewDialogForm", "Supergalactic grid", nullptr));
#if QT_CONFIG(tooltip)
        showEquatorJ2000LineCheckBox->setToolTip(QCoreApplication::translate("viewDialogForm", "Show line", nullptr));
#endif // QT_CONFIG(tooltip)
        showEquatorJ2000LineCheckBox->setText(QString());
#if QT_CONFIG(tooltip)
        eclipticJ2000PartsCheckBox->setToolTip(QCoreApplication::translate("viewDialogForm", "Show partitions", nullptr));
#endif // QT_CONFIG(tooltip)
        eclipticJ2000PartsCheckBox->setText(QString());
#if QT_CONFIG(tooltip)
        eclipticLabelsCheckBox->setToolTip(QCoreApplication::translate("viewDialogForm", "Label partitions", nullptr));
#endif // QT_CONFIG(tooltip)
        eclipticLabelsCheckBox->setText(QString());
#if QT_CONFIG(tooltip)
        colorCelestialPoles->setToolTip(QCoreApplication::translate("viewDialogForm", "Color of celestial poles (of date)", nullptr));
#endif // QT_CONFIG(tooltip)
        showSolsticeJ2000PointsCheckBox->setText(QCoreApplication::translate("viewDialogForm", "Solstices (J2000)", nullptr));
#if QT_CONFIG(tooltip)
        horizonLabel->setToolTip(QCoreApplication::translate("viewDialogForm", "Show mathematical horizon line.", nullptr));
#endif // QT_CONFIG(tooltip)
        horizonLabel->setText(QCoreApplication::translate("viewDialogForm", "Horizon", nullptr));
#if QT_CONFIG(tooltip)
        colorEquatorialGrid->setToolTip(QCoreApplication::translate("viewDialogForm", "Color of the equatorial grid (of date)", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        longitudeLabelsCheckBox->setToolTip(QCoreApplication::translate("viewDialogForm", "Label partitions", nullptr));
#endif // QT_CONFIG(tooltip)
        longitudeLabelsCheckBox->setText(QString());
#if QT_CONFIG(tooltip)
        colorEclipticGridOfDate->setToolTip(QCoreApplication::translate("viewDialogForm", "Color of the ecliptical grid (of date)", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        showCelestialJ2000PolesCheckBox->setToolTip(QCoreApplication::translate("viewDialogForm", "Show celestial poles of J2000.0.", nullptr));
#endif // QT_CONFIG(tooltip)
        showCelestialJ2000PolesCheckBox->setText(QCoreApplication::translate("viewDialogForm", "Celestial poles (J2000)", nullptr));
#if QT_CONFIG(tooltip)
        eclipticJ2000Label->setToolTip(QCoreApplication::translate("viewDialogForm", "Show ecliptic line of J2000.0 (VSOP87A fundamental plane).", nullptr));
#endif // QT_CONFIG(tooltip)
        eclipticJ2000Label->setText(QCoreApplication::translate("viewDialogForm", "Ecliptic (J2000)", nullptr));
#if QT_CONFIG(tooltip)
        solarEquatorLabel->setToolTip(QCoreApplication::translate("viewDialogForm", "Solar equator projected into space.", nullptr));
#endif // QT_CONFIG(tooltip)
        solarEquatorLabel->setText(QCoreApplication::translate("viewDialogForm", "Projected Solar Equator", nullptr));
#if QT_CONFIG(tooltip)
        showPenumbraCheckBox->setToolTip(QCoreApplication::translate("viewDialogForm", "This circle represents the outermost rim of Earth's shadow in the distance of the Moon. Will not show when Moon scaling is enabled!", nullptr));
#endif // QT_CONFIG(tooltip)
        showPenumbraCheckBox->setText(QCoreApplication::translate("viewDialogForm", "Earth penumbra", nullptr));
#if QT_CONFIG(tooltip)
        colorEclipticLineOfDate->setToolTip(QCoreApplication::translate("viewDialogForm", "Color of ecliptic (of date)", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        showEquatorialJ2000GridCheckBox->setToolTip(QCoreApplication::translate("viewDialogForm", "Equatorial coordinates of J2000.0.", nullptr));
#endif // QT_CONFIG(tooltip)
        showEquatorialJ2000GridCheckBox->setText(QCoreApplication::translate("viewDialogForm", "Equatorial grid (J2000)", nullptr));
#if QT_CONFIG(tooltip)
        colorSolsticeJ2000Points->setToolTip(QCoreApplication::translate("viewDialogForm", "Color of the solstice points (J2000.0)", nullptr));
#endif // QT_CONFIG(tooltip)
        colorSolsticeJ2000Points->setText(QString());
#if QT_CONFIG(tooltip)
        eclipticJ2000LabelsCheckBox->setToolTip(QCoreApplication::translate("viewDialogForm", "Label partitions", nullptr));
#endif // QT_CONFIG(tooltip)
        eclipticJ2000LabelsCheckBox->setText(QString());
        showSolsticePointsCheckBox->setText(QCoreApplication::translate("viewDialogForm", "Solstices (of date)", nullptr));
#if QT_CONFIG(tooltip)
        showPrimeVerticalLineCheckBox->setToolTip(QCoreApplication::translate("viewDialogForm", "Show line", nullptr));
#endif // QT_CONFIG(tooltip)
        showPrimeVerticalLineCheckBox->setText(QString());
#if QT_CONFIG(tooltip)
        showCelestialPolesCheckBox->setToolTip(QCoreApplication::translate("viewDialogForm", "Show celestial poles of current planet and date.", nullptr));
#endif // QT_CONFIG(tooltip)
        showCelestialPolesCheckBox->setText(QCoreApplication::translate("viewDialogForm", "Celestial poles (of date)", nullptr));
#if QT_CONFIG(tooltip)
        colorCurrentVerticalLine->setToolTip(QCoreApplication::translate("viewDialogForm", "Color of altitude line", nullptr));
#endif // QT_CONFIG(tooltip)
        colorCurrentVerticalLine->setText(QString());
#if QT_CONFIG(tooltip)
        primeVerticalLabel->setToolTip(QCoreApplication::translate("viewDialogForm", "Show Prime (East-West) Vertical.", nullptr));
#endif // QT_CONFIG(tooltip)
        primeVerticalLabel->setText(QCoreApplication::translate("viewDialogForm", "Prime Vertical", nullptr));
#if QT_CONFIG(tooltip)
        showLongitudeLineCheckBox->setToolTip(QCoreApplication::translate("viewDialogForm", "Show line", nullptr));
#endif // QT_CONFIG(tooltip)
        showLongitudeLineCheckBox->setText(QString());
#if QT_CONFIG(tooltip)
        showEquatorialGridCheckBox->setToolTip(QCoreApplication::translate("viewDialogForm", "Equatorial coordinates of current date and planet.", nullptr));
#endif // QT_CONFIG(tooltip)
        showEquatorialGridCheckBox->setText(QCoreApplication::translate("viewDialogForm", "Equatorial grid (of date)", nullptr));
#if QT_CONFIG(tooltip)
        showPrecessionCirclesCheckBox->setToolTip(QCoreApplication::translate("viewDialogForm", "Show circles", nullptr));
#endif // QT_CONFIG(tooltip)
        showPrecessionCirclesCheckBox->setText(QString());
#if QT_CONFIG(tooltip)
        showMeridianLineCheckBox->setToolTip(QCoreApplication::translate("viewDialogForm", "Show line", nullptr));
#endif // QT_CONFIG(tooltip)
        showMeridianLineCheckBox->setText(QString());
#if QT_CONFIG(tooltip)
        precessionLabel->setToolTip(QCoreApplication::translate("viewDialogForm", "Instantaneous circles of earth's axis on its motion around ecliptical poles. Displayed on Earth only.", nullptr));
#endif // QT_CONFIG(tooltip)
        precessionLabel->setText(QCoreApplication::translate("viewDialogForm", "Precession circles", nullptr));
        showGalacticPolesCheckBox->setText(QCoreApplication::translate("viewDialogForm", "Galactic poles", nullptr));
#if QT_CONFIG(tooltip)
        currentVerticalLabel->setToolTip(QCoreApplication::translate("viewDialogForm", "Show a vertical line (with optional altitude marks) in the screen center.", nullptr));
#endif // QT_CONFIG(tooltip)
        currentVerticalLabel->setText(QCoreApplication::translate("viewDialogForm", "Altitude", nullptr));
        showCompassMarksCheckBox->setText(QCoreApplication::translate("viewDialogForm", "Compass marks", nullptr));
#if QT_CONFIG(tooltip)
        colorEquatorJ2000Line->setToolTip(QCoreApplication::translate("viewDialogForm", "Color of equator (J2000.0)", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        colorEquatorialJ2000Grid->setToolTip(QCoreApplication::translate("viewDialogForm", "Color of the equatorial grid (J2000.0)", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        showGalacticGridCheckBox->setToolTip(QCoreApplication::translate("viewDialogForm", "Galactic Coordinates, System II (IAU 1958).", nullptr));
#endif // QT_CONFIG(tooltip)
        showGalacticGridCheckBox->setText(QCoreApplication::translate("viewDialogForm", "Galactic grid", nullptr));
#if QT_CONFIG(tooltip)
        colorMeridianLine->setToolTip(QCoreApplication::translate("viewDialogForm", "Color of meridian", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        showCurrentVerticalLineCheckBox->setToolTip(QCoreApplication::translate("viewDialogForm", "Show line", nullptr));
#endif // QT_CONFIG(tooltip)
        showCurrentVerticalLineCheckBox->setText(QString());
#if QT_CONFIG(tooltip)
        showCardinalPointsCheckBox->setToolTip(QCoreApplication::translate("viewDialogForm", "Labels for the cardinal directions (4-wind compass rose).", nullptr));
#endif // QT_CONFIG(tooltip)
        showCardinalPointsCheckBox->setText(QCoreApplication::translate("viewDialogForm", "Cardinal points", nullptr));
#if QT_CONFIG(tooltip)
        showOrdinal8WRPointsCheckBox->setToolTip(QCoreApplication::translate("viewDialogForm", "Labels for the intercardinal (or ordinal) directions (8-wind compass rose).", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        showOrdinal16WRPointsCheckBox->setToolTip(QCoreApplication::translate("viewDialogForm", "Labels for the secondary intercardinal directions (16-wind compass rose).", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        showOrdinal32WRPointsCheckBox->setToolTip(QCoreApplication::translate("viewDialogForm", "Labels for the tertiary intercardinal directions (32-wind compass rose).", nullptr));
#endif // QT_CONFIG(tooltip)
        showAntisolarPointCheckBox->setText(QCoreApplication::translate("viewDialogForm", "Antisolar point", nullptr));
#if QT_CONFIG(tooltip)
        colorGalacticEquatorLine->setToolTip(QCoreApplication::translate("viewDialogForm", "Color of galactic equator", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        showCircumpolarCirclesCheckBox->setToolTip(QCoreApplication::translate("viewDialogForm", "These circles delimit stars which stay always above (respectively below) the mathematical horizon.", nullptr));
#endif // QT_CONFIG(tooltip)
        showCircumpolarCirclesCheckBox->setText(QCoreApplication::translate("viewDialogForm", "Circumpolar circles", nullptr));
#if QT_CONFIG(tooltip)
        showHorizonLineCheckBox->setToolTip(QCoreApplication::translate("viewDialogForm", "Show line", nullptr));
#endif // QT_CONFIG(tooltip)
        showHorizonLineCheckBox->setText(QString());
#if QT_CONFIG(tooltip)
        colorEclipticPoles->setToolTip(QCoreApplication::translate("viewDialogForm", "Color of ecliptic poles (of date)", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        showFixedEquatorLineCheckBox->setToolTip(QCoreApplication::translate("viewDialogForm", "Show line", nullptr));
#endif // QT_CONFIG(tooltip)
        showFixedEquatorLineCheckBox->setText(QString());
#if QT_CONFIG(tooltip)
        horizonLabelsCheckBox->setToolTip(QCoreApplication::translate("viewDialogForm", "Label partitions", nullptr));
#endif // QT_CONFIG(tooltip)
        horizonLabelsCheckBox->setText(QString());
#if QT_CONFIG(tooltip)
        showEclipticJ2000PolesCheckBox->setToolTip(QCoreApplication::translate("viewDialogForm", "Show ecliptic poles of J2000.0", nullptr));
#endif // QT_CONFIG(tooltip)
        showEclipticJ2000PolesCheckBox->setText(QCoreApplication::translate("viewDialogForm", "Ecliptic poles (J2000)", nullptr));
#if QT_CONFIG(tooltip)
        colorFixedEquatorLine->setToolTip(QCoreApplication::translate("viewDialogForm", "Color of fixed equator", nullptr));
#endif // QT_CONFIG(tooltip)
        colorFixedEquatorLine->setText(QString());
#if QT_CONFIG(tooltip)
        showQuadratureLineCheckBox->setToolTip(QCoreApplication::translate("viewDialogForm", "A circle 90\302\260 from the Sun marking quadrature", nullptr));
#endif // QT_CONFIG(tooltip)
        showQuadratureLineCheckBox->setText(QCoreApplication::translate("viewDialogForm", "Quadrature circle", nullptr));
#if QT_CONFIG(tooltip)
        showColuresLineCheckBox->setToolTip(QCoreApplication::translate("viewDialogForm", "Show circles", nullptr));
#endif // QT_CONFIG(tooltip)
        showColuresLineCheckBox->setText(QString());
#if QT_CONFIG(tooltip)
        fixedEquatorLabel->setToolTip(QCoreApplication::translate("viewDialogForm", "Show fixed celestial equator (hour angles) of current planet.", nullptr));
#endif // QT_CONFIG(tooltip)
        fixedEquatorLabel->setText(QCoreApplication::translate("viewDialogForm", "Fixed Equator", nullptr));
        showGalacticCenterCheckBox->setText(QCoreApplication::translate("viewDialogForm", "Galactic center and anticenter", nullptr));
#if QT_CONFIG(tooltip)
        eclipticLabel->setToolTip(QCoreApplication::translate("viewDialogForm", "Show ecliptic line of current date.", nullptr));
#endif // QT_CONFIG(tooltip)
        eclipticLabel->setText(QCoreApplication::translate("viewDialogForm", "Ecliptic (of date)", nullptr));
#if QT_CONFIG(tooltip)
        withSolarTicksCheckbox->setToolTip(QCoreApplication::translate("viewDialogForm", "Mark Solar positions along the Ecliptic", nullptr));
#endif // QT_CONFIG(tooltip)
        withSolarTicksCheckbox->setText(QCoreApplication::translate("viewDialogForm", "with Solar Dates", nullptr));
#if QT_CONFIG(tooltip)
        equatorPartsCheckBox->setToolTip(QCoreApplication::translate("viewDialogForm", "Show partitions", nullptr));
#endif // QT_CONFIG(tooltip)
        equatorPartsCheckBox->setText(QString());
#if QT_CONFIG(tooltip)
        supergalacticEquatorPartsCheckBox->setToolTip(QCoreApplication::translate("viewDialogForm", "Show partitions", nullptr));
#endif // QT_CONFIG(tooltip)
        supergalacticEquatorPartsCheckBox->setText(QString());
#if QT_CONFIG(tooltip)
        colorCompassMarks->setToolTip(QCoreApplication::translate("viewDialogForm", "Color of compass marks", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        colorColuresLine->setToolTip(QCoreApplication::translate("viewDialogForm", "Color of colures", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        colorZenithNadir->setToolTip(QCoreApplication::translate("viewDialogForm", "Color of Zenith and Nadir", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        colorEquinoxJ2000Points->setToolTip(QCoreApplication::translate("viewDialogForm", "Color of the equinox points (J2000.0)", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        meridianLabel->setToolTip(QCoreApplication::translate("viewDialogForm", "Show meridian line.", nullptr));
#endif // QT_CONFIG(tooltip)
        meridianLabel->setText(QCoreApplication::translate("viewDialogForm", "Meridian", nullptr));
#if QT_CONFIG(tooltip)
        colorEclipticJ2000Poles->setToolTip(QCoreApplication::translate("viewDialogForm", "Color of the ecliptic poles (J2000.0)", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        showFOVCenterMarkerCheckBox->setToolTip(QCoreApplication::translate("viewDialogForm", "Show marker of center for field of view (FOV)", nullptr));
#endif // QT_CONFIG(tooltip)
        showFOVCenterMarkerCheckBox->setText(QCoreApplication::translate("viewDialogForm", "Center of FOV", nullptr));
#if QT_CONFIG(tooltip)
        colorInvariablePlane->setToolTip(QCoreApplication::translate("viewDialogForm", "Color of the invariable plane of the Solar system", nullptr));
#endif // QT_CONFIG(tooltip)
        colorInvariablePlane->setText(QString());
#if QT_CONFIG(tooltip)
        colorPrecessionCircles->setToolTip(QCoreApplication::translate("viewDialogForm", "Color of precession circles", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        gridSpacingLabel->setToolTip(QCoreApplication::translate("viewDialogForm", "Grid line spacing density", nullptr));
#endif // QT_CONFIG(tooltip)
        gridSpacingLabel->setText(QCoreApplication::translate("viewDialogForm", "Grid density:", nullptr));
        gridSpacingComboBox->setItemText(0, QCoreApplication::translate("viewDialogForm", "Fine", "grid density"));
        gridSpacingComboBox->setItemText(1, QCoreApplication::translate("viewDialogForm", "Normal", "grid density"));
        gridSpacingComboBox->setItemText(2, QCoreApplication::translate("viewDialogForm", "Coarse", "grid density"));

#if QT_CONFIG(tooltip)
        gridSpacingComboBox->setToolTip(QCoreApplication::translate("viewDialogForm", "Select grid line spacing density", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        label_2->setToolTip(QCoreApplication::translate("viewDialogForm", "The thickness of celestial lines", nullptr));
#endif // QT_CONFIG(tooltip)
        label_2->setText(QCoreApplication::translate("viewDialogForm", "Line thickness:", nullptr));
#if QT_CONFIG(tooltip)
        lineThicknessSpinBox->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        partThicknessLabel->setToolTip(QCoreApplication::translate("viewDialogForm", "The line thickness for circle partitions", nullptr));
#endif // QT_CONFIG(tooltip)
        partThicknessLabel->setText(QCoreApplication::translate("viewDialogForm", "Partitions thickness:", nullptr));
#if QT_CONFIG(tooltip)
        partThicknessSpinBox->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        pointSizeLabel->setToolTip(QCoreApplication::translate("viewDialogForm", "Size of celestial points in pixels", nullptr));
#endif // QT_CONFIG(tooltip)
        pointSizeLabel->setText(QCoreApplication::translate("viewDialogForm", "Point size:", nullptr));
#if QT_CONFIG(tooltip)
        pointSizeSpinBox->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
        pushButtonAddRemoveLandscapes->setText(QCoreApplication::translate("viewDialogForm", "Add/remove landscapes...", nullptr));
        pushButtonLandscapes_say->setText(QCoreApplication::translate("viewDialogForm", "Read text", nullptr));
        pushButtonLandscapes_stop->setText(QCoreApplication::translate("viewDialogForm", "Stop", nullptr));
        landscapeOptionsGroupBox->setTitle(QCoreApplication::translate("viewDialogForm", "Options", nullptr));
#if QT_CONFIG(tooltip)
        localLandscapeBrightnessCheckBox->setToolTip(QCoreApplication::translate("viewDialogForm", "Use minimal brightness as may be specified in landscape.ini", nullptr));
#endif // QT_CONFIG(tooltip)
        localLandscapeBrightnessCheckBox->setText(QCoreApplication::translate("viewDialogForm", "from landscape, if given", nullptr));
#if QT_CONFIG(tooltip)
        landscapeIlluminationCheckBox->setToolTip(QCoreApplication::translate("viewDialogForm", "Show illumination layer (bright windows, light pollution, etc.)", nullptr));
#endif // QT_CONFIG(tooltip)
        landscapeIlluminationCheckBox->setText(QCoreApplication::translate("viewDialogForm", "Show illumination ", nullptr));
        landscapeTransparencyCheckBox->setText(QCoreApplication::translate("viewDialogForm", "Transparency:", nullptr));
#if QT_CONFIG(tooltip)
        landscapePolylineCheckBox->setToolTip(QCoreApplication::translate("viewDialogForm", "Draw horizon polyline if one is defined.", nullptr));
#endif // QT_CONFIG(tooltip)
        landscapePolylineCheckBox->setText(QCoreApplication::translate("viewDialogForm", "Draw only polygon", nullptr));
#if QT_CONFIG(tooltip)
        landscapePolylineThicknessSpinBox->setToolTip(QCoreApplication::translate("viewDialogForm", "Thickness of line in pixels", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        landscapeBrightnessCheckBox->setToolTip(QCoreApplication::translate("viewDialogForm", "Use minimal brightness to leave landscape visible also in darkness", nullptr));
#endif // QT_CONFIG(tooltip)
        landscapeBrightnessCheckBox->setText(QCoreApplication::translate("viewDialogForm", "Minimal brightness:", nullptr));
#if QT_CONFIG(tooltip)
        landscapeBrightnessSpinBox->setToolTip(QCoreApplication::translate("viewDialogForm", "Value range 0..1 (landscape is black at night - landscape is fully bright)", nullptr));
#endif // QT_CONFIG(tooltip)
        landscapeLabelsCheckBox->setText(QCoreApplication::translate("viewDialogForm", "Landscape labels", nullptr));
#if QT_CONFIG(tooltip)
        landscapeLabelsFontSizeSpinBox->setToolTip(QCoreApplication::translate("viewDialogForm", "Font size", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        landscapeLabelsAngleSpinBox->setToolTip(QCoreApplication::translate("viewDialogForm", "Text angle", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        labelsColorButton->setToolTip(QCoreApplication::translate("viewDialogForm", "Color for landscape labels", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        polygonColorButton->setToolTip(QCoreApplication::translate("viewDialogForm", "Color for polygon line", nullptr));
#endif // QT_CONFIG(tooltip)
        polygonColorButton->setText(QString());
        showFogCheckBox->setText(QCoreApplication::translate("viewDialogForm", "Show fog", nullptr));
        showGroundCheckBox->setText(QCoreApplication::translate("viewDialogForm", "Show ground", nullptr));
#if QT_CONFIG(tooltip)
        landscapeLocationCheckBox->setToolTip(QCoreApplication::translate("viewDialogForm", "Set the planet and location as specified for the selected landscape", nullptr));
#endif // QT_CONFIG(tooltip)
        landscapeLocationCheckBox->setText(QCoreApplication::translate("viewDialogForm", "Location from landscape", nullptr));
        useAsDefaultLandscapeCheckBox->setText(QCoreApplication::translate("viewDialogForm", "Use this landscape as default", nullptr));
        skyCultureOptionsGroupBox->setTitle(QCoreApplication::translate("viewDialogForm", "Options", nullptr));
        useAsDefaultSkyCultureCheckBox->setText(QCoreApplication::translate("viewDialogForm", "Use this sky culture as default", nullptr));
        pushButtonSkyculture_say->setText(QCoreApplication::translate("viewDialogForm", "Read text", nullptr));
        pushButtonSkyculture_stop->setText(QCoreApplication::translate("viewDialogForm", "Stop", nullptr));
        labelInfoLabel2->setText(QCoreApplication::translate("viewDialogForm", "Info label", nullptr));
        labelScreenLabel2->setText(QCoreApplication::translate("viewDialogForm", "Screen label", nullptr));
        screenLabelTranslationCheckBox->setText(QCoreApplication::translate("viewDialogForm", "translation", "menu item"));
        infoLabelTranslationCheckBox->setText(QCoreApplication::translate("viewDialogForm", "translation", "menu item"));
        screenLabelPronounceCheckBox->setText(QCoreApplication::translate("viewDialogForm", "transliteration", "menu item"));
        screenLabelModernCheckBox->setText(QCoreApplication::translate("viewDialogForm", "modern", "menu item"));
#if QT_CONFIG(tooltip)
        screenLabelTransliterationCheckBox->setToolTip(QCoreApplication::translate("viewDialogForm", "Scientific transliteration", nullptr));
#endif // QT_CONFIG(tooltip)
        screenLabelTransliterationCheckBox->setText(QCoreApplication::translate("viewDialogForm", "sci. translit.", "menu item"));
        infoLabelNativeCheckBox->setText(QCoreApplication::translate("viewDialogForm", "native", "menu item"));
#if QT_CONFIG(tooltip)
        infoLabelTransliterationCheckBox->setToolTip(QCoreApplication::translate("viewDialogForm", "Scientific transliteration", nullptr));
#endif // QT_CONFIG(tooltip)
        infoLabelTransliterationCheckBox->setText(QCoreApplication::translate("viewDialogForm", "sci. translit.", "menu item"));
#if QT_CONFIG(tooltip)
        infoLabelIPACheckBox->setToolTip(QCoreApplication::translate("viewDialogForm", "International Phonetic Alphabet", nullptr));
#endif // QT_CONFIG(tooltip)
        infoLabelIPACheckBox->setText(QCoreApplication::translate("viewDialogForm", "IPA", "menu item"));
        screenLabelNativeCheckBox->setText(QCoreApplication::translate("viewDialogForm", "native", "menu item"));
        infoLabelPronounceCheckBox->setText(QCoreApplication::translate("viewDialogForm", "transliteration", "menu item"));
#if QT_CONFIG(tooltip)
        screenLabelIPACheckBox->setToolTip(QCoreApplication::translate("viewDialogForm", "International Phonetic Alphabet", nullptr));
#endif // QT_CONFIG(tooltip)
        screenLabelIPACheckBox->setText(QCoreApplication::translate("viewDialogForm", "IPA", "menu item"));
        infoLabelModernCheckBox->setText(QCoreApplication::translate("viewDialogForm", "modern", "menu item"));
        infoLabelBynameCheckBox->setText(QCoreApplication::translate("viewDialogForm", "byname", "menu item"));
        screenLabelBynameCheckBox->setText(QCoreApplication::translate("viewDialogForm", "byname", "menu item"));
#if QT_CONFIG(tooltip)
        zodiacCheckBox->setToolTip(QCoreApplication::translate("viewDialogForm", "Show zodiac (if defined)", nullptr));
#endif // QT_CONFIG(tooltip)
        zodiacCheckBox->setText(QCoreApplication::translate("viewDialogForm", "Zodiac", nullptr));
#if QT_CONFIG(tooltip)
        constellationsFontSizeSpinBox->setToolTip(QCoreApplication::translate("viewDialogForm", "Constellations font size", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        zodiacColorButton->setToolTip(QCoreApplication::translate("viewDialogForm", "Color of zodiac lines", nullptr));
#endif // QT_CONFIG(tooltip)
        zodiacColorButton->setText(QString());
#if QT_CONFIG(tooltip)
        zodiacThicknessSpinBox->setToolTip(QCoreApplication::translate("viewDialogForm", "Thickness of line in pixels", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        asterismLinesFadeDurationDoubleSpinBox->setToolTip(QCoreApplication::translate("viewDialogForm", "Fading duration for lines of asterisms", nullptr));
#endif // QT_CONFIG(tooltip)
        showConstellationLabelsCheckBox->setText(QCoreApplication::translate("viewDialogForm", "Constellation labels", nullptr));
#if QT_CONFIG(tooltip)
        colorAsterismLines->setToolTip(QCoreApplication::translate("viewDialogForm", "Color of asterism lines", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        constellationHullsColorButton->setToolTip(QCoreApplication::translate("viewDialogForm", "Color of constellation area (convex hull) boundaries", nullptr));
#endif // QT_CONFIG(tooltip)
        constellationHullsColorButton->setText(QString());
#if QT_CONFIG(tooltip)
        constellationPickCheckBox->setToolTip(QCoreApplication::translate("viewDialogForm", "Only one at a time", nullptr));
#endif // QT_CONFIG(tooltip)
        constellationPickCheckBox->setText(QCoreApplication::translate("viewDialogForm", "Isolated", nullptr));
#if QT_CONFIG(tooltip)
        constellationBoundariesThicknessSpinBox->setToolTip(QCoreApplication::translate("viewDialogForm", "Thickness of line in pixels", nullptr));
#endif // QT_CONFIG(tooltip)
        showAsterismLinesCheckBox->setText(QCoreApplication::translate("viewDialogForm", "Asterism lines", nullptr));
#if QT_CONFIG(tooltip)
        colorRayHelpers->setToolTip(QCoreApplication::translate("viewDialogForm", "Color of ray helpers", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        constellationHullsCheckBox->setToolTip(QCoreApplication::translate("viewDialogForm", "Show areas (convex hulls) of constellations", nullptr));
#endif // QT_CONFIG(tooltip)
        constellationHullsCheckBox->setText(QCoreApplication::translate("viewDialogForm", "Constellation areas", nullptr));
#if QT_CONFIG(tooltip)
        colorConstellationBoundaries->setToolTip(QCoreApplication::translate("viewDialogForm", "Color of constellation boundaries", nullptr));
#endif // QT_CONFIG(tooltip)
        abbreviatedNamesCheckBox->setText(QCoreApplication::translate("viewDialogForm", "Abbreviated names", nullptr));
#if QT_CONFIG(tooltip)
        colorAsterismLabels->setToolTip(QCoreApplication::translate("viewDialogForm", "Color of asterism names", nullptr));
#endif // QT_CONFIG(tooltip)
        showConstellationArtCheckBox->setText(QCoreApplication::translate("viewDialogForm", "Constellation art", nullptr));
#if QT_CONFIG(tooltip)
        lunarSystemCheckBox->setToolTip(QCoreApplication::translate("viewDialogForm", "Show lunar stations (if defined)", nullptr));
#endif // QT_CONFIG(tooltip)
        lunarSystemCheckBox->setText(QCoreApplication::translate("viewDialogForm", "Lunar Stations", nullptr));
#if QT_CONFIG(tooltip)
        constellationArtBrightnessSpinBox->setToolTip(QCoreApplication::translate("viewDialogForm", "Brightness for constellation art", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        showConstellationBoundariesCheckBox->setToolTip(QCoreApplication::translate("viewDialogForm", "Show boundaries of constellations", nullptr));
#endif // QT_CONFIG(tooltip)
        showConstellationBoundariesCheckBox->setText(QCoreApplication::translate("viewDialogForm", "Constellation boundaries", nullptr));
#if QT_CONFIG(tooltip)
        rayHelpersFadeDurationDoubleSpinBox->setToolTip(QCoreApplication::translate("viewDialogForm", "Fading duration for lines of ray helpers", nullptr));
#endif // QT_CONFIG(tooltip)
        showConstellationLinesCheckBox->setText(QCoreApplication::translate("viewDialogForm", "Constellation lines", nullptr));
#if QT_CONFIG(tooltip)
        namesFadeDurationDoubleSpinBox->setToolTip(QCoreApplication::translate("viewDialogForm", "Fading duration for screen labels of constellations", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        constellationHullsThicknessSpinBox->setToolTip(QCoreApplication::translate("viewDialogForm", "Thickness of line in pixels", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        lunarSystemFadeDurationDoubleSpinBox->setToolTip(QCoreApplication::translate("viewDialogForm", "Fading duration for lunar station lines", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        asterismNamesFadeDurationDoubleSpinBox->setToolTip(QCoreApplication::translate("viewDialogForm", "Fading duration for screen labels of asterisms ", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        lunarSystemThicknessSpinBox->setToolTip(QCoreApplication::translate("viewDialogForm", "Thickness of line in pixels", nullptr));
#endif // QT_CONFIG(tooltip)
        showRayHelpersCheckBox->setText(QCoreApplication::translate("viewDialogForm", "Ray helpers", nullptr));
#if QT_CONFIG(tooltip)
        artFadeDurationDoubleSpinBox->setToolTip(QCoreApplication::translate("viewDialogForm", "Fading duration for artwork of constellations ", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        colorConstellationLabels->setToolTip(QCoreApplication::translate("viewDialogForm", "Color of constellation names", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        constellationHullsFadeDurationDoubleSpinBox->setToolTip(QCoreApplication::translate("viewDialogForm", "Fading duration for area limits of constellations", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        asterismLineThicknessSpinBox->setToolTip(QCoreApplication::translate("viewDialogForm", "Thickness of line in pixels", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        colorConstellationLines->setToolTip(QCoreApplication::translate("viewDialogForm", "Color of constellation lines", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        constellationLineThicknessSpinBox->setToolTip(QCoreApplication::translate("viewDialogForm", "Thickness of line in pixels", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        selectSingleConstellationCheckBox->setToolTip(QCoreApplication::translate("viewDialogForm", "Click on star to show its constellation", nullptr));
#endif // QT_CONFIG(tooltip)
        selectSingleConstellationCheckBox->setText(QCoreApplication::translate("viewDialogForm", "Select single constellation", nullptr));
        showAsterismLabelsCheckBox->setText(QCoreApplication::translate("viewDialogForm", "Asterism labels", nullptr));
#if QT_CONFIG(tooltip)
        zodiacFadeDurationDoubleSpinBox->setToolTip(QCoreApplication::translate("viewDialogForm", "Fading duration for zodiac lines", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        asterismsFontSizeSpinBox->setToolTip(QCoreApplication::translate("viewDialogForm", "Asterisms font size", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        rayHelperThicknessSpinBox->setToolTip(QCoreApplication::translate("viewDialogForm", "Thickness of line in pixels", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        lunarSystemColorButton->setToolTip(QCoreApplication::translate("viewDialogForm", "Color of Lunar station lines", nullptr));
#endif // QT_CONFIG(tooltip)
        lunarSystemColorButton->setText(QString());
#if QT_CONFIG(tooltip)
        linesFadeDurationDoubleSpinBox->setToolTip(QCoreApplication::translate("viewDialogForm", "Fading duration for lines of constellations", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        boundariesFadeDurationDoubleSpinBox->setToolTip(QCoreApplication::translate("viewDialogForm", "Fading duration for boundaries of constellations", nullptr));
#endif // QT_CONFIG(tooltip)
        skyCultureTabWidget->setTabText(skyCultureTabWidget->indexOf(skyCultureDetailsTab), QCoreApplication::translate("viewDialogForm", "Details and Appearance", nullptr));
        skyCultureTimeOptionsGroupBox->setTitle(QCoreApplication::translate("viewDialogForm", "Options", nullptr));
        skyCultureCurrentTimeLabel->setText(QCoreApplication::translate("viewDialogForm", "Current time", nullptr));
        skyCultureMinTimeLabel->setText(QCoreApplication::translate("viewDialogForm", "Minimum year", nullptr));
        skyCultureMaxTimeLabel->setText(QCoreApplication::translate("viewDialogForm", "Maximum year", nullptr));
        applyTimeOnListCheckBox->setText(QCoreApplication::translate("viewDialogForm", "Apply time interval limits to list", nullptr));
        selectedCultureMinTimeLabel->setText(QCoreApplication::translate("viewDialogForm", "Selected culture start time:", nullptr));
        selectedCultureMaxTimeLabel->setText(QCoreApplication::translate("viewDialogForm", "Selected culture end time:", nullptr));
        useLocationForRotationCheckBox->setText(QCoreApplication::translate("viewDialogForm", "Rotate the map according to the current location", nullptr));
        culturesListSearchLineEdit->setText(QString());
        culturesListSearchLineEdit->setPlaceholderText(QCoreApplication::translate("viewDialogForm", "Enter Culture...", nullptr));
        skyCultureTabWidget->setTabText(skyCultureTabWidget->indexOf(skyCultureMapTab), QCoreApplication::translate("viewDialogForm", "Exploration and Selection", nullptr));
        surveysFilter->setPlaceholderText(QCoreApplication::translate("viewDialogForm", "Filter", nullptr));
        (void)viewDialogForm;
    } // retranslateUi

};

namespace Ui {
    class viewDialogForm: public Ui_viewDialogForm {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_VIEWDIALOG_H
